# Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved. 
# Caution: This file is part of the command scripting implementation. Do not edit or move
# this file because this may cause commands and scripts to fail. Do not
# try to reuse the logic in this file or keep copies of this file because this
# could cause your scripts to fail when you upgrade to a different version.
"""
This script holds all the commands for Webcenter Ensemble Connections.
@author Greg Gutkin
"""
import ora_mbs
import jarray
from java.lang import Object
from java.lang import String
from java.lang import Exception
from javax.management import Attribute
import WebCenterHandlerHelper as helper

# Code for detecting syntax error, especially missing colons
def ensembleCheck():
    helper.wcPrintMessage('FILE_CHECK_MESG')

# Create an Ensemble Connection.
def registerPageletProducer(appName,name,url,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    noError = 1
    nameError = 0
    urlError = 0
    if (not checkEnsembleFieldNotEmpty(name)):
        nameError=1
        noError=0
    if (not checkEnsembleFieldNotEmpty(url)):
        urlError=1
        noError=0
    if noError==0:
        helper.wcPrintErrorMessage('CREATECONNECTION_ARGUMENT_ERROR')
        if nameError:
            printInvalidEnsembleConnectionName()
        if urlError:
            printInvalidEnsembleUrl()
    if noError:
        connectionType='EnsembleConnectionProvider'
        userArg={'URL':url} # userArg is a dictionary
        helper.customCreateConnection(appName,name,connectionType,userArg,needsRestart=0)
    helper.webcenterRestore()

# Set/modify an Ensemble Connection.
ensembleMagicKey = 'eNsEmBlEmAgIcKeY'
def setPageletProducer(appName,name,url=ensembleMagicKey,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    noError = 1
    nameError = 0
    urlError = 0
    userArg={}
    if (not checkEnsembleFieldNotEmpty(name)):
        nameError=1
        noError=0
    if (not checkEnsembleFieldNotEmpty(url)):
        urlError=1
        noError=0
    elif (url != ensembleMagicKey):
        userArg['URL'] = url
    if noError==0:
        helper.wcPrintErrorMessage('SETCONNECTION_ARGUMENT_ERROR')
        if nameError:
            printInvalidEnsembleConnectionName()
        if urlError:
            printInvalidEnsembleUrl()
    else:
    	helper.customSetConnection(appName,name,'EnsembleConnectionProvider',userArg,0,needsRestart=0)
    helper.webcenterRestore()

def listPageletProducers(appName,verbose=0,name='',server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    stringAttrs= [(helper.wcGetMessageFromResourceBundle('ENSEMBLE_LABEL_CONNECTION_NAME'),'ConnectionName'),\
                  (helper.wcGetMessageFromResourceBundle('ENSEMBLE_LABEL_URL'),'URL')]
    nonStrAttrs=None 
    helper.customListConnections(appName,'EnsembleConnectionProvider',stringAttrs,ensembleNonStrAttrs,nonStrAttrs,verbose,name)
    helper.webcenterRestore()

def deregisterPageletProducer(appName,name='',server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    helper.deleteConnection(appName,name,server,applicationVersion)
    helper.webcenterRestore()

# Helper functions

def ensembleNonStrAttrs(objName,nonStrAttrs):
    pass

#Function to check if param is not null or not empty
def checkEnsembleFieldNotEmpty(param):
    if param is None:
        return 0
    if len(param.strip())==0:
        return 0
    return 1

#Messages for Ensemble Service
def printInvalidEnsembleConnectionName():
    helper.wcPrintErrorMessage('ENSEMBLE_ERROR_INVALID_CONNECTION_NAME')

def printInvalidEnsembleUrl():
    helper.wcPrintErrorMessage('ENSEMBLE_ERROR_INVALID_URL')

def printInvalidEnsembleUsername():
    helper.wcPrintErrorMessage('ENSEMBLE_ERROR_INVALID_USERNAME')
    
def printInvalidEnsemblePassword():
    helper.wcPrintErrorMessage('ENSEMBLE_ERROR_INVALID_PASSWORD')    

def getEnsembleObjectName(appName, connectionName):
    mbeanarray = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(mbeanarray,appName)
    connObjName = helper.getConnObjName(ADFConnObjName,connectionName,'EnsembleConnectionProvider')
    return connObjName

def getEnsembleConnectionAttribute(appName, connectionName, attributeType, server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    attrVal = None
    try:
        objName = getEnsembleObjectName(appName, connectionName)
        if objName is None :
            attrVal = None
        attrVal = ora_mbs.getAttribute(objName, attributeType)
    except Exception,ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
        helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE',attributeType)
    helper.webcenterRestore()
    return attrVal
