# Caution: This file is part of the command scripting implementation. Do not edit or move
# this file because this may cause commands and scripts to fail. Do not
# try to reuse the logic in this file or keep copies of this file because this
# could cause your scripts to fail when you upgrade to a different version.
"""
This script holds the commands to export/import groupspace/templates for WebCenter application.
@author Jaya Chaudhary
"""
import ora_mbs
import javax.management as management
import jarray
from java.lang import Object
from java.lang import String
from java.lang import Exception
from javax.management import Attribute
import WebCenterHandlerHelper as helper
import LifecycleHandler as lifecyclehandler
import ExtractConnHandler as extractConnection
import re
import os
import shutil
import tempfile
import zipfile

# Code for detecting syntax error, especially missing colons
def expimpCheck():
    helper.wcPrintMessage('FILE_CHECK_MESG')

def listWebCenterPortalArchive(appName, fileName,  extractDir=''):
    return lifecyclehandler.listWebCenterPortalArchive(appName=appName, fileName=fileName, extractDir=extractDir)

def importWebCenterPortalConnections(appName, fileName, promptForPassword=1, logFile='', server='', applicationVersion=''):
    return lifecyclehandler.importWebCenterPortalConnections(appName=appName, fileName=fileName, promptForPassword=promptForPassword, logFile=logFile, server=server, applicationVersion=applicationVersion)

def exportWebCenterPortalConnections(appName, fileName, connectionType=None, connectionName=None, logFile='', server='', applicationVersion=''):
    return lifecyclehandler.exportWebCenterPortalConnections(appName=appName, fileName=fileName, connectionType=connectionType, connectionName=connectionName, logFile=logFile, server=server, applicationVersion=applicationVersion)

# Export GroupSpace (s) command
def exportGroupSpaces(appName, fileName, names=None, exportCustomizations=1, exportSecurity=0, exportData=1, forceOffline=0, server='', applicationVersion=''):
    if names:
        nameArr = re.split(',', names.replace(' ', ''))

        if not exportSecurity:
            helper.wcPrintMessage('GS_SEC_POLICY_NOT_EXPORTED')
        # Call the _doExport method from lifecycle wlst
        return lifecyclehandler._doExport(appName=appName, fileName=fileName, scopeNames=nameArr, exportBaseDocuments=1, exportCustomizations=exportCustomizations, exportPersonalizations=0, exportSecurity=exportSecurity, exportData=exportData, exportPreferences=1, forceOffline=forceOffline, includeUCMData=0, serviceIds=None, showProgress=0, server=server, applicationVersion=applicationVersion)
    else:
        helper.wcPrintMessage('GS_EXP_EXAMPLE')
        return lifecyclehandler.failureStatus

def exportWebCenterPortals(appName, fileName, names=None, offlineDuringExport=0, exportUCMData=0, exportConnections=0, server='',applicationVersion=''):
    if lifecyclehandler._validateArgument('LF_INVALID_EXPORTCONNECTIONS', exportConnections) == 0:
        return lifecyclehandler.failureStatus
    # Call the _doExportPortals method from lifecycle wlst
    nameArr = None
    if names:
        nameArr = re.split(',', names.replace(' ', ''))
    retval = lifecyclehandler._doExportPortals(appName=appName, fileName=fileName, scopeNames=nameArr, offlineDuringExport=offlineDuringExport, includeUCMData=exportUCMData, isTemplateExport=0, serviceIds=None, server=server, applicationVersion=applicationVersion)
    if retval == lifecyclehandler.successStatus and exportConnections == 1:
        # Extract the connections config details
        print ''
        helper.wcPrintMessage('EXTCONN_EXPORT_EXTRACT_CONNECTIONS')
        # create a temp directory for the portal contents and connection.properties
        tempDir = tempfile.gettempdir()
        tempDir = os.path.join(tempDir, 'wlst')
        if os.path.isdir(tempDir):
            shutil.rmtree(tempDir)
        os.makedirs(tempDir)
        configFile = os.path.join(tempDir, 'connection.properties')
        connectionLogFile = os.path.join(tempDir, 'connectionExtraction.log')
        extConn = extractConnection.ExtractConnections(appName=appName,configFile=configFile,logFile=connectionLogFile,server=server,applicationVersion=applicationVersion)
        extConn.extractConnectionConfig()
        connectionReturnCode = extConn.getReturnCode()

        # extract the fileName contents into a temp location and zip it back , including the connection.properties
        # temporary work around since zipfile.ZipFile.write() corrupts 
        # archive intermittently
        # Bug: 12599310: Trim any leading and trailing white spaces in file arguments
        fileName = fileName.strip()

        print ''
        helper.wcPrintMessage('EXTCONN_EXPORT_ADD_CONNECTIONS',os.path.basename(configFile),fileName)
        try:
            myZipFile=zipfile.ZipFile(fileName,'r')
            for name in myZipFile.namelist(): 
              toFile = os.path.join(tempDir, name)
              if name.endswith(".pdr"):
                fd = open(toFile, "wb")
              elif name.endswith(".log"):
                # append the connectionLogFile first to the log file
                fd = open(toFile, "w")
                tempFile = open(connectionLogFile, "r")
                fileContent = tempFile.read()
                fd.write(fileContent)
                tempFile.close()
                # delete the connectionLogFile
                os.remove(connectionLogFile)
              else :
                fd = open(toFile,"w")    
              fd.write(myZipFile.read(name))
              fd.close()
            myZipFile.close()
        
            newZip = zipfile.ZipFile(fileName, mode='w')
            fileList = os.listdir(tempDir)
            for name in fileList:
              name = os.path.join(tempDir, name)
              newZip.write(name,os.path.basename(name))
            newZip.close()
        except Exception:
            helper.wcPrintMessage('EXTCONN_EXPORT_EXCEPTION', fileName)
            return lifecyclehandler.failureStatus
    
        # copy connection.properties outside of the archive
        destnDir = os.path.dirname(os.path.abspath(fileName))
        shutil.copy(configFile, destnDir)
        helper.wcPrintMessage('EXTCONN_EXPORT_SUCCESS_MESSAGE', os.path.basename(configFile), destnDir)
    
        # delete the tempDir
        shutil.rmtree(tempDir)
        if connectionReturnCode == lifecyclehandler.failureStatus:
           helper.wcPrintMessage('EXTCONN_EXPORT_ERROR')
           return connectionReturnCode
    return retval    

def exportWebCenterPortalTemplates(appName, fileName, names=None, exportUCMData=0, server='',applicationVersion=''):
    # Call the _doExportPortals method from lifecycle wlst
    portalTemplates = []
    nameArr = None
    if names:
        nameArr = re.split(',', names.replace(' ', ''))
        for i in range (len(nameArr)):
            portalTemplates.append('spacetemplate/' + nameArr[i])
    return lifecyclehandler._doExportPortals(appName=appName, fileName=fileName, scopeNames=portalTemplates, offlineDuringExport=0, includeUCMData=exportUCMData, isTemplateExport=1, serviceIds=None, server=server, applicationVersion=applicationVersion)

def importWebCenterPortals(appName, fileName, names=None, outputFile=None, forceOffline=0, parentPortal='',backupPortal=0, overwrite=0, importPortalContent=0, importCustomizations=1, importSecurity=1, importData=1, importActivities=1, server='',applicationVersion=''):
    return lifecyclehandler._doImportPortals(appName=appName, fileName=fileName, scopeNames=names, outputFile=outputFile, forceOffline=forceOffline, parentPortal=parentPortal, backupPortal=backupPortal, overwrite=overwrite,  importPortalContent=importPortalContent, importCustomizations=importCustomizations, importSecurity=importSecurity, importData=importData, importActivities=importActivities, server=server, applicationVersion=applicationVersion)

# Export Portal (s) command
def deployWebCenterPortal(appName, name=None, includeUCMData=1, targetConnectionName=None, outputFile=None, backupPortal=0, overwrite=0, deployCustomizations=1, deploySecurity=1, deployData=1, deployActivities=1, server='',applicationVersion=''):
    if name:
        nameArr = re.split(',', name.replace(' ', ''))
        if len(nameArr) >1 :
            helper.wcPrintErrorMessage('LF_ERROR_DEPLOY_MULTIPLE_PORTALS')
            return lifecyclehandler.failureStatus
        exportCustomizations=1
        exportSecurity=1
        exportData=1
        forceOffline=1
        # Call the _doExport method from lifecycle wlst
        # personalizations set when customizations is set
        return lifecyclehandler._doDeploy(appName=appName, portalNames=nameArr, exportBaseDocuments=1, exportCustomizations=deployCustomizations, exportPersonalizations=deployCustomizations,
                  exportSecurity=deploySecurity, exportData=deployData, exportPreferences=1, forceOffline=forceOffline, 
                  includeExternalData=includeUCMData, targetConnectionName=targetConnectionName, outputFile=outputFile, serviceIds=None, backupPortal=backupPortal, 
                  overwrite=overwrite, deployActivities=deployActivities, server=server, applicationVersion=applicationVersion)
    else:
        #TODO - Add help text for the deploy 
        helper.wcPrintMessage('DEPLOY_PORTAL_EXAMPLE')
        return lifecyclehandler.failureStatus

# Export GroupSpace (s) template command
def exportGroupSpaceTemplates(appName, fileName, names=None, server='', applicationVersion=''):
    groupSpaceTemplates = []
    if names:
        nameArr = re.split(',', names.replace(' ', ''))
        for i in range (len(nameArr)):
            groupSpaceTemplates.append('spacetemplate/' + nameArr[i])
        # Call the _doExport method from lifecycle wlst
        return lifecyclehandler._doExport(appName=appName, fileName=fileName, scopeNames=groupSpaceTemplates, exportBaseDocuments=1, exportCustomizations=1, exportPersonalizations=1, exportSecurity=1, exportData=1, exportPreferences=1, forceOffline=0, includeUCMData=0, serviceIds=None, showProgress=0, server=server, applicationVersion=applicationVersion) 
    else:
        helper.wcPrintMessage('GS_TEMP_EXP_EXAMPLE')
        return lifecyclehandler.failureStatus

def validateArgsForDeviceType(resourceType, scopeName, resourceGUID):
    if scopeName is not None:
        helper.wcPrintMessage('DEVICE_TYPE_IGNORE_SCOPE', resourceType)
    if resourceGUID is not None:
        helper.wcPrintMessage('DEVICE_TYPE_IGNORE_RESOURCEGUID', resourceType)

# Export Site Resource(s) command
def exportSiteResources(appName, fileName, scopeName, resourceType, resourceGUID=None, resourceName=None, server='',applicationVersion=''):
    if resourceType == 'device' or resourceType == 'deviceGroup':
        validateArgsForDeviceType(resourceType, scopeName, resourceGUID)
    if scopeName is None:
      scopeName = 'defaultScope'
    resNameArr = None
    resGuidArr = None
    if resourceGUID:
        resGuidArr = re.split(',', resourceGUID.replace(' ', ''))
    if resourceName:
        resNameArr = re.split(',', resourceName)
    if resourceName is not None or resourceGUID is not None:  
        # Call the _doSiteResExport method from lifecycle wlst
        return lifecyclehandler._doSiteResExport(appName=appName, fileName=fileName, scopeName=scopeName, resourceType=resourceType, resourceGUID=resGuidArr, resourceName=resNameArr, server=server, applicationVersion=applicationVersion) 
    else:
        helper.wcPrintMessage('SITERES_EXP_EXAMPLE')
        return lifecyclehandler.failureStatus

# Import GroupSpace(s)/templates command
def importGroupSpaces(appName, fileName, exportCustomizations=1, exportSecurity=1, exportData=1, forceOffline=0, parentScope='', server='',applicationVersion=''):
    # Call the _doImport method from lifecycle wlst
    return lifecyclehandler._doScopeImport(appName=appName, fileName=fileName, exportCustomizations=exportCustomizations, exportSecurity=exportSecurity, exportData=exportData, forceOffline=forceOffline, parentScope=parentScope, scopeName=None, resourceType=None, showProgress=0, server=server, applicationVersion=applicationVersion)

# Import Site Resource(s) command
def importSiteResources(appName, fileName, scopeName, resourceType, server='',applicationVersion=''):
    # Call the _doSiteResImport method from lifecycle wlst
    if scopeName is None:
      scopeName = 'defaultScope'
    if resourceType is None:
      resourceType = 'NotProvided'
    return lifecyclehandler._doScopeImport(appName=appName, fileName=fileName, exportCustomizations=None, exportSecurity=None, exportData=None, forceOffline=None, parentScope=None, scopeName=scopeName, resourceType=resourceType, showProgress=0, server=server, applicationVersion=applicationVersion)

# Import Site Resource(s) command
def importSiteResourcesInternal(appName, fileName, scopeGUID, resourceType, server='', applicationVersion=''):
    # Call the _doSiteResImport method from lifecycle wlst
    if resourceType is None:
      resourceType = 'NotProvided'
    return lifecyclehandler._doImportInternal(appName=appName, fileName=fileName,exportCustomizations=None, exportSecurity=None, exportData=None, forceOffline=None, parentScope=None, scopeGUID=scopeGUID, resourceType=resourceType, server=server, applicationVersion=applicationVersion)

