# Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved. 
# Caution: This file is part of the command scripting implementation. Do not edit or move
# this file because this may cause commands and scripts to fail. Do not
# try to reuse the logic in this file or keep copies of this file because this
# could cause your scripts to fail when you upgrade to a different version.
"""
This script holds all the functions for Webcenter Discussion Forum Connections.
@author Alexis Chan
"""
# Code for detecting syntax error, especially missing colons
import ora_mbs
import javax.management as management
import jarray
from java.lang import Object
from java.lang import String
from java.lang import Exception
from javax.management import Attribute
import WebCenterHandlerHelper as helper
import CollabHandler as collabhandler
from javax.management import RuntimeMBeanException
from javax.management.openmbean import ArrayType
from javax.management import ObjectName
import re
def fcpCheck():
    helper.wcPrintMessage('FILE_CHECK_MESG')

def createDiscussionForumConnection(appName,name,url,adminUser,secured=0,timeout=-1,default=0,policyURIForAuthAccess='',policyURIForPublicAccess='',recipientKeyAlias='',server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionType='ForumConnectionProvider'
    if(not collabhandler.checkCollabConnFieldNotEmpty(url)):
        helper.wcPrintMessage('PARAMETER_MISSING', 'url,Forum')
	helper.wcPrintMessage('ERROR_CREATE_CONNECTION',name)
	return None
    if(not collabhandler.checkCollabConnFieldNotEmpty(adminUser)):
        helper.wcPrintMessage('PARAMETER_MISSING', 'adminUser,Forum')
	helper.wcPrintMessage('ERROR_CREATE_CONNECTION',name)
	return None    
    userArg={'Url':url,'AdminUser':adminUser,'ConnectionTimeOut':timeout,'PolicyURIForAuthenticatedAccess':policyURIForAuthAccess,'PolicyURIForPublicAccess':policyURIForPublicAccess,'RecipientKeyAlias':recipientKeyAlias}
    connObj = helper.customCreateConnection(appName,name,connectionType,userArg)
    # set connection as default only if create connection succeeded
    if connObj is not None:
        if default==1:
            setDefaultDiscussionForumConnection(appName,name,server,applicationVersion)
    helper.webcenterRestore()

def setDiscussionForumConnection(appName,name,url='OrAcLeDiScUsSiOnFoRuMwLsTmAgIcKeYs',adminUser='OrAcLeDiScUsSiOnFoRuMwLsTmAgIcKeYs',secured='OrAcLeDiScUsSiOnFoRuMwLsTmAgIcKeYs',timeout=-1,default='',policyURIForAuthAccess='OrAcLeDiScUsSiOnFoRuMwLsTmAgIcKeYs',policyURIForPublicAccess='OrAcLeDiScUsSiOnFoRuMwLsTmAgIcKeYs',recipientKeyAlias='OrAcLeReCiPiEnTkEyAlIaS',server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    #obtain old values as validation can be done with a union of currently passed in params and already existing param.
    #This is required as set command does not mandate all params to be passed.
    objname = getDFbjectName(appName, name)
    if objname is None:
      helper.wcPrintErrorMessage('ERROR_NO_CONNECTION', name)
      helper.webcenterRestore()
      return
    if(not collabhandler.checkCollabConnFieldNotEmpty(url)):
        helper.wcPrintMessage('PARAMETER_MISSING', 'url,Forum')
        helper.wcPrintMessage('ERROR_SET_CONNECTION',name)
        return None
    if(not collabhandler.checkCollabConnFieldNotEmpty(adminUser)):
        helper.wcPrintMessage('PARAMETER_MISSING', 'adminUser,Forum')
        helper.wcPrintMessage('ERROR_SET_CONNECTION',name)
        return None
    if(url == 'OrAcLeDiScUsSiOnFoRuMwLsTmAgIcKeYs'):
        try:
            url = ora_mbs.getAttribute(objname,'Url')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','Url')
    if(adminUser == 'OrAcLeDiScUsSiOnFoRuMwLsTmAgIcKeYs'):
        try:
            adminUser = ora_mbs.getAttribute(objname,'AdminUser')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','AdminUser')
    if(policyURIForAuthAccess == 'OrAcLeDiScUsSiOnFoRuMwLsTmAgIcKeYs'):
        try:
            policyURIForAuthAccess = ora_mbs.getAttribute(objname,'PolicyURIForAuthenticatedAccess')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','PolicyURIForAuthenticatedAccess')
    if(policyURIForPublicAccess == 'OrAcLeDiScUsSiOnFoRuMwLsTmAgIcKeYs'):
        try:
            policyURIForPublicAccess = ora_mbs.getAttribute(objname,'PolicyURIForPublicAccess')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','PolicyURIForPublicAccess')
    if(recipientKeyAlias == 'OrAcLeReCiPiEnTkEyAlIaS'):
        try:
            recipientKeyAlias = ora_mbs.getAttribute(objname,'RecipientKeyAlias')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','RecipientKeyAlias')
    userArg={'Url':url,'AdminUser':adminUser,'ConnectionTimeOut':timeout,'PolicyURIForAuthenticatedAccess':policyURIForAuthAccess,'PolicyURIForPublicAccess':policyURIForPublicAccess,'RecipientKeyAlias':recipientKeyAlias}
    helper.customSetConnection(appName,name,'ForumConnectionProvider',userArg,0)
    if(default is not None and default != ''):
      if default==1:
          setDefaultDiscussionForumConnection(appName,name,server,applicationVersion)
      else:
          connectionName = collabhandler.getCollabDefaultConnection(appName,'oracle.webcenter.collab.forum')
          if connectionName == name:
            removeDiscussionForumServiceProperty(appName,'selected.connection',server,applicationVersion)
          connectionName = collabhandler.getCollabDefaultConnection(appName,'oracle.webcenter.collab.announcement')
          if connectionName == name:
            removeAnnouncementServiceProperty(appName,'selected.connection',server,applicationVersion)

    helper.webcenterRestore()

def listDiscussionForumConnections(appName,verbose=0,name='',server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    stringAttrs= [(helper.wcGetMessageFromResourceBundle('CON_NAME'),'ConnectionName'),(helper.wcGetMessageFromResourceBundle('URL'),'Url'),(helper.wcGetMessageFromResourceBundle('ADMIN_USER'),'AdminUser'),(helper.wcGetMessageFromResourceBundle('BPEL_RECIPIENT_KEY_ALIAS_ID4'),'RecipientKeyAlias')]
    nonStrAttrs = [(helper.wcGetMessageFromResourceBundle('CONNECTION_TIME_OUT'),'ConnectionTimeOut')]
    helper.customListConnections(appName,'ForumConnectionProvider',stringAttrs,forumNonStrAttrsFunc,nonStrAttrs,verbose,name)
    helper.webcenterRestore()

def listDefaultDiscussionForumConnection(appName,verbose=0,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionName = collabhandler.getCollabDefaultConnection(appName,'oracle.webcenter.collab.forum')
    print '------------------'
    helper.wcPrintMessage('DEFAULT_CONNECTION', connectionName)
    print '------------------'
    if verbose:
        listDiscussionForumConnections(appName,1,connectionName,server,applicationVersion)
    helper.webcenterRestore()

def setDiscussionForumConnectionProperty(appName,name,key,value,secure=0,server='',applicationVersion=''):
    if secure:
	setSecureDFConnectionProperty(appName,name,key,value,server,applicationVersion)
	return None
    helper.webcenterInitialize(server,applicationVersion)
    connectionType='ForumConnectionProvider'
    objs = jarray.array([key,value],Object)
    strs = jarray.array(['java.lang.String','java.lang.String'],String)
    connectionTypeStr=helper.wcGetMessageFromResourceBundle('DF_CONNECTION')
    setArgs=[objs,strs,'addProperty', helper.printErrorInvokingAddProperty,helper.printAddPropertySuccess,key,connectionTypeStr]
    helper.editProperty(appName,name,connectionType,helper.setPropertyFunc,setArgs)
    helper.webcenterRestore()

def setSecureDFConnectionProperty(appName,name,key,value,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionType='ForumConnectionProvider'
    objs = jarray.array([key,value],Object)
    strs = jarray.array(['java.lang.String','java.lang.String'],String)
    connectionTypeStr=helper.wcGetMessageFromResourceBundle('DF_CONNECTION')
    setArgs=[objs,strs,'addSecuredProperty',helper.printErrorInvokingAddProperty,helper.printAddPropertySuccess,key,connectionTypeStr]
    helper.editProperty(appName,name,connectionType,helper.setPropertyFunc,setArgs)
    helper.webcenterRestore()

def deleteDiscussionForumConnectionProperty (appName,name,key,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionType='ForumConnectionProvider'
    objs = jarray.array([key],Object)
    strs = jarray.array(['java.lang.String'],String)
    connectionTypeStr=helper.wcGetMessageFromResourceBundle('DF_CONNECTION')
    deleteArgs=[objs,strs,'removeProperty',helper.printErrorInvokingRemoveProperty,helper.printRemovePropertySuccess,connectionTypeStr]
    helper.editProperty(appName,name,connectionType,helper.deletePropertyFunc,deleteArgs)
    helper.webcenterRestore()


# Sets the specified Forum Connection as the Forum Connection in ADF Forum Config MBean
def setDefaultDiscussionForumConnection(appName,name,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    noError = 1
    connectionType='ForumConnectionProvider'
    connectionMBeans = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(connectionMBeans,appName)
    # Need the ADF Connections Object Name to search for the connection name
    if ADFConnObjName is None:
        noError=0
    if(not checkDFConFieldNotEmpty(name)):
        helper.wcPrintMessage('INVALID_CONNECTION_NAME')
        noError=0
    if(not helper.connMBeanExists(ADFConnObjName,name,connectionType)):
        printNoForumConnection(name)
        noError=0
    if noError:
        collabhandler.setCollabDefaultConnection(appName,'oracle.webcenter.collab.forum',name,server,applicationVersion)
    setDefaultAnnouncementConnection(appName, name,server,applicationVersion)
    helper.webcenterRestore()

# Sets the specified Forum Connection as the Announcement Connection in ADF Config MBean
def setDefaultAnnouncementConnection(appName,name,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    noError = 1    
    connectionType='ForumConnectionProvider'
    connectionMBeans = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(connectionMBeans,appName)
    # Need the ADF Connections Object Name to search for the connection name
    if ADFConnObjName is None:
        helper.webcenterCommandError()
        noError=0
    if(not checkDFConFieldNotEmpty(name)):
        helper.webcenterCommandError()
        helper.wcPrintMessage('INVALID_CONNECTION_NAME')
        noError=0
    if(not helper.connMBeanExists(ADFConnObjName,name,connectionType)):
        helper.webcenterCommandError()
        printNoForumConnection(name)
        noError=0
    if noError:
        collabhandler.setCollabDefaultConnection(appName,'oracle.webcenter.collab.announcement',name,server,applicationVersion)
    helper.webcenterRestore()

def syncDiscussionServerPermissions(appName,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    try:
      forumRoleMappingObjectName = getForumRoleMappingMBean(appName)
      ora_mbs.invoke(forumRoleMappingObjectName, 'syncDiscussionsRoleMapping', None, None)
      announcementRoleMappingObjectName = getAnnouncementRoleMappingMBean(appName)
      ora_mbs.invoke(announcementRoleMappingObjectName, 'syncAnnouncementRoleMapping', None, None)
    except Exception, e:
      helper.wcPrintExceptionMessage(e.printStackTrace())
    helper.webcenterRestore()
  
def setDiscussionForumServiceProperty(appName,property,value,server='',applicationVersion=''):
    collabhandler.addCollabServiceProperty(appName,'oracle.webcenter.collab.forum',property,value,server,applicationVersion)

def removeDiscussionForumServiceProperty(appName,property,server='',applicationVersion=''):
    collabhandler.removeCollabServiceProperty(appName,'oracle.webcenter.collab.forum',property,server,applicationVersion)

def listDiscussionForumServiceProperties(appName,server='',applicationVersion=''):
    collabhandler.listCollabServiceProperties(appName,'oracle.webcenter.collab.forum',server,applicationVersion)

def setAnnouncementServiceProperty(appName,property,value,server='',applicationVersion=''):
    collabhandler.addCollabServiceProperty(appName,'oracle.webcenter.collab.announcement',property,value,server,applicationVersion)

def removeAnnouncementServiceProperty(appName,property,server='',applicationVersion=''):
    collabhandler.removeCollabServiceProperty(appName,'oracle.webcenter.collab.announcement',property,server,applicationVersion)

def listAnnouncementServiceProperties(appName,server='',applicationVersion=''):
    collabhandler.listCollabServiceProperties(appName,'oracle.webcenter.collab.announcement',server,applicationVersion)

# Helper functions
def forumNonStrAttrsFunc(objName,nonStrAttrs):
    attrLabel = helper.wcGetMessageFromResourceBundle('POLICY_URI_FOR_AUTH_ACCESS')
    attrValue = ora_mbs.getAttribute(objName,'PolicyURIForAuthenticatedAccess')
    if(not collabhandler.checkCollabConnFieldNotEmpty(attrValue)):
      attrValue = 'oracle/wss10_saml_token_service_policy'
    print attrLabel+ ' '+ attrValue
    attrLabel = helper.wcGetMessageFromResourceBundle('POLICY_URI_FOR_PUBLIC_ACCESS')
    attrValue = ora_mbs.getAttribute(objName,'PolicyURIForPublicAccess')
    if(not collabhandler.checkCollabConnFieldNotEmpty(attrValue)):
      attrValue = 'oracle/no_authentication_client_policy'
    print attrLabel+ ' '+ attrValue
    for item in nonStrAttrs:
        try:
            attrLabel=item[0]
            attrName=item[1]
            obj = ora_mbs.getAttribute(objName,attrName)
            if obj is None:
                attrValue='-1'
            else:
                if attrName=='ConnectionSecured':
                  if obj==1:
                    attrValue=helper.wcGetMessageFromResourceBundle('YES')
                  else:
                    attrValue=helper.wcGetMessageFromResourceBundle('NO')
                else:  
                  attrValue=str(obj)
            print attrLabel+ ' '+ attrValue
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE',item[1])
    #Returns ComposteData[] which is then formatted
    try:
        addfields=ora_mbs.getAttribute(objName,'Properties')
        if addfields is not None:
           print helper.wcGetMessageFromResourceBundle('ADDITIONAL_PROPERTIES_MSG')+': '+formatForumFields(addfields)
    except Exception, ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
        helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','Properties')

#Rountine to format additional fields
def formatForumFields(addfields):
    #no additional fields
    fieldlen=len(addfields)
    if fieldlen==0:
        return helper.wcGetMessageFromResourceBundle('ADDITIONAL_PROPERTIES_NOT_SPECIFIED')
    #concatenate additional fields to render in list command
    formatStr='{'
    index=0
    for field in addfields:
        fieldname=field.get('key')
        fieldval=field.get('value')
        formatStr=formatStr+str(fieldname)+':'+str(fieldval)
        #add , only if there are more fields
        if (index<fieldlen-1):
            formatStr=formatStr+','
        index = index + 1

    formatStr=formatStr+'}'
    return formatStr


def printNoForumConnection(connectionName):
    helper.wcPrintErrorMessage('ERROR_NO_CONNECTION',connectionName)

#Function to check if param is not null or not empty
def checkDFConFieldNotEmpty(param):
    if param is None:
        return 0
    if len(param.strip())==0:
        return 0
    return 1

# Gets an array of MBean object names that match the pattern supplied
def _getForumMBeanArray(pattern):
    objname= ObjectName(pattern)
    try:
        mbset = ora_mbs.queryNames(objname,None)
        mbarray= mbset.toArray()
        return mbarray
    except Exception, ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
        helper.wcPrintErrorMessage('LF_ERROR_MDS_QUERY_NAMES',pattern)
    return None

#Function to return extapp objectname 
def getDFbjectName(appName, connectionName):
    mbeanarray = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(mbeanarray,appName)
    connObjName = helper.getConnObjName(ADFConnObjName,connectionName,'ForumConnectionProvider')
    return connObjName

# Finds an MBean that matches the pattern and contains the search string
def _findForumMBean(pattern, searchStr):
    mbeanarray = _getForumMBeanArray(pattern)
    if mbeanarray is not None:
        for i in range(len(mbeanarray)):
            objnamestr = mbeanarray[i].toString()
            if objnamestr.find(searchStr) >= 0:
                return mbeanarray[i]
    return None

# Gets the object name of the Forum RoleMapping MBean
def getForumRoleMappingMBean(appName):
    objectName = _findForumMBean('*oracle.webcenter.collab.forum:*', 'name=ForumRoleMappingSyncMXBeanImpl,type=ForumRoleMappingSyncMXBeanImpl,Application=' + appName)
    if objectName is None:
        helper.wcPrintMessage('FORUM_ROLEMAPPING_MBEAN_NOTFOUND')
    return objectName

# Gets the object name of the Announcement RoleMapping MBean
def getAnnouncementRoleMappingMBean(appName):
    objectName = _findForumMBean('*oracle.webcenter.collab.announcement:*', 'name=AnnouncementRoleMappingSyncMXBeanImpl,type=AnnouncementRoleMappingSyncMXBeanImpl,Application=' + appName)
    if objectName is None:
        helper.wcPrintMessage('ANNOUNCEMENT_ROLEMAPPING_MBEAN_NOTFOUND')
    return objectName

def getDiscussionForumConnectionAttribute(appName, connectionName, attributeType,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    objName = getDFbjectName(appName,connectionName)
    attrVal = None
    if objName is None :
        return
    try:
        attrVal = ora_mbs.getAttribute(objName,attributeType)
	if attributeType == 'Properties' :
	    # format the additional fields
	    attrVal = formatForumFields(attrVal)

    except Exception, ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
        helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE',attributeType)
    helper.webcenterRestore()
    return attrVal    

def getDefaultForumConnection(appName,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionName = collabhandler.getCollabDefaultConnection(appName,'oracle.webcenter.collab.forum')
    helper.webcenterRestore()
    return connectionName
	    
