# Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved. 
# Caution: This file is part of the command scripting implementation. Do not edit or move
# this file because this may cause commands and scripts to fail. Do not
# try to reuse the logic in this file or keep copies of this file because this
# could cause your scripts to fail when you upgrade to a different version.
"""
This script holds all the functions for Webcenter Instant Messaging and Presence Connections.
@author Alexis Chan
"""
import ora_mbs
import javax.management as management
import jarray
from java.lang import Object
from java.lang import String
from java.lang import Exception
from javax.management import Attribute
import WebCenterHandlerHelper as helper
import CollabHandler as collabhandler
import ExtAppHandler as extapphandler
from javax.management import RuntimeMBeanException
from javax.management.openmbean import ArrayType
import re
# Code for detecting syntax error, especially missing colons
def rtcCheck():
    helper.wcPrintMessage('FILE_CHECK_MESG')

def createIMPConnection(appName,name, adapter, url, domain='',appId='',poolName='',policyURI='',userDomain='',adminUser='',adminPassword='',recipientKeyAlias='',timeout=-1,default=0,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionType='RtcConnectionProvider'
    if(not collabhandler.checkCollabConnFieldNotEmpty(url)):
        helper.wcPrintMessage('PARAMETER_MISSING', 'url,Presence')
	helper.wcPrintMessage('ERROR_CREATE_CONNECTION',name)
	return None
    # if adapter is LCS we throw an error if no extappId or poolname is supplied
    if adapter=='LCS':
        if(not collabhandler.checkCollabConnFieldNotEmpty(appId)):
            helper.wcPrintErrorMessage('PARAMETER_MISSING', 'appId,LCS Presence')
            helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
            return None
        if(not collabhandler.checkCollabConnFieldNotEmpty(poolName)):
            helper.wcPrintErrorMessage('PARAMETER_MISSING', 'poolName,LCS Presence')
            helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
            return None
        userArg={'BaseConnectionURL':url,'AdapterName':adapter,'ExternalAppId':appId,'PoolName':poolName,'ConnectionTimeOut':timeout}
    elif adapter=='OCS2007':
        if(not collabhandler.checkCollabConnFieldNotEmpty(appId)):
            helper.wcPrintErrorMessage('PARAMETER_MISSING', 'appId,OCS Presence')
            helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
            return None
        if(not collabhandler.checkCollabConnFieldNotEmpty(userDomain)):
            helper.wcPrintErrorMessage('PARAMETER_MISSING', 'userDomain,OCS Presence')
            helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
            return None
        if(not collabhandler.checkCollabConnFieldNotEmpty(poolName)):
            helper.wcPrintErrorMessage('PARAMETER_MISSING', 'poolName,OCS Presence')
            helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
            return None
        userArg={'BaseConnectionURL':url,'AdapterName':adapter,'ExternalAppId':appId,'UserDomain':userDomain,'PoolName':poolName,'ConnectionTimeOut':timeout}
    else:
        helper.wcPrintErrorMessage('WRONG_ADAPTER_NAME')
        helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
        return None
    if(collabhandler.checkCollabConnFieldNotEmpty(appId)):
        if(not extapphandler.checkValidAppConnName(appName,appId,'ExtAppConnectionProvider',1)):
            helper.wcPrintErrorMessage('WRONG_EXT_APP',appId)
            helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
            return None
    connObj = helper.customCreateConnection(appName,name,connectionType,userArg)
    # if connObj returned from helper.customCreateConnection is None, we don't perform any operations because the connection creation has failed.
    if connObj is not None:
        if default==1:
            setDefaultIMPConnection(appName,name,server,applicationVersion)	
    helper.webcenterRestore()

def setIMPConnection(appName,name, adapter='OrAcLeImPwLsTmAgIcKeYs',url='OrAcLeImPwLsTmAgIcKeYs', domain='OrAcLeImPwLsTmAgIcKeYs', appId='OrAcLeImPwLsTmAgIcKeYs', poolName='OrAcLeImPwLsTmAgIcKeYs',policyURI='OrAcLeImPwLsTmAgIcKeYs', userDomain='OrAcLeImPwLsTmAgIcKeYs', adminUser='OrAcLeImPwLsTmAgIcKeYs', adminPassword='OrAcLeImPwLsTmAgIcKeYs', recipientKeyAlias='OrAcLeImPwLsTmAgIcKeYs', timeout=-1, default='',server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    objname = getImpObjectName(appName, name)
    if objname is None:
    	helper.wcPrintErrorMessage('ERROR_NO_CONNECTION', name)
	helper.webcenterRestore()
        return
    # BaseConnectionUrl and AdapterName are mandatory for all adapters. ExternalAppId and PoolName are mandatory for LCS and OCS.
    if(not collabhandler.checkCollabConnFieldNotEmpty(url)):
        helper.wcPrintMessage('PARAMETER_MISSING', 'url,Presence')
        helper.wcPrintMessage('ERROR_SET_CONNECTION',name)
        return None
    if(url == 'OrAcLeImPwLsTmAgIcKeYs'):
        try:
            url = ora_mbs.getAttribute(objname,'BaseConnectionURL')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','BaseConnectionURL')
    #checks if the user has supplied a valid adapter
    if(adapter != 'OrAcLeImPwLsTmAgIcKeYs'):
        if (adapter != 'LCS'):
            if (adapter!='OCS2007'):
                helper.wcPrintErrorMessage('WRONG_ADAPTER_NAME')
                helper.wcPrintErrorMessage('ERROR_SET_CONNECTION',name)
                return None		    
    else:
        try:
            adapter = ora_mbs.getAttribute(objname,'AdapterName')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','AdapterName')
            return None

    # if appid supplied is default magic key or empty then fetch the appid already set on the connection
    if(appId == 'OrAcLeImPwLsTmAgIcKeYs'):
  	try:
           appId = ora_mbs.getAttribute(objname,'ExternalAppId')
	except Exception, ex:
           helper.wcPrintExceptionMessage(ex.getMessage())
  	   helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','ExternalAppId')

    if(appId != 'OrAcLeImPwLsTmAgIcKeYs' and appId != '' and appId is not None):
  	if(not extapphandler.checkValidAppConnName(appName,appId,'ExtAppConnectionProvider',1)):
	    helper.wcPrintErrorMessage('WRONG_EXT_APP',appId)
	    helper.wcPrintErrorMessage('ERROR_SET_CONNECTION',name)
	    return None

    # if poolName supplied is default magic key or empty then fetch the poolName already set on the connection
    if(adapter == 'LCS'):
        if(poolName == 'OrAcLeImPwLsTmAgIcKeYs'):
            try:
                poolName = ora_mbs.getAttribute(objname,'PoolName')
            except Exception, ex:
                helper.wcPrintExceptionMessage(ex.getMessage())
                helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','ExternalAppId')
        if(poolName == 'OrAcLeImPwLsTmAgIcKeYs'):
            helper.wcPrintErrorMessage('PARAMETER_MISSING', 'poolName,LCS Presence')
            helper.wcPrintErrorMessage('ERROR_SET_CONNECTION',name)
            return None
        #if the appid set on the connection is also null then throw an error for LCS adapter
        if(appId == 'OrAcLeImPwLsTmAgIcKeYs'):
            helper.wcPrintErrorMessage('PARAMETER_MISSING', 'appId,LCS Presence')
            helper.wcPrintErrorMessage('ERROR_SET_CONNECTION',name)
            return None
        userArg={'BaseConnectionURL':url,'AdapterName':adapter,'ExternalAppId':appId,'PoolName':poolName,'ConnectionTimeOut':timeout}
    elif(adapter == 'OCS2007'):
    	if(userDomain == 'OrAcLeImPwLsTmAgIcKeYs'):
	    try:
	        userDomain = ora_mbs.getAttribute(objname,'UserDomain')
	    except Exception, ex:
	        helper.wcPrintExceptionMessage(ex.getMessage())
	        helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','UserDomain')
    	if(userDomain == 'OrAcLeImPwLsTmAgIcKeYs'):
    	    helper.wcPrintErrorMessage('PARAMETER_MISSING', 'userDomain,OCS Presence')
            helper.wcPrintErrorMessage('ERROR_SET_CONNECTION',name)
    	    return None
    	if(poolName == 'OrAcLeImPwLsTmAgIcKeYs'):
    	    try:
    	        poolName = ora_mbs.getAttribute(objname,'PoolName')
            except Exception, ex:
                helper.wcPrintExceptionMessage(ex.getMessage())
    		helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','poolName')
        if(poolName == 'OrAcLeImPwLsTmAgIcKeYs'):
            helper.wcPrintErrorMessage('PARAMETER_MISSING', 'poolName,OCS Presence')
            helper.wcPrintErrorMessage('ERROR_SET_CONNECTION',name)
            return None
        #if the appid set on the connection is also null then throw an error for OCS adapter
        if(appId == 'OrAcLeImPwLsTmAgIcKeYs'):
            helper.wcPrintErrorMessage('PARAMETER_MISSING', 'appId,OCS Presence')
            helper.wcPrintErrorMessage('ERROR_SET_CONNECTION',name)
            return None
    	userArg={'BaseConnectionURL':url,'AdapterName':adapter,'ExternalAppId':appId,'UserDomain':userDomain,'PoolName':poolName,'ConnectionTimeOut':timeout}
    else:
        if(policyURI == 'OrAcLeImPwLsTmAgIcKeYs'):
            try:
                policyURI = ora_mbs.getAttribute(objname,'PolicyURI')
            except Exception, ex:
                helper.wcPrintExceptionMessage(ex.getMessage())
                helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','PolicyURI')
        if(appId != 'OrAcLeImPwLsTmAgIcKeYs' and appId != ''):
            userArg={'BaseConnectionURL':url,'AdapterName':adapter,'ExternalAppId':appId,'ConnectionTimeOut':timeout,'PolicyURI':policyURI}
        else:
            userArg={'BaseConnectionURL':url,'AdapterName':adapter,'ConnectionTimeOut':timeout,'PolicyURI':policyURI}
    helper.customSetConnection(appName,name,'RtcConnectionProvider',userArg,0)
    if(default is not None and default != ''):
        if default==1:
            setDefaultIMPConnection(appName,name,server,applicationVersion)
        else:
            connectionName = collabhandler.getCollabDefaultConnection(appName,'oracle.webcenter.collab.rtc')
            if connectionName == name:
                removeIMPServiceProperty(appName,'selected.connection',server,applicationVersion)
    helper.webcenterRestore()


def listIMPConnections(appName,verbose=0,name='',server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    objname = getImpObjectName(appName, name)
    adapter = ''
    #if name is given we can get the adapter name and show specific attributes, otherwise we have to show all the attributes
    if(name != ''):
        try:
            adapter = ora_mbs.getAttribute(objname,'AdapterName')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','AdapterName')
    if(adapter == ''):
        rtcCustomListConnections(appName, verbose)
        helper.webcenterRestore()
        return
    elif (adapter == 'LCS'):
        stringAttrs=[(helper.wcGetMessageFromResourceBundle('CON_NAME'),'ConnectionName'),(helper.wcGetMessageFromResourceBundle('BASE_CON_URL'),'BaseConnectionURL'),(helper.wcGetMessageFromResourceBundle('ADAPTER_NAME'),'AdapterName'),(helper.wcGetMessageFromResourceBundle('EXT_APP_ID'),'ExternalAppId'),(helper.wcGetMessageFromResourceBundle('LCS_POOL_NAME'),'PoolName')]
    elif (adapter == 'OCS2007'):
        stringAttrs=[(helper.wcGetMessageFromResourceBundle('CON_NAME'),'ConnectionName'),(helper.wcGetMessageFromResourceBundle('BASE_CON_URL'),'BaseConnectionURL'),(helper.wcGetMessageFromResourceBundle('ADAPTER_NAME'),'AdapterName'),(helper.wcGetMessageFromResourceBundle('EXT_APP_ID'),'ExternalAppId'),(helper.wcGetMessageFromResourceBundle('USER_DOMAIN'),'UserDomain'),(helper.wcGetMessageFromResourceBundle('OCS_POOL_NAME'),'PoolName')]
    else:
        stringAttrs=[(helper.wcGetMessageFromResourceBundle('CON_NAME'),'ConnectionName'),(helper.wcGetMessageFromResourceBundle('BASE_CON_URL'),'BaseConnectionURL'),(helper.wcGetMessageFromResourceBundle('ADAPTER_NAME'),'AdapterName'),(helper.wcGetMessageFromResourceBundle('EXT_APP_ID'),'ExternalAppId'),(helper.wcGetMessageFromResourceBundle('POLICY_URI'),'PolicyURI'),(helper.wcGetMessageFromResourceBundle('ADMIN_USER'),'AdminUser'),(helper.wcGetMessageFromResourceBundle('RECIPIENT_KEY_ALIAS'),'RecipientKeyAlias')]
    nonStrAttrs = [(helper.wcGetMessageFromResourceBundle('CONNECTION_TIME_OUT'),'ConnectionTimeOut')]
    helper.customListConnections(appName,'RtcConnectionProvider',stringAttrs,impNonStrAttrsFunc,nonStrAttrs,verbose,name)
    helper.webcenterRestore()

def listIMPAdapters():
    helper.wcPrintMessage('IMP_ADAPTER_LIST')
    print '------------------'    
    print 'LCS'
    print '------------------'
    print 'OCS2007'
    print '------------------'

def listDefaultIMPConnection(appName,verbose=0,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionName = collabhandler.getCollabDefaultConnection(appName,'oracle.webcenter.collab.rtc')
    print '------------------'
    helper.wcPrintMessage('DEFAULT_CONNECTION', connectionName)
    print '------------------'
    if verbose:
        listIMPConnections(appName,1,connectionName,server,applicationVersion)
    helper.webcenterRestore()


def setIMPConnectionProperty (appName,name, key, value, secure=0,server='',applicationVersion=''):
    if secure:
        setSecureImpConnectionProperty(appName,name,key,value)
        return None
    helper.webcenterInitialize(server,applicationVersion)
    connectionType='RtcConnectionProvider'
    objs = jarray.array([key,value],Object)
    strs = jarray.array(['java.lang.String','java.lang.String'],String)
    connectionTypeStr=helper.wcGetMessageFromResourceBundle('IMP_CON')
    setArgs=[objs,strs,'addProperty',helper.printErrorInvokingAddProperty,helper.printAddPropertySuccess,key,connectionTypeStr]
    helper.editProperty(appName,name,connectionType,helper.setPropertyFunc,setArgs)
    helper.webcenterRestore()

def setSecureImpConnectionProperty(appName,name,key,value,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionType='RtcConnectionProvider'
    objs = jarray.array([key,value],Object)
    strs = jarray.array(['java.lang.String','java.lang.String'],String)
    connectionTypeStr=helper.wcGetMessageFromResourceBundle('IMP_CON')
    setArgs=[objs,strs,'addSecuredProperty',helper.printErrorInvokingAddProperty,helper.printAddPropertySuccess,key,connectionTypeStr]
    helper.editProperty(appName,name,connectionType,helper.setPropertyFunc,setArgs)
    helper.webcenterRestore()

def deleteIMPConnectionProperty (appName,name, key,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionType='RtcConnectionProvider'
    objs = jarray.array([key],Object)
    strs = jarray.array(['java.lang.String'],String)
    connectionTypeStr=helper.wcGetMessageFromResourceBundle('IMP_CON')
    deleteArgs=[objs,strs,'removeProperty',helper.printErrorInvokingRemoveProperty,helper.printRemovePropertySuccess,connectionTypeStr]
    helper.editProperty(appName,name,connectionType,helper.deletePropertyFunc,deleteArgs)
    helper.webcenterRestore()

# Sets the specified IMP Connection as the default connection in ADF IMP Config MBean
def setDefaultIMPConnection(appName,name,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    noError = 1
    connectionType='RtcConnectionProvider'
    connectionMBeans = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(connectionMBeans,appName)
    # Need the ADF Connections Object Name to search for the connection name
    if ADFConnObjName is None:
        noError=0
    if(not collabhandler.checkCollabConnFieldNotEmpty(name)):
        helper.wcPrintErrorMessage('INVALID_CONNECTION_NAME')
        noError=0
    if(not helper.connMBeanExists(ADFConnObjName,name,connectionType)):
        helper.webcenterCommandError()
        printNoImpConnection(name)
        noError=0
    if noError:
        collabhandler.setCollabDefaultConnection(appName,'oracle.webcenter.collab.rtc',name,server,applicationVersion)
    helper.webcenterRestore()

def setIMPServiceProperty(appName,property,value,server='',applicationVersion=''):
    collabhandler.addCollabServiceProperty(appName,'oracle.webcenter.collab.rtc',property,value,server,applicationVersion)

def removeIMPServiceProperty(appName,property,server='',applicationVersion=''):
    collabhandler.removeCollabServiceProperty(appName,'oracle.webcenter.collab.rtc',property,server,applicationVersion)

def listIMPServiceProperties(appName,server='',applicationVersion=''):
    collabhandler.listCollabServiceProperties(appName,'oracle.webcenter.collab.rtc',server,applicationVersion)
    
def createIMPExtAppConnection(appName, name, displayName='', server='',applicationVersion=''):
    extapphandler.createExtAppConnection(appName=appName,name=name,displayName=displayName,userFieldName='Username',pwdFieldName='Password',server=server,applicationVersion=applicationVersion)
    extapphandler.addExtAppField(appName=appName,name=name,fieldName='Account',displayToUser=1)    

# Helper functions
def impNonStrAttrsFunc(objName,nonStrAttrs):
    for item in nonStrAttrs:
        try:
            attrLabel=item[0]
            obj = ora_mbs.getAttribute(objName,item[1])
            if obj is None:
                attrValue='-1'
            else:
                attrValue=str(obj)
            print attrLabel+ ' ' +attrValue
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE',item[1])
    #Returns ComposteData[] which is then formatted
    try:
        addfields=ora_mbs.getAttribute(objName,'Properties')
        if addfields is not None:
            print helper.wcGetMessageFromResourceBundle('ADDITIONAL_PROPERTIES_MSG')+': '+formatImpFields(addfields)
    except Exception, ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
        helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','Properties')

#Rountine to format additional fields
def formatImpFields(addfields):
    #no additional fields
    fieldlen=len(addfields)
    if fieldlen==0:
        return helper.wcGetMessageFromResourceBundle('ADDITIONAL_PROPERTIES_NOT_SPECIFIED')
    #concatenate additional fields to render in list command
    formatStr='{'
    index=0
    for field in addfields:
        fieldname=field.get('key')
        fieldval=field.get('value')
        formatStr=formatStr+str(fieldname)+':'+str(fieldval)
        #add , only if there are more fields
        if (index<fieldlen-1):
            formatStr=formatStr+','
        index = index + 1

    formatStr=formatStr+'}'
    return formatStr


def printNoImpConnection(connectionName):
    helper.wcPrintErrorMessage('ERROR_NO_CONNECTION',connectionName)

def rtcCustomListConnections(appName,verbose):
    mbeanarray = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(mbeanarray,appName)
    if ADFConnObjName is None:
        return
    connectionType = 'RtcConnectionProvider'
    objNamesList = helper.getExistingConnObjNames(ADFConnObjName,connectionType)
    if objNamesList is None:
        helper.wcPrintErrorMessage('ERROR_NO_CONNECTION_TYPE',connectionType)
        return
    if len(objNamesList)<=0:
        helper.wcPrintErrorMessage('ERROR_NO_CONNECTION_TYPE',connectionType)
        return
    # list connections
    if len(objNamesList)>0:
        for objN in objNamesList:
            name = ora_mbs.getAttribute(objN,'ConnectionName')
            adapter = ''
            #if name is given we can get the adapter name and show specific attributes, otherwise we have to show all the attributes
            if(name != ''):
                try:
                    adapter = ora_mbs.getAttribute(objN,'AdapterName')
                except Exception, ex:
                    helper.wcPrintExceptionMessage(ex.getMessage())
                    helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','AdapterName')
                if (adapter == 'LCS'):
                    stringAttrs=[(helper.wcGetMessageFromResourceBundle('CON_NAME'),'ConnectionName'),(helper.wcGetMessageFromResourceBundle('BASE_CON_URL'),'BaseConnectionURL'),(helper.wcGetMessageFromResourceBundle('ADAPTER_NAME'),'AdapterName'),(helper.wcGetMessageFromResourceBundle('EXT_APP_ID'),'ExternalAppId'),(helper.wcGetMessageFromResourceBundle('LCS_POOL_NAME'),'PoolName')]
                elif (adapter == 'OCS2007'):
                    stringAttrs=[(helper.wcGetMessageFromResourceBundle('CON_NAME'),'ConnectionName'),(helper.wcGetMessageFromResourceBundle('BASE_CON_URL'),'BaseConnectionURL'),(helper.wcGetMessageFromResourceBundle('ADAPTER_NAME'),'AdapterName'),(helper.wcGetMessageFromResourceBundle('EXT_APP_ID'),'ExternalAppId'),(helper.wcGetMessageFromResourceBundle('USER_DOMAIN'),'UserDomain'),(helper.wcGetMessageFromResourceBundle('OCS_POOL_NAME'),'PoolName')]
                else:
                    stringAttrs=[(helper.wcGetMessageFromResourceBundle('CON_NAME'),'ConnectionName'),(helper.wcGetMessageFromResourceBundle('BASE_CON_URL'),'BaseConnectionURL'),(helper.wcGetMessageFromResourceBundle('ADAPTER_NAME'),'AdapterName'),(helper.wcGetMessageFromResourceBundle('EXT_APP_ID'),'ExternalAppId'),(helper.wcGetMessageFromResourceBundle('POLICY_URI'),'PolicyURI'),(helper.wcGetMessageFromResourceBundle('ADMIN_USER'),'AdminUser'),(helper.wcGetMessageFromResourceBundle('RECIPIENT_KEY_ALIAS'),'RecipientKeyAlias')]
            nonStrAttrs = [(helper.wcGetMessageFromResourceBundle('CONNECTION_TIME_OUT'),'ConnectionTimeOut')]
            helper.printName(appName,objN,connectionType,stringAttrs,verbose,impNonStrAttrsFunc,nonStrAttrs)

#Function to return imp objectname 
def getImpObjectName(appName, connectionName):
    mbeanarray = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(mbeanarray,appName)
    connObjName = helper.getConnObjName(ADFConnObjName,connectionName,'RtcConnectionProvider')
    return connObjName

def getImpConnectionAttribute(appName, connectionName,attributeType,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    attrVal = None
    try:
        objName = getImpObjectName(appName, connectionName)
        if objName is None :
            attrVal = None
        attrVal = ora_mbs.getAttribute(objName, attributeType)
        if attributeType == 'Properties':
           #format the additional fields
           attrVal = formatImpFields(attrVal)
    except Exception,ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
        helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE',attributeType)
    helper.webcenterRestore()
    return attrVal

def getDefaultImpConnection(appName,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionName = collabhandler.getCollabDefaultConnection(appName,'oracle.webcenter.collab.rtc')
    helper.webcenterRestore()    	
    return connectionName
