# Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved. 
# Caution: This file is part of the command scripting implementation. Do not edit or move
# this file because this may cause commands and scripts to fail. Do not
# try to reuse the logic in this file or keep copies of this file because this
# could cause your scripts to fail when you upgrade to a different version.
"""
This script holds all the functions for Webcenter Mail Connections.
@author Alexis Chan
"""
import ora_mbs
import javax.management as management
import jarray
from java.lang import Object
from java.lang import String
from java.lang import Exception
from javax.management import Attribute
import WebCenterHandlerHelper as helper
import CollabHandler as collabhandler
import ExtAppHandler as extapphandler
from javax.management import RuntimeMBeanException
from javax.management.openmbean import ArrayType
import re
# Code for detecting syntax error, especially missing colons
def mailCheck():
    helper.wcPrintMessage('FILE_CHECK_MESG')

def createMailConnection(appName,name, imapHost='', imapPort=0, smtpHost='', smtpPort=0, imapSecured=0, smtpSecured=0, appId='', timeout=-1,default=0,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionType='MailConnectionProvider'
    if((not collabhandler.checkCollabConnFieldNotEmpty(imapHost)) and (not collabhandler.checkCollabConnFieldNotEmpty(smtpHost))):
       helper.wcPrintErrorMessage('ERROR_MISSING_IMAP_SMTP_DETAILS')
       helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
       return None
    if((collabhandler.checkCollabConnFieldNotEmpty(imapHost) and (imapPort == 0)) or ((not collabhandler.checkCollabConnFieldNotEmpty(imapHost)) and (not (imapPort == 0)))):
       helper.wcPrintErrorMessage('ERROR_MISSING_HOST_PORT_DETAILS','IMAP')
       helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
       return None       
    if((collabhandler.checkCollabConnFieldNotEmpty(smtpHost) and (smtpPort == 0)) or ((not collabhandler.checkCollabConnFieldNotEmpty(smtpHost)) and (not (smtpPort == 0)))):
       helper.wcPrintErrorMessage('ERROR_MISSING_HOST_PORT_DETAILS','SMTP')
       helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
       return None
    if(not collabhandler.checkCollabConnFieldNotEmpty(appId)):
       helper.wcPrintErrorMessage('PARAMETER_MISSING', 'appId,Mail')
       helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
       return None	
    if(collabhandler.checkCollabConnFieldNotEmpty(appId)):
       if(not extapphandler.checkValidAppConnName(appName,appId,'ExtAppConnectionProvider',1)):
           helper.wcPrintErrorMessage('WRONG_EXT_APP',appId)
           helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
           return None
    userArg={'ImapHost':imapHost,'ImapPort':imapPort,'ImapSecured':imapSecured, 'SmtpHost':smtpHost, 'SmtpPort':smtpPort, 'SmtpSecured':smtpSecured, 'ExternalAppId':appId,'ConnectionTimeOut':timeout}
    connObj = helper.customCreateConnection(appName,name,connectionType,userArg)
    # set connection as default only if create connection succeeded
    if connObj is not None:
       if default==1:
           setDefaultMailConnection(appName,name,server,applicationVersion)
    helper.webcenterRestore()
    
    
    
def setMailConnection(appName, name, imapHost='OrAcLeMaIlWlStMaGiCkEyS', imapPort=0, smtpHost='OrAcLeMaIlWlStMaGiCkEyS', smtpPort=0, imapSecured='', smtpSecured='', appId='OrAcLeMaIlWlStMaGiCkEyS', default='', ldapHost='OrAcLeMaIlWlStMaGiCkEyS', ldapPort=0, ldapBaseDN='OrAcLeMaIlWlStMaGiCkEyS', ldapAdminUser='OrAcLeMaIlWlStMaGiCkEyS', ldapAdminPassword='OrAcLeMaIlWlStMaGiCkEyS', domain='OrAcLeMaIlWlStMaGiCkEyS', defaultUser='OrAcLeMaIlWlStMaGiCkEyS', ldapSecured='', timeout=-1,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    objname = getMailObjectName(appName, name)
    # appName, External App Id is mandatory for Mail
    if objname is None:
        helper.wcPrintErrorMessage('ERROR_NO_CONNECTION', name)
        helper.webcenterRestore()
        return

    if(imapHost == 'OrAcLeMaIlWlStMaGiCkEyS'):
        try:
            imapHost = ora_mbs.getAttribute(objname,'ImapHost')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','imapHost')

    if(smtpHost == 'OrAcLeMaIlWlStMaGiCkEyS'):
        try:
            smtpHost = ora_mbs.getAttribute(objname,'SmtpHost')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','smtpHost')

    if(ldapHost == 'OrAcLeMaIlWlStMaGiCkEyS'):
        try:
            ldapHost = ora_mbs.getAttribute(objname,'LdapHost')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','ldapHost')

    if(ldapBaseDN == 'OrAcLeMaIlWlStMaGiCkEyS'):
        try:
            ldapBaseDN = ora_mbs.getAttribute(objname,'LdapBaseDn')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','ldapBaseDN')

    if(ldapAdminUser == 'OrAcLeMaIlWlStMaGiCkEyS'):
        try:
            ldapAdminUser = ora_mbs.getAttribute(objname,'LdapAdminUsername')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','ldapAdminUser')

    if(ldapAdminPassword == 'OrAcLeMaIlWlStMaGiCkEyS'):
        try:
            ldapAdminPassword = ora_mbs.getAttribute(objname,'LdapAdminPassword')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','ldapAdminPassword')

    if(defaultUser == 'OrAcLeMaIlWlStMaGiCkEyS'):
        try:
            defaultUser = ora_mbs.getAttribute(objname,'LdapDefaultUser')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','defaultUser')

    if(domain == 'OrAcLeMaIlWlStMaGiCkEyS'):
        try:
            domain = ora_mbs.getAttribute(objname,'LdapDomain')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','domain')

    if(appId == 'OrAcLeMaIlWlStMaGiCkEyS'):
        try:
            appId = ora_mbs.getAttribute(objname,'ExternalAppId')
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','ExternalAppId')

    if(appId != 'OrAcLeImPwLsTmAgIcKeYs' and appId != '' and appId is not None):
        if(not extapphandler.checkValidAppConnName(appName,appId,'ExtAppConnectionProvider',1)):
            helper.wcPrintMessage('WRONG_EXT_APP',appId)
            helper.wcPrintErrorMessage('ERROR_SET_CONNECTION',name)
            return None

    if(imapPort == 0):
        imapPort= ora_mbs.getAttribute(objname,'ImapPort')

    if(smtpPort == 0):
        smtpPort = ora_mbs.getAttribute(objname,'SmtpPort')

    if(ldapPort == 0):
        ldapPort = ora_mbs.getAttribute(objname,'LdapPort')

    if(imapSecured == ''):
        imapSecured = ora_mbs.getAttribute(objname,'ImapSecured')

    if(smtpSecured == ''):
        smtpSecured = ora_mbs.getAttribute(objname,'SmtpSecured')

    if(ldapSecured == ''):
        ldapSecured = ora_mbs.getAttribute(objname,'LdapSecured')

    if((not collabhandler.checkCollabConnFieldNotEmpty(imapHost)) and (not collabhandler.checkCollabConnFieldNotEmpty(smtpHost))):
       helper.wcPrintErrorMessage('ERROR_MISSING_IMAP_SMTP_DETAILS')
       helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
       return None
    if((collabhandler.checkCollabConnFieldNotEmpty(imapHost) and (imapPort == 0)) or ((not collabhandler.checkCollabConnFieldNotEmpty(imapHost)) and (not (imapPort == 0)))):
       helper.wcPrintErrorMessage('ERROR_MISSING_HOST_PORT_DETAILS','IMAP')
       helper.wcPrintErrorMessage('ERROR_SET_CONNECTION',name)
       return None
    if((collabhandler.checkCollabConnFieldNotEmpty(smtpHost) and (smtpPort == 0)) or ((not collabhandler.checkCollabConnFieldNotEmpty(smtpHost)) and (not (smtpPort == 0)))):
       helper.wcPrintErrorMessage('ERROR_MISSING_HOST_PORT_DETAILS','SMTP')
       helper.wcPrintErrorMessage('ERROR_SET_CONNECTION',name)
       return None

    userArg={'LdapDomain':domain,'LdapDefaultUser':defaultUser,'ImapHost':imapHost,'ImapPort':imapPort,'ImapSecured':imapSecured,'SmtpHost':smtpHost, 'SmtpPort':smtpPort, 'SmtpSecured':smtpSecured, 'ExternalAppId':appId,'LdapHost':ldapHost, 'LdapPort':ldapPort, 'LdapBaseDn':ldapBaseDN, 'LdapAdminUsername':ldapAdminUser, 'LdapAdminPassword':ldapAdminPassword, 'LdapSecured':ldapSecured,'ConnectionTimeOut':timeout}
    helper.customSetConnection(appName,name,'MailConnectionProvider',userArg,0)
    if(default is not None and default != ''):
      if default==1:
         setDefaultMailConnection(appName,name,server,applicationVersion)
      else:
          connectionName = collabhandler.getCollabDefaultConnection(appName,'oracle.webcenter.collab.mail')
          if connectionName == name:
            removeMailServiceProperty(appName,'selected.connection',server,applicationVersion)
    helper.webcenterRestore()
    
    
    
def listMailConnections(appName,verbose=0,name='',server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    stringAttrs=[(helper.wcGetMessageFromResourceBundle('CON_NAME'),'ConnectionName'),(helper.wcGetMessageFromResourceBundle('LDAP_DOMAIN'),'LdapDomain'),(helper.wcGetMessageFromResourceBundle('LDAP_DEF_USER'),'LdapDefaultUser'),(helper.wcGetMessageFromResourceBundle('IMAP_HOST'),'ImapHost'),(helper.wcGetMessageFromResourceBundle('SMTP_HOST'),'SmtpHost'),(helper.wcGetMessageFromResourceBundle('LDAP_HOST'),'LdapHost'),(helper.wcGetMessageFromResourceBundle('LDAP_BASE_DN'),'LdapBaseDn'), (helper.wcGetMessageFromResourceBundle('LDAP_ADMIN_USER'),'LdapAdminUsername'), (helper.wcGetMessageFromResourceBundle('EXT_APP_ID'),'ExternalAppId')]
    nonStrAttrs = [(helper.wcGetMessageFromResourceBundle('IMAP_PORT'),'ImapPort'), (helper.wcGetMessageFromResourceBundle('IMAP_SEC'),'ImapSecured'), (helper.wcGetMessageFromResourceBundle('SMTP_PORT'),'SmtpPort'), (helper.wcGetMessageFromResourceBundle('SMTP_SEC'),'SmtpSecured'),(helper.wcGetMessageFromResourceBundle('LDAP_PORT'),'LdapPort'), (helper.wcGetMessageFromResourceBundle('LDAP_SEC'),'LdapSecured'),(helper.wcGetMessageFromResourceBundle('CONNECTION_TIME_OUT'),'ConnectionTimeOut')]
    helper.customListConnections(appName,'MailConnectionProvider',stringAttrs,mailNonStrAttrsFunc,nonStrAttrs,verbose,name)
    helper.webcenterRestore()
    
 
def listDefaultMailConnection(appName,verbose=0,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionName = collabhandler.getCollabDefaultConnection(appName,'oracle.webcenter.collab.mail')
    print '------------------'
    helper.wcPrintMessage('DEFAULT_CONNECTION', connectionName)
    print '------------------'
    if verbose:
        listMailConnections(appName,1,connectionName,server,applicationVersion)
    helper.webcenterRestore()
    
    
    
def setMailConnectionProperty (appName,name,key,value,secure=0,server='',applicationVersion=''):
    if secure:
   	setSecureMailConnectionProperty(appName,name,key,value,server,applicationVersion)
	return None
    helper.webcenterInitialize(server,applicationVersion)
    connectionType='MailConnectionProvider'
    objs = jarray.array([key,value],Object)
    strs = jarray.array(['java.lang.String','java.lang.String'],String)
    connectionTypeStr=helper.wcGetMessageFromResourceBundle('MAIL_CON')
    setArgs=[objs,strs,'addProperty',helper.printErrorInvokingAddProperty,helper.printAddPropertySuccess,key,connectionTypeStr]
    helper.editProperty(appName,name,connectionType,helper.setPropertyFunc,setArgs)
    helper.webcenterRestore()

def setSecureMailConnectionProperty(appName,name,key,value,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionType='MailConnectionProvider'
    objs = jarray.array([key,value],Object)
    strs = jarray.array(['java.lang.String','java.lang.String'],String)
    connectionTypeStr=helper.wcGetMessageFromResourceBundle('MAIL_CON')
    setArgs=[objs,strs,'addSecuredProperty',helper.printErrorInvokingAddProperty,helper.printAddPropertySuccess,key,connectionTypeStr]
    helper.editProperty(appName,name,connectionType,helper.setPropertyFunc,setArgs)
    helper.webcenterRestore()



def deleteMailConnectionProperty (appName,name, key,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionType='MailConnectionProvider'
    objs = jarray.array([key],Object)
    strs = jarray.array(['java.lang.String'],String)
    connectionTypeStr=helper.wcGetMessageFromResourceBundle('MAIL_CON')
    deleteArgs=[objs,strs,'removeProperty',helper.printErrorInvokingRemoveProperty,helper.printRemovePropertySuccess,connectionTypeStr]
    helper.editProperty(appName,name,connectionType,helper.deletePropertyFunc,deleteArgs)
    helper.webcenterRestore()




# Sets the specified MAIL Connection as the default connection in ADF MAIL Config MBean
def setDefaultMailConnection(appName,name,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    noError = 1
    connectionType='MailConnectionProvider'
    connectionMBeans = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(connectionMBeans,appName)
    # Need the ADF Connections Object Name to search for the connection name
    if ADFConnObjName is None:
        noError=0
    if(not collabhandler.checkCollabConnFieldNotEmpty(name)):
        helper.wcPrintErrorMessage('INVALID_CONNECTION_NAME')
        noError=0
    if(not helper.connMBeanExists(ADFConnObjName,name,connectionType)):
        helper.webcenterCommandError()
        printNoMailConnection(name)
        noError=0
    if noError:
        collabhandler.setCollabDefaultConnection(appName,'oracle.webcenter.collab.mail',name,server,applicationVersion)
    helper.webcenterRestore()

def setMailServiceProperty(appName,property,value,server='',applicationVersion=''):
    collabhandler.addCollabServiceProperty(appName,'oracle.webcenter.collab.mail',property,value,server,applicationVersion)

def removeMailServiceProperty(appName,property,server='',applicationVersion=''):
    collabhandler.removeCollabServiceProperty(appName,'oracle.webcenter.collab.mail',property,server,applicationVersion)

def listMailServiceProperties(appName,server='',applicationVersion=''):
    collabhandler.listCollabServiceProperties(appName,'oracle.webcenter.collab.mail',server,applicationVersion)
    
def createMailExtAppConnection(appName, name, displayName='', server='',applicationVersion=''):
    extapphandler.createExtAppConnection(appName=appName,name=name,displayName=displayName,server=server,applicationVersion=applicationVersion)
    extapphandler.addExtAppField(appName=appName,name=name,fieldName='Email Address',displayToUser=1)
    extapphandler.addExtAppField(appName=appName,name=name,fieldName='Your Name',displayToUser=1)
    extapphandler.addExtAppField(appName=appName,name=name,fieldName='Reply-To Address',displayToUser=1)
    
# Helper functions
def mailNonStrAttrsFunc(objName,nonStrAttrs):
    for item in nonStrAttrs:
        try:
            attrLabel=item[0]
            obj = ora_mbs.getAttribute(objName,item[1])
            if obj is None:
                attrValue='-1'
            else:
                attrValue=str(obj)
            print attrLabel+' '+attrValue
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE',item[1])
    #Returns ComposteData[] which is then formatted
    try:
	addfields=ora_mbs.getAttribute(objName,'Properties')
	if addfields is not None:
	   print helper.wcGetMessageFromResourceBundle('ADDITIONAL_PROPERTIES_MSG')+': '+formatMailFields(addfields)
    except Exception, ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
	helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','Properties')

#Rountine to format additional fields
def formatMailFields(addfields):
    #no additional fields
    fieldlen=len(addfields)
    if fieldlen==0:
        return helper.wcGetMessageFromResourceBundle('ADDITIONAL_PROPERTIES_NOT_SPECIFIED')
    #concatenate additional fields to render in list command
    formatStr='{'
    index=0
    for field in addfields:
        fieldname=field.get('key')
        fieldval=field.get('value')
        formatStr=formatStr+str(fieldname)+': '+str(fieldval)
        #add , only if there are more fields
        if (index<fieldlen-1):
            formatStr=formatStr+','
        index = index + 1

    formatStr=formatStr+'}'
    return formatStr

def printNoMailConnection(connectionName):
    helper.wcPrintErrorMessage('ERROR_NO_CONNECTION',connectionName)

#Function to return mail objectname 
def getMailObjectName(appName, connectionName):
    mbeanarray = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(mbeanarray,appName)
    connObjName = helper.getConnObjName(ADFConnObjName,connectionName,'MailConnectionProvider')
    return connObjName

def getMailConnectionAttribute(appName, connectionName, attributeType, server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    attrVal = None
    try:
        objName = getMailObjectName(appName, connectionName)
        if objName is None :
            attrVal = None
        attrVal = ora_mbs.getAttribute(objName, attributeType)
        if attributeType == 'Properties':
           #format the additional fields
           attrVal = formatMailFields(attrVal)
    except Exception,ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
        helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE',attributeType)
    helper.webcenterRestore()
    return attrVal

def getDefaultMailConnection(appName,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionName = collabhandler.getCollabDefaultConnection(appName,'oracle.webcenter.collab.mail')
    helper.webcenterRestore()    	
    return connectionName

