# Copyright (c) 2010, 2013, Oracle and/or its affiliates. All rights reserved. 
"""
This script holds the commands to get/set WebCenter Openusage connection.
@author Vasif Shaikh
"""
import ora_mbs
import javax.management as management
import jarray
from java.lang import Object
from java.lang import String
from java.lang import Boolean
from java.lang import Exception
from javax.management import Attribute
from javax.management import ObjectName
import WebCenterHandlerHelper as helper
import LifecycleHandler as lifecyclehandler

# Code for detecting syntax error, especially missing colons
def openusageCheck():
    helper.wcPrintMessage('FILE_CHECK_MESG')

#Set the connection properties for openusage in Adf Openusage Config MBean.
def setDefaultAnalyticsConnection(appName, name, server='',applicationVersion=''):
    #get the connection
    connectionMBeans = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(connectionMBeans,appName)

    if ADFConnObjName is None:
        return 'false'

    #get corresponding connection name.
    if name!= '':
        if not helper.connMBeanExists(ADFConnObjName, name, 'OpenusageConnectionProvider'):
            _printErrorNoOpenusageConnection(name)
            return 'false'
    
    #set the connection name 
    try:
        openusageConfigObjName = _getOpenusageConfigObjName(appName)
        if openusageConfigObjName is None:
            return 'false'

        ora_mbs.setAttribute(openusageConfigObjName, Attribute('ConnectionName', name))
        
        helper.customSaveConfig(appName)
        if name!='':
            _printSetOpenusageConnection(name)
        else:
            _printResetOpenusageConnection(name)
    except Exception,ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
        _printErrorSettingConnection(name)
        customRefreshConfig(appName)

def getDefaultAnalyticsConnection(appName,server='',applicationVersion=''):
    helper.webcenterInitialize(server, applicationVersion)
    OpenusageConfigObjName = _getOpenusageConfigObjName(appName)
    if(OpenusageConfigObjName is None):
        helper.webcenterRestore()
        return
    try:
        connName =  _getOpenusageConfigAttr(OpenusageConfigObjName, 'ConnectionName')
        if(connName is None or connName == ''):
            helper.printName(appName, OpenusageConfigObjName, 'OpenusageConnectionProvider', None, 0, None, None)
            helper.webcenterRestore()
            return
        connObjName = _getOpenusageConnectionObjectName(appName, _getOpenusageConfigAttr(OpenusageConfigObjName, 'ConnectionName'))
        stringAttrs = [(helper.wcGetMessageFromResourceBundle('OU_ATTR_CLUSTERNAME'),'ClusterName')
                                    ]
        nonStringAttrs = [(helper.wcGetMessageFromResourceBundle('OU_ATTR_PORT'),'CollectorPort'), \
                                    (helper.wcGetMessageFromResourceBundle('OU_ATTR_TIMEOUT'),'TimeOut'), \
                                    (helper.wcGetMessageFromResourceBundle('OU_ATTR_UNICAST'),'Unicast'), \
                                    (helper.wcGetMessageFromResourceBundle('OU_ATTR_ENABLED'),'Enabled')
                                    ]
        helper.printName(appName,connObjName,'OpenusageConnectionProvider',stringAttrs,1,printNonStrAttrsFunc,nonStringAttrs)
    except Exception,ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
        _printErrorGettingConnection()
    helper.webcenterRestore()


#Return the openusage config object name
def _getOpenusageConfigObjName(appName):
    openusageConfigObjName = helper.findOrCreateConfigObjName(appName,'oracle.adf.mbean.share.config.runtime.webcenter.openusage.AdfOpenusageConfig')
    if(openusageConfigObjName is None):
        helper.wcPrintErrorMessage('OPENUSAGE_ERROR_GETTING_CONNECTION')
    return openusageConfigObjName

# Get attribute value in AdfOpenusageConfig
def _getOpenusageConfigAttr(objName, name):
    try:
        obj = ora_mbs.getAttribute(objName, name)
        if obj is None:
          return ''
        else:
          return obj
    except Exception, ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
        helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE', name)

#Messages for Openusage Service
def _printSetOpenusageConnection(name):
    helper.wcPrintMessage('OPENUSAGE_SET_CONNECTION', name)

def _printResetOpenusageConnection(name):
    helper.wcPrintMessage('OPENUSAGE_RESET_CONNECTION', name)

def _printSuccessGettingConnection():
    helper.wcPrintMessage('OPENUSAGE_SUCCESS_GETTING_CONNECTION')

def _printErrorGettingConnection():     
    helper.wcPrintErrorMessage('OPENUSAGE_ERROR_GETTING_CONNECTION')

def _printErrorSettingConnection():
    helper.wcPrintErrorMessage('OPENUSAGE_ERROR_SETTING_CONNECTION', name)

def _printErrorNoOpenusageConnection(name):
    helper.wcPrintErrorMessage('OPENUSAGE_ERROR_NO_NAME_TYPE', name)

###############################Connection Mbean Section########################
def createAnalyticsConnection(appName, connectionName, isUnicast=1, collectorHost='localhost',  clusterName='localhost', collectorPort=31314, isEnabled='true', timeout=30, default=0, server='',applicationVersion=''):
    # Constants
    connectionType = 'OpenusageConnectionProvider'

    mbeanarray = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(mbeanarray,appName)
    if ADFConnObjName is None:
        return

    # Check for a valid connection name
    if(connectionName is None or connectionName == ''):
        helper.wcPrintErrorMessage('INVALID_CONNECTION_NAME')
        return

    # If a Connection MBean with that name already exists, abort the creation.
    if helper.connMBeanExists(ADFConnObjName,connectionName,connectionType):
        helper.wcPrintMessage('ERROR_CONNECTION_EXISTS',connectionName)
        return

    # Initialize WebCenter
    clusterOrHostName = collectorHost
    if isUnicast == 0:
        clusterOrHostName = clusterName
    conArgs = {'ClusterName':clusterOrHostName, 'CollectorPort':collectorPort, 'Enabled':isEnabled, 'TimeOut':timeout, 'Unicast':isUnicast}
    _createNewOpenusageConnection(appName, connectionName, conArgs)
    _getOpenusageConnectionList(appName)
    if default == 1:
        setDefaultAnalyticsConnection(appName, connectionName, server, applicationVersion)
    
 # Modify a File System specific connection
def setAnalyticsConnection(appName, connectionName, isUnicast=None, collectorHost=None, clusterName=None, collectorPort=None, isEnabled=None, timeout=None, default=None, server='',applicationVersion=''):
    helper.webcenterInitialize(server, applicationVersion)
    objName = _getOpenusageConnectionObjectName(appName, connectionName)
    if objName is None:
        _printErrorNoOpenusageConnection(connectionName)
        return
    if collectorHost is not None and clusterName is not None:
        helper.wcPrintMessage('OPENUSAGE_CANNOT_SPECIFY_BOTH_CLUSTER_AND_HOST')
        return
    needRestart = 0
    try:
        try:
            if isUnicast is not None:
                ora_mbs.setAttribute(objName,  Attribute('Unicast', isUnicast))
                needRestart = 1
            if collectorHost is not None:
                ora_mbs.setAttribute(objName,  Attribute('ClusterName', collectorHost))
                needRestart = 1
            if clusterName is not None:
                ora_mbs.setAttribute(objName,  Attribute('ClusterName', clusterName))
                needRestart = 1
            if collectorPort is not None:
                ora_mbs.setAttribute(objName,  Attribute('CollectorPort', collectorPort))
                needRestart = 1
            if isEnabled is not None:
                ora_mbs.setAttribute(objName,  Attribute('Enabled', isEnabled))
                needRestart = 1
            if timeout is not None:
                ora_mbs.setAttribute(objName,  Attribute('TimeOut', timeout))
                needRestart = 1
            if needRestart == 1:
                helper.customSave(appName)
                helper.wcPrintMessage('INFORM_NEED_RESTART') 
            if default is not None:
                setDefaultAnalyticsConnection(appName, connectionName, server, applicationVersion)
            
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.printStackTrace())
            return
    finally:
        helper.webcenterRestore()

# List connections that exists for openusage connection type
def listAnalyticsConnections(appName,server='',applicationVersion=''):
    helper.webcenterInitialize(server, applicationVersion)
    _getOpenusageConnectionList(appName)    
    helper.webcenterRestore()
# Generic code for creating a Openusage Connection
def _createNewOpenusageConnection(appName, name, conArgs):
    # Constants
    connectionType = 'OpenusageConnectionProvider'

    mbeanarray = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(mbeanarray,appName)
    if ADFConnObjName is None:
        return
    else:
        objs = jarray.array([String(connectionType),String(name)],Object)
        strs = jarray.array(['java.lang.String','java.lang.String'],String)
        try:
            connObjName = ora_mbs.invoke(ADFConnObjName,'createConnection',objs,strs)
            objNameStr = connObjName.toString()
            # Set the main connection specific attributes
            exFromSet = _setOpenusageArgs(connObjName,conArgs)
            if exFromSet is not None:
                raise exFromSet
            helper.customSave(appName)
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
            helper.customRefresh(appName)
            return

    if helper.debugIsEnabled():
        print objNameStr

# Generic code for listing Openusage connections
def _getOpenusageConnectionList(appName):
    mbeanarray = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(mbeanarray,appName)
    if ADFConnObjName is None:
        helper.wcPrintMessage('NONE')
        return
    objs = jarray.array([String('OpenusageConnectionProvider')],Object)
    strs = jarray.array(['java.lang.String'],String)
    try:
        connObjNameArray = ora_mbs.invoke(ADFConnObjName,'listConnectionMBeans',objs,strs)
        stringAttrs = [(helper.wcGetMessageFromResourceBundle('OU_ATTR_CLUSTERNAME'),'ClusterName')
                                    ]
        nonStringAttrs = [(helper.wcGetMessageFromResourceBundle('OU_ATTR_PORT'),'CollectorPort'), \
                                    (helper.wcGetMessageFromResourceBundle('OU_ATTR_TIMEOUT'),'TimeOut'), \
                                    (helper.wcGetMessageFromResourceBundle('OU_ATTR_UNICAST'),'Unicast'), \
                                    (helper.wcGetMessageFromResourceBundle('OU_ATTR_ENABLED'),'Enabled')
                                    ]
        for connObjName in connObjNameArray:
            helper.printName(appName,connObjName,'OpenusageConnectionProvider',stringAttrs,1,printNonStrAttrsFunc,nonStringAttrs)        
    except Exception, ex:
        helper.wcPrintExceptionMessage(ex.printStackTrace())

def printNonStrAttrsFunc(objName, nonStrAttrs):
    if nonStrAttrs is None:
        return;

    for item in nonStrAttrs:
        try:
            attrLabel=item[0]
            obj = ora_mbs.getAttribute(objName,item[1])
            if obj is None:
                attrValue='not set'
            else:
                attrValue=str(obj)
                if(attrLabel == helper.wcGetMessageFromResourceBundle('OU_ATTR_ENABLED')): 
                    attrValue=_convertToBoolean(attrValue)
                if(attrLabel == helper.wcGetMessageFromResourceBundle('OU_ATTR_UNICAST')):
                    attrValue=_convertToBoolean(attrValue)
            print attrLabel+ ' ' +attrValue
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.printStackTrace())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE',item[1])  
            
def _convertToBoolean(val):
    if(val == '1'):
        return 'true'
    if(val == '0'):
        return 'false'
    return val
   
# Generic code for listing Openusage connections
def _setOpenusageConnectionArgs(appName, name, args): 
    objName = _getOpenusageConnectionObjectName(appName, name)
    if objName is None:
        _printErrorNoOpenusageConnection(name)
        return
    try:
        exFromArgs =_setOpenusageArgs(objName, args)
        if exFromArgs is None:
            helper.customSave(appName)
            helper.wcPrintMessage('INFORM_NEED_RESTART')
        else:
            raise exFromArgs
    except Exception, ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
        customRefresh(appName)     
   
   
 #Function to return openusage connection objectname 
def _getOpenusageConnectionObjectName(appName, connectionName):
    mbeanarray = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(mbeanarray,appName)
    connObjName = helper.getConnObjName(ADFConnObjName,connectionName,'OpenusageConnectionProvider')
    return connObjName 
    
# Set attributes on a connection (or sub-connection)
def _setOpenusageArgs(objName,args):
    for arg in args.items():
        try:
            ora_mbs.setAttribute(objName,Attribute(arg[0],arg[1]))
        except Exception, ex:            
            helper.wcPrintErrorMessage('ERROR_SET_ATTRIBUTE',arg[0])
            return ex
    return None
    
def printSuccesfulCreation(connName):
    helper.wcPrintMessage('OPENUSAGE_CONNECTION_CREATION_SUCCESS', connName)

def printSuccesfulSet(connectionName):
    helper.wcPrintMessage('OPENUSAGE_CONNECTION_SET_SUCCESS', connectionName)

def getOpenusageConnectionAttribute(appName, connectionName, attributeType,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    OpenusageConfigObjName = _getOpenusageConfigObjName(appName)
    if(OpenusageConfigObjName is None):
        helper.webcenterRestore()
        return
    connObjName = _getOpenusageConnectionObjectName(appName, connectionName)
    helper.webcenterRestore()
    return _getOpenusageConfigAttr(connObjName, attributeType)

def getDefaultAnalyticsCollectorConnection(appName, server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    OpenusageConfigObjName = _getOpenusageConfigObjName(appName)
    if(OpenusageConfigObjName is None):
        helper.webcenterRestore()
        return
    try:
        connName =  _getOpenusageConfigAttr(OpenusageConfigObjName, 'ConnectionName')
        if(connName is None or connName == ''):
            helper.printName(appName, OpenusageConfigObjName, 'OpenusageConnectionProvider', None, 0, None, None)
            helper.webcenterRestore()
            return
        helper.webcenterRestore()
        return connName
    except Exception,ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
        _printErrorGettingConnection() 

