# Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved. 
# Caution: This file is part of the command scripting implementation. Do not edit or move
# this file because this may cause commands and scripts to fail. Do not
# try to reuse the logic in this file or keep copies of this file because this
# could cause your scripts to fail when you upgrade to a different version.

"""
This script holds all the functions for Webcenter Personal Event Connections.
@author Alexis Chan
"""
import ora_mbs
import javax.management as management
import jarray
from java.lang import Object
from java.lang import String
from java.lang import Exception
from javax.management import Attribute
import WebCenterHandlerHelper as helper
import CollabHandler as collabhandler
import ExtAppHandler as extapphandler
from javax.management import RuntimeMBeanException
from javax.management.openmbean import ArrayType
import re

# Code for detecting syntax error, especially missing colons
def peCheck():
    helper.wcPrintMessage('FILE_CHECK_MESG')

def createPersonalEventConnection(appName,name,webServiceUrl,adapterName,appId,default=0,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionType='WebCenterPersonalEventConnectionProvider'
    if(not collabhandler.checkCollabConnFieldNotEmpty(name)):
       helper.wcPrintErrorMessage('PARAMETER_MISSING', 'name,Personal Events')
       helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
       helper.webcenterRestore()
       return None
    if(not collabhandler.checkCollabConnFieldNotEmpty(webServiceUrl)):
       helper.wcPrintErrorMessage('PARAMETER_MISSING', 'webServiceUrl,Personal Events')
       helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
       helper.webcenterRestore()
       return None
    if(not collabhandler.checkCollabConnFieldNotEmpty(adapterName)):
       helper.wcPrintErrorMessage('PARAMETER_MISSING', 'adapterName,Personal Events')
       helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
       helper.webcenterRestore()
       return None
    if(not collabhandler.checkCollabConnFieldNotEmpty(appId)):
       helper.wcPrintErrorMessage('PARAMETER_MISSING', 'appId,Personal Events')
       helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION',name)
       helper.webcenterRestore()
       return None
    if not adapterName in ('MSEx2007', 'MSEx2003'):
       helper.wcPrintErrorMessage('WRONG_PEVENT_ADAPTER_NAME');
       helper.wcPrintErrorMessage('ERROR_CREATE_CONNECTION', name)
       helper.webcenterRestore()
       return None

    userArg={'SiteBaseUrl':webServiceUrl,'WebServiceUrl':webServiceUrl,'AdapterName':adapterName,'ExternalAppId':appId}
    helper.customCreateConnection(appName,name,connectionType,userArg)
    if default:
        setDefaultPersonalEventConnection(appName, name,server,applicationVersion)
    helper.webcenterRestore()
    
def setPersonalEventConnection(appName,name,webServiceUrl='',adapterName='',appId='',default=None,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    if(not collabhandler.checkCollabConnFieldNotEmpty(name)):
       helper.wcPrintErrorMessage('PARAMETER_MISSING', 'name,Personal Events')
       helper.wcPrintErrorMessage('ERROR_SET_CONNECTION',name)
       helper.webcenterRestore()
       return None
    connObjName = getPersonalEventObjectName(appName,name)
    if connObjName is not None:
       oldWebServiceUrl = ora_mbs.getAttribute(connObjName, 'WebServiceUrl')
       oldAdapterName = ora_mbs.getAttribute(connObjName, 'AdapterName')
       oldAppId = ora_mbs.getAttribute(connObjName, 'ExternalAppId')
    else:
       oldWebServiceUrl = None
       oldAdapterName = None
       oldAppId = None
    if extapphandler.isEmpty(webServiceUrl):
        webServiceUrl = oldWebServiceUrl
    if extapphandler.isEmpty(adapterName):
        adapterName = oldAdapterName
    if extapphandler.isEmpty(appId):
        appId = oldAppId
    userArg={'SiteBaseUrl':webServiceUrl,'WebServiceUrl':webServiceUrl,'AdapterName':adapterName,'ExternalAppId':appId}
    helper.customSetConnection(appName,name,'WebCenterPersonalEventConnectionProvider',userArg,0)
    if default==1:
       setDefaultPersonalEventConnection(appName, name,server,applicationVersion)
    else:
      if default==0:
         connectionName = getDefaultPersonalEventsConnection(appName,server,applicationVersion)
         if connectionName == name:
              removePersonalEventsServiceProperty(appName,'selected.connection',server,applicationVersion)
    helper.webcenterRestore()

def listPersonalEventConnections(appName,verbose=0,name='',server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    stringAttrs=[(helper.wcGetMessageFromResourceBundle('PES_LABEL_CONNECTION_NAME'),'ConnectionName'), \
                 (helper.wcGetMessageFromResourceBundle('PES_LABEL_WEB_SERVICE_URL'),'WebServiceUrl'), \
                 (helper.wcGetMessageFromResourceBundle('PES_LABEL_ADAPTER_NAME'),'AdapterName'), \
                 (helper.wcGetMessageFromResourceBundle('PES_LABEL_EXTERNAL_APPLICATION_ID'),'ExternalAppId')]
    nonStrAttrs = None
    helper.customListConnections(appName,'WebCenterPersonalEventConnectionProvider',stringAttrs,peNonStrAttrsFunc,nonStrAttrs,verbose,name)
    listDefaultPersonalEventConnection(appName,server,applicationVersion)
    helper.webcenterRestore()

def setDefaultPersonalEventConnection(appName, connectionName,server='',applicationVersion=''):
    collabhandler.setCollabDefaultConnection(appName, 'oracle.webcenter.collab.calendar.personal', connectionName,server,applicationVersion)

def removePersonalEventsServiceProperty(appName,property,server='',applicationVersion=''):
    collabhandler.removeCollabServiceProperty(appName,'oracle.webcenter.collab.calendar.personal',property,server,applicationVersion)

def getDefaultPersonalEventsConnection(appName, server='',applicationVersion=''):
    return collabhandler.getCollabDefaultConnection(appName,'oracle.webcenter.collab.calendar.personal')

def listDefaultPersonalEventConnection(appName,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    print '------------------'
    helper.wcPrintMessage('DEFAULT_CONNECTION', getDefaultPersonalEventsConnection(appName,server,applicationVersion))
    print '------------------'
    helper.webcenterRestore()

#Function to return connection objectname 
def getPersonalEventObjectName(appName, connectionName):
    mbeanarray = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(mbeanarray,appName)
    connObjName = helper.getConnObjName(ADFConnObjName,connectionName,'WebCenterPersonalEventConnectionProvider')
    return connObjName

# Helper functions
def peNonStrAttrsFunc(objName,nonStrAttrs):
    pass


def getPersonalEventConnectionAttribute(appName, connectionName, attributeType,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    attrVal = None
    try:
        objName = getPersonalEventObjectName(appName, connectionName)
        if objName is None :
            attrVal = None
        attrVal = ora_mbs.getAttribute(objName, attributeType)
    except Exception,ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
        helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE',attributeType)
    helper.webcenterRestore()
    return attrVal
