# Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved. 
# Caution: This file is part of the command scripting implementation. Do not edit or move
# this file because this may cause commands and scripts to fail. Do not
# try to reuse the logic in this file or keep copies of this file because this
# could cause your scripts to fail when you upgrade to a different version.
"""
This script holds all the functions for Webcenter Search Enterprise Service Connections.
@author Chung Cheng
"""
import ora_mbs
import javax.management as management
import jarray
from java.lang import Object
from java.lang import String
from java.lang import Long
from java.lang import Integer
from java.lang import Boolean
from java.lang import Exception
from javax.management import Attribute
from javax.management import ObjectName
import WebCenterHandlerHelper as helper


# Code for detecting syntax error, especially missing colons
def sesCheck():
    helper.wcPrintMessage('FILE_CHECK_MESG')

def createFederationTrustedEntity(appName, sesUrl, sesSchema, sesPassword, entityName, entityPassword,  desc, server='', applicationVersion='' ):
    helper.webcenterInitialize(server,applicationVersion)
    
    constructFederationTrustedEntity(appName, sesUrl, sesSchema, sesPassword, entityName, entityPassword, Boolean.FALSE, '', desc)
    
    helper.webcenterRestore()

#verbose not implemented yet
def listDiscussionsCrawler(appName, sesUrl, sesSchema, sesPassword, host, port, verbose=0,  server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
   
    forumName = constructSourceName(appName, host, port, 'forums')
    threadName = constructSourceName(appName, host, port, 'threads')
    messageName = constructSourceName(appName, host, port, 'messages')
    announceName = constructSourceName(appName, host, port, 'announcements')
    ##Call Exists for both sources
    forumExists = sourceExists(appName, sesUrl, sesSchema, sesPassword, forumName)
    threadExists = sourceExists(appName, sesUrl, sesSchema, sesPassword, threadName)
    messageExists = sourceExists(appName, sesUrl, sesSchema, sesPassword, messageName)
    announceExists = sourceExists(appName, sesUrl, sesSchema, sesPassword, announceName)

    print '----------------'
    #Needs Translation
    helper.wcPrintMessage('DISCUSSIONS_CRAWLERS_TITLE')
    print '----------------'
    print ''
    
    
    if forumExists:
        print forumName
    if threadExists:
        print threadName
    if messageExists:
        print messageName    
    if announceExists:
        print announceName    

    print ''

    helper.webcenterRestore()
    
def startDiscussionsCrawler(appName, sesUrl, sesSchema, sesPassword, host, port,  server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    
    scheduleName = constructSourceName(appName, host, port, 'discussions')

    ##helper method for calling mbean
    startSchedule(appName, sesUrl, sesSchema, sesPassword, scheduleName)
    
    helper.webcenterRestore()

def stopDiscussionsCrawler(appName, sesUrl, sesSchema, sesPassword, host, port,  server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    
    scheduleName = constructSourceName(appName, host, port, 'discussions')

    ##helper method for calling mbean
    stopSchedule(appName, sesUrl, sesSchema, sesPassword, scheduleName)
    
    helper.webcenterRestore()

 #mbean not implemented yet
def deleteDiscussionsCrawler(appName, sesUrl, sesSchema, sesPassword, host, port, server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    
    ## Sources
    forumName = constructSourceName(appName, host, port, 'forums')
    messageName = constructSourceName(appName, host, port, 'messages')
    threadName = constructSourceName(appName, host, port, 'threads')
    
    announceName = constructSourceName(appName, host, port, 'announcements')

    ## Schedule
    scheduleName = constructSourceName(appName, host, port, 'discussions')
   
    ##helper method for calling mbean
    deleteSource(appName, sesUrl, sesSchema, sesPassword, forumName)
    deleteSource(appName, sesUrl, sesSchema, sesPassword, announceName)
    deleteSource(appName, sesUrl, sesSchema, sesPassword, messageName)
    deleteSource(appName, sesUrl, sesSchema, sesPassword, threadName)
    deleteSchedule(appName, sesUrl, sesSchema, sesPassword, scheduleName)
    
    helper.webcenterRestore()
   
    
def createDiscussionsCrawler(appName,  host, port, sesUrl, sesSchema, sesPassword,  dbConnString, user, password, authUserIdFormat, crawlingMode, recrawlPolicy, freqType, startHour, hoursBetweenLaunches, startDayOfWeek, startDayOfMonth, daysBetweenLaunches, weeksBetweenLaunches, monthsBetweenLaunches,  server='', applicationVersion=''):

    helper.webcenterInitialize(server,applicationVersion)
    
    announceName = createDBSource(appName, 'announcements', sesUrl, sesSchema, sesPassword, host, port,  dbConnString, user, password, authUserIdFormat)
    messageName = createDBSource(appName, 'messages', sesUrl, sesSchema, sesPassword, host, port, dbConnString, user, password, authUserIdFormat)
    threadName = createDBSource(appName, 'threads', sesUrl, sesSchema, sesPassword, host, port, dbConnString, user, password, authUserIdFormat)
    forumName = createDBSource(appName, 'forums', sesUrl, sesSchema, sesPassword, host, port, dbConnString, user, password, authUserIdFormat)
    
    scheduleName = constructSourceName(appName, host, port, 'discussions')
    sourceNames = jarray.array([String(messageName), String(forumName), String(threadName), String(announceName)], String)
    ##sourceNames = java.util.ArrayList()
    ##sourceNames.add(announceName)
    ##sourceNames.add(forumName)
    
    createSchedule(appName, scheduleName, sourceNames, sesUrl, sesSchema, sesPassword, crawlingMode, recrawlPolicy, freqType, startHour, hoursBetweenLaunches, daysBetweenLaunches, weeksBetweenLaunches, startDayOfWeek, monthsBetweenLaunches, startDayOfMonth )

    sourceGroupName = constructSourcePrefix(appName, host, port)

    addToSourceGroup(appName, sesUrl, sesSchema, sesPassword, sourceGroupName, sourceNames)        
  
    helper.webcenterRestore()

#verbose not implemented yet
def listDocumentsCrawler(appName, sesUrl, sesSchema, sesPassword, host, port, verbose=0, server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
  
    
    ucmName =  constructSourceName(appName, host, port, 'documents')
   
    ##Call Exists 
    ucmExists = sourceExists(appName, sesUrl, sesSchema, sesPassword, ucmName)
     
    print '----------------'
    #Needs Translation
    helper.wcPrintMessage('DOCUMENTS_CRAWLERS_TITLE')
    print '----------------'
    print ''
    
    if ucmExists:
        print ucmName

    print ''

    helper.webcenterRestore()
    
def startDocumentsCrawler(appName, sesUrl, sesSchema, sesPassword, host, port,  server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    
    scheduleName =  constructSourceName(appName, host, port, 'documents')

    ##helper method for calling mbean
    startSchedule(appName, sesUrl, sesSchema, sesPassword, scheduleName)
    
    helper.webcenterRestore()

def stopDocumentsCrawler(appName, sesUrl, sesSchema, sesPassword, host, port,  server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    
    scheduleName = constructSourceName(appName, host, port, 'documents')

    ##helper method for calling mbean
    stopSchedule(appName, sesUrl, sesSchema, sesPassword, scheduleName)
    
    helper.webcenterRestore()


#mbean not implemented yet
def deleteDocumentsCrawler(appName, sesUrl, sesSchema, sesPassword, host, port, server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)

    
    ucmName =  constructSourceName(appName, host, port, 'documents')
    
    ##helper method for calling mbean
    deleteSource(appName, sesUrl, sesSchema, sesPassword, ucmName)
    deleteSchedule(appName, sesUrl, sesSchema, sesPassword, ucmName)
    
    helper.webcenterRestore()
   

def createDocumentsCrawler(appName,  host, port, sesUrl, sesSchema, sesPassword, configUrl, user, password, scratchDir,  httpEndpoint, displayUrl, realm,  authUserIdFormat, pipelineName, crawlingMode, recrawlPolicy, freqType, startHour, hoursBetweenLaunches, startDayOfWeek, startDayOfMonth, daysBetweenLaunches, weeksBetweenLaunches, monthsBetweenLaunches,  server='', applicationVersion=''):

    helper.webcenterInitialize(server,applicationVersion)

    ucmName = createUCMSource(appName,  host, port, sesUrl, sesSchema, sesPassword, configUrl, user, password, scratchDir,  httpEndpoint, displayUrl, authUserIdFormat, pipelineName, realm)
   
    
    scheduleName =  constructSourceName(appName, host, port, 'documents')
    sourceNames = jarray.array([String(ucmName)], String)

    ##sourceNames = java.util.ArrayList()
    ##sourceNames.add(ucmName)
    
    createSchedule(appName, scheduleName, sourceNames, sesUrl, sesSchema, sesPassword, crawlingMode, recrawlPolicy, freqType, startHour, hoursBetweenLaunches, daysBetweenLaunches, weeksBetweenLaunches, startDayOfWeek, monthsBetweenLaunches, startDayOfMonth )

    sourceGroupName = constructSourcePrefix(appName, host, port)

    addToSourceGroup(appName, sesUrl, sesSchema, sesPassword, sourceGroupName, sourceNames)        
  
    helper.webcenterRestore()
    
#verbose not implemented yet
def listSpacesCrawler(appName, sesUrl, sesSchema, sesPassword, host, port, verbose=0,  server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    
        
    spacesName = constructSourceName(appName, host, port, 'spaces')
   
    ##Call Exists for both sources
    spacesExists = sourceExists(appName, sesUrl, sesSchema, sesPassword, spacesName)

    print '----------------'
    #Needs Translation
    helper.wcPrintMessage('SPACES_CRAWLERS_TITLE')
    print '----------------'
    print ''
    
    if spacesExists:
        print spacesName
   

    print ''

    helper.webcenterRestore()
    
def startSpacesCrawler(appName, sesUrl, sesSchema, sesPassword, host, port,  server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    
    scheduleName = constructSourceName(appName, host, port, 'spaces')

    ##helper method for calling mbean
    startSchedule(appName, sesUrl, sesSchema, sesPassword, scheduleName)
    
    helper.webcenterRestore()

def stopSpacesCrawler(appName, sesUrl, sesSchema, sesPassword, host, port,  server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    
    scheduleName = constructSourceName(appName, host, port, 'spaces')

    ##helper method for calling mbean
    stopSchedule(appName, sesUrl, sesSchema, sesPassword, scheduleName)
    
    helper.webcenterRestore()

#mbean not implemented yet
def deleteSpacesCrawler(appName, sesUrl, sesSchema, sesPassword, host, port, server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    
    spacesName = constructSourceName(appName, host, port, 'spaces')
      
    ##helper method for calling mbean
    deleteSource(appName, sesUrl, sesSchema, sesPassword, spacesName)
    deleteSchedule(appName, sesUrl, sesSchema, sesPassword, spacesName)
       
    helper.webcenterRestore()



def createSpacesCrawler(appName,  host, port, sesUrl, sesSchema, sesPassword, crawlUser, crawlPassword, scratchDir, authUserIdFormat, crawlingMode, recrawlPolicy, freqType, startHour, hoursBetweenLaunches, startDayOfWeek, startDayOfMonth, daysBetweenLaunches, weeksBetweenLaunches, monthsBetweenLaunches, server='', applicationVersion=''):

    helper.webcenterInitialize(server,applicationVersion)
    
    spacesName = createWCSource(appName,  host, port, sesUrl, sesSchema, sesPassword, crawlUser, crawlPassword, scratchDir, authUserIdFormat)
  
    scheduleName = constructSourceName(appName, host, port, 'spaces')
    sourceNames = jarray.array([String(spacesName)], String)
    ##sourceNames = java.util.ArrayList()
    ##sourceNames.add(spacesName)
    
    createSchedule(appName, scheduleName, sourceNames, sesUrl, sesSchema, sesPassword, crawlingMode, recrawlPolicy, freqType, startHour, hoursBetweenLaunches, daysBetweenLaunches, weeksBetweenLaunches, startDayOfWeek, monthsBetweenLaunches, startDayOfMonth)

    sourceGroupName =  constructSourcePrefix(appName, host, port) 

    addToSourceGroup(appName, sesUrl, sesSchema, sesPassword, sourceGroupName, sourceNames)        

    helper.webcenterRestore()
    
def getSesAdminManager(appName):
    # This method must be called within the calls webcenterInitialize(server,applicationVersion) and
    # webcenterRestore.

    objectName = 'oracle.webcenter.search:name=SesAdminManager,type=SesAdminManager,Application=' + appName + ',ApplicationName=' + appName
    if helper.WebCenter.server != '':
      if ora_mbs.isWebSphere():
         objectName= objectName + ',process='+helper.WebCenter.server
      else: 
         objectName= objectName + ',Location='+helper.WebCenter.server
    if helper.WebCenter.applicationVersion != '':
        objectName= objectName + ',ApplicationVersion='+ helper.WebCenter.applicationVersion
    objectName=objectName + ',*'

    ##print 'object name is: '+objectName
    mbean = getSesAdminObjectName(objectName)
    return mbean

def getSesAdminObjectName(name):
    queryObjName = ObjectName(name)
    mbean = None
    try:
        pmBeanSet = ora_mbs.queryNames(queryObjName,None)
        pmBeanArray = pmBeanSet.toArray()
        if len(pmBeanArray) > 0:
            mbean = pmBeanArray[0]
        else:
            helper.wcPrintErrorMessage('ERROR_MBS_QUERYNAME',name)
    except Exception, ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
        helper.wcPrintErrorMessage('ERROR_MBS_QUERYNAME',name)

    # Will return the producer mbean or None
    return mbean 
#
# Commands for SES Connection
#
def createSESConnection (appName,name,url,appUser,appPassword,default=0,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    connectionType='SesConnectionProvider'#process arguments given by user if need to
    userArg={'SoapUrl':url,'AppUsername':appUser,'AppPassword':appPassword}
    connObj = helper.customCreateConnection(appName,name,connectionType,userArg)
    # set connection as default only if create connection succeeded
    if connObj is not None:
        # If default is 1, update AdfSearchConfig
        if default:
            setSearchConfigConnectionName(appName,name)
    helper.webcenterRestore()

def setSESConnection (appName,name, url='',appUser='',appPassword='',default=None,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    userArg={}
    # For attributes not provided by input, retrieve their values from existing entry
    if url != '':
        userArg['SoapUrl'] = url
    if appUser != '':
        userArg['AppUsername'] = appUser
    if appPassword != '':
        userArg['AppPassword'] = appPassword
    helper.customSetConnection(appName,name,'SesConnectionProvider',userArg,0)
    # If default is 1, set this connection as default in AdfSearchConfig
    # If default is 0, remove this connection as default in AdfSearchConfig 
    if default==1:
        setSearchConfigConnectionName(appName,name)
    else:
        if default==0:
           removeSearchConfigConnectionName(appName,name)
    helper.webcenterRestore()

def listSESConnections(appName,verbose=0,name='',server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    stringAttrs= [(helper.wcGetMessageFromResourceBundle('SES_NAME_ID1'),'ConnectionName'),(helper.wcGetMessageFromResourceBundle('SES_SOAP_URL_ID2'),'SoapUrl'),(helper.wcGetMessageFromResourceBundle('SES_APP_NAME_ID3'),'AppUsername')]
    nonStrAttrs=None 
    helper.customListConnections(appName,'SesConnectionProvider',stringAttrs,sesNonStrAttrs,nonStrAttrs,verbose,name)
    # Print default connection
    # If a name is specified, show default connection value in the entry
    # Otherwise, show default connection after listing all connections
    defConnectionName = getSearchConfigConnectionName(appName)
    if name != '':
        if name==defConnectionName:
            printIsDefaultSESConnection('true')
        else:
            printIsDefaultSESConnection('false')
    else:
        if defConnectionName != '':
            printDefaultSESConnection(defConnectionName)
    helper.webcenterRestore()

#
# Commands for ADF SEARCH CONFIG
#
def setSearchConfig (appName, numSavedSearches='', numResultsRegion='', numResultsMain='', numResultsToolbar='', executionTimeout='', prepareTimeout='', showAllExecutionTimeout='',server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    searchConfigObj = getSearchConfigObj(appName)
    if searchConfigObj is not None:
        userArg={}
        if numSavedSearches != '':
            userArg[SearchCfgConst.numSavedSearches]= Integer(numSavedSearches)
        if numResultsRegion != '':
            userArg[SearchCfgConst.numResultsRegion]=Integer(numResultsRegion)
        if numResultsMain != '':
            userArg[SearchCfgConst.numResultsMain]=Integer(numResultsMain)
        if executionTimeout != '':
            userArg[SearchCfgConst.executionTimeout]=Integer(executionTimeout)
        if prepareTimeout != '':
            userArg[SearchCfgConst.prepareTimeout]=Integer(prepareTimeout)
        if showAllExecutionTimeout != '':
            userArg[SearchCfgConst.showAllExecutionTimeout]=Long(showAllExecutionTimeout)
        try:
            exFromSet = helper.customSetAttributes(appName,searchConfigObj,userArg)
            if exFromSet is None:
                helper.customSaveConfig(appName)
                helper.wcPrintMessage('INFORM_NEED_RESTART')
            else:
                raise exFromSet
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_SET_ATTRIBUTE','SearchConfig')
            helper.customRefreshConfig(appName)                
    else:
        helper.wcPrintErrorMessage('ERROR_SET_ATTRIBUTE','SearchConfig')
    helper.webcenterRestore()

def setSearchSESConfig(appName, connectionName='', dataGroup='', topNRows='',server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    searchConfigObj = getSearchConfigObj(appName)
    if searchConfigObj is not None:
        userArg={}
        if connectionName != '':
            userArg[SearchCfgConst.connectionName]=connectionName
        if dataGroup != '':
            userArg[SearchCfgConst.dataGroup]=dataGroup
        if topNRows != '':
            userArg[SearchCfgConst.topNRows]=Integer(topNRows)
        try:
            exFromSet = helper.customSetAttributes(appName,searchConfigObj,userArg)
            if exFromSet is None:
                helper.customSaveConfig(appName)
                helper.wcPrintMessage('INFORM_NEED_RESTART')
            else:
                raise exFromSet
        except Exception, ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_SET_ATTRIBUTE','SearchConfig')
            helper.customRefreshConfig(appName)       
    else:
        helper.wcPrintErrorMessage('ERROR_SET_ATTRIBUTE','SearchSESConfig')
    helper.webcenterRestore()

def listSearchConfig(appName,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    searchConfigObj = getSearchConfigObj(appName)
    if searchConfigObj is not None:
        print '-------------'
        print helper.wcGetMessageFromResourceBundle('SEARCH_CONFIG_TITLE')
        print '-------------'
        print helper.wcGetMessageFromResourceBundle('SEARCH_CONFIG_NUMSAVED_SEARCHES') + ': ', getSearchConfigAttr(searchConfigObj, SearchCfgConst.numSavedSearches)
        print helper.wcGetMessageFromResourceBundle('SEARCH_CONFIG_NUMRESULTS_REGION') + ': ', getSearchConfigAttr(searchConfigObj, SearchCfgConst.numResultsRegion)
        print helper.wcGetMessageFromResourceBundle('SEARCH_CONFIG_NUMRESULTS_MAIN') + ': ', getSearchConfigAttr(searchConfigObj, SearchCfgConst.numResultsMain)
        print helper.wcGetMessageFromResourceBundle('SEARCH_CONFIG_EXEC_TIMEOUT') + ': ', getSearchConfigAttr(searchConfigObj, SearchCfgConst.executionTimeout)
        print helper.wcGetMessageFromResourceBundle('SEARCH_CONFIG_PREPARE_TIMEOUT') + ': ', getSearchConfigAttr(searchConfigObj, SearchCfgConst.prepareTimeout)
        print helper.wcGetMessageFromResourceBundle('SEARCH_CONFIG_SHOWALL_EXEC_TIMEOUT') + ': ', getNullableSearchConfigAttr(searchConfigObj, SearchCfgConst.showAllExecutionTimeout)
    else:
        helper.wcPrintErrorMessage('ERROR_NO_APPLICATION', appName)
    helper.webcenterRestore()

def listSearchSESConfig(appName,server='',applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
    searchConfigObj = getSearchConfigObj(appName)
    if searchConfigObj is not None:
        print '-----------------'
        print helper.wcGetMessageFromResourceBundle('SEARCH_SES_CONFIG_TITLE')
        print '-----------------'
        print helper.wcGetMessageFromResourceBundle('SEARCH_SES_CONFIG_CONNECTION') + ': ', getSearchConfigAttr(searchConfigObj, SearchCfgConst.connectionName)
        print helper.wcGetMessageFromResourceBundle('SEARCH_SES_CONFIG_DATAGROUP') + ': ', getSearchConfigAttr(searchConfigObj, SearchCfgConst.dataGroup)
        print helper.wcGetMessageFromResourceBundle('SEARCH_SES_CONFIG_TOPNROWS') + ': ', getNullableSearchConfigAttr(searchConfigObj, SearchCfgConst.topNRows)
    else:
        helper.wcPrintErrorMessage('ERROR_NO_APPLICATION', appName)
    helper.webcenterRestore()
    
# Set the SES version number used by this copy of Spaces. 
def setSESVersion(appName,  sesUrl, sesSchema, sesPassword, server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
   
    ##helper method for calling mbean
    setVersion(appName, sesUrl, sesSchema, sesPassword)
    
    helper.webcenterRestore()
    
def listSESVersion(appName, sesUrl, server='', applicationVersion=''):
    helper.webcenterInitialize(server,applicationVersion)
   
    ##helper method for calling mbean
    version = getVersion(appName, sesUrl)

    if version == '00.0.0.0.0':
        version = 'Not Configured'

    print '-----------------'
    print helper.wcGetMessageFromResourceBundle('SES_VERSION_CONFIG_TITLE')
    print '-----------------'
    print helper.wcGetMessageFromResourceBundle('SEARCH_SES_URL_ID1') + ': ', sesUrl
    print helper.wcGetMessageFromResourceBundle('SEARCH_SES_VERSION_ID1') + ': ', version
    
    helper.webcenterRestore()

# Search Config Constants
class SearchCfgConst:
    # Attribute constants
    numSavedSearches = 'NumSavedSearches'
    numResultsRegion = 'SimpleSearchResultsNumRows'
    numResultsMain = 'SearchResultsNumRows'
    executionTimeout = 'ExecutionTimeoutMs'
    prepareTimeout = 'ExecutorPreparationTimeoutMs'
    showAllExecutionTimeout = 'ShowAllExecutionTimeoutMs'
    connectionName = 'SesConnectionName'
    dataGroup = 'SesDataGroup'
    topNRows = 'SesTopNRows'
    spacesCrawlEnabled = 'WcServicesCrawlEnabled'
    documentCrawlEnabled = 'WcUcmCrawlEnabled'
    discussionsCrawlEnabled = 'WcDiscussionsCrawlEnabled'
    fullCrawlInterval = 'FullCrawlInterval'
   

# Helper functions

def constructFederationTrustedEntity(appName, wsUrl, wsUser, wsPassword, entityName, entityPassword, useIdPlugin, authAttr, desc):
    lstGroup = [String(wsUrl), String(wsUser),String(wsPassword), String(entityName),String(entityPassword), Boolean(useIdPlugin), String(authAttr), String(desc)]
    argsGroup = ['java.lang.String' for x in range(8)]
    argsGroup[5] = 'java.lang.Boolean'    
    objsGroup = jarray.array(lstGroup, Object)
    strsGroup = jarray.array(argsGroup, String)
    try:
        ora_mbs.invoke(getSesAdminManager(appName),'createFederationTrustedEntity',objsGroup, strsGroup)
        
    except Exception, e:
        if e.getMessage():
            helper.wcPrintExceptionMessage(e.getMessage())
        else:
            helper.wcPrintErrorMessage('ENTITY_CREATION_FAILED', entityName);

def deleteSource(appName, sesUrl, sesSchema, sesPassword, sourceName):
    lstGroup = [String(sesUrl), String(sesSchema),String(sesPassword), String(sourceName)]
    argsGroup = ['java.lang.String' for x in range(4)]

    objsGroup = jarray.array(lstGroup, Object)
    strsGroup = jarray.array(argsGroup, String)
    try:
        ora_mbs.invoke(getSesAdminManager(appName),'deleteSource',objsGroup, strsGroup)
        ##bean = oracle.webcenter.search.admin.SesAdminMXBeanImpl()
        ##exists = bean.deleteSource(lstGroup[0], lstGroup[1], lstGroup[2],lstGroup[3]) 
    except Exception, e:
        helper.wcPrintExceptionMessage(e.getMessage())

def deleteSchedule(appName, sesUrl, sesSchema, sesPassword, sourceName):
    lstGroup = [String(sesUrl), String(sesSchema),String(sesPassword), String(sourceName)]
    argsGroup = ['java.lang.String' for x in range(4)]

    objsGroup = jarray.array(lstGroup, Object)
    strsGroup = jarray.array(argsGroup, String)
    try:
        ora_mbs.invoke(getSesAdminManager(appName),'deleteSchedule',objsGroup, strsGroup)
        ##bean = oracle.webcenter.search.admin.SesAdminMXBeanImpl()
        ##exists = bean.deleteSchedule(lstGroup[0], lstGroup[1], lstGroup[2],lstGroup[3]) 
    except Exception, e:
        helper.wcPrintExceptionMessage(e.getMessage())

def sourceExists(appName, sesUrl, sesSchema, sesPassword, sourceName):
    lstGroup = [String(sesUrl), String(sesSchema),String(sesPassword), String(sourceName)]
    argsGroup =  ['java.lang.String' for x in range(4)]

    objsGroup = jarray.array(lstGroup, Object)
    strsGroup = jarray.array(argsGroup, String)
    try:
        exists=  ora_mbs.invoke(getSesAdminManager(appName),'sourceExists',objsGroup, strsGroup)
        ##bean = oracle.webcenter.search.admin.SesAdminMXBeanImpl()
        ##exists = bean.sourceExists(lstGroup[0], lstGroup[1], lstGroup[2],lstGroup[3]) 
        return exists
        
    except Exception, e:
        helper.wcPrintExceptionMessage(e.getMessage())

    return 0
        
def scheduleExists(appName, sesUrl, sesSchema, sesPassword, scheduleName):
    lstGroup = [String(sesUrl), String(sesSchema),String(sesPassword), String(scheduleName)]
    argsGroup =  ['java.lang.String' for x in range(4)]

    objsGroup = jarray.array(lstGroup, Object)
    strsGroup = jarray.array(argsGroup, String)
    try:
        exists = ora_mbs.invoke(getSesAdminManager(appName),'scheduleExists',objsGroup, strsGroup)
        ##bean = oracle.webcenter.search.admin.SesAdminMXBeanImpl()
        ##exists = bean.scheduleExists(lstGroup[0], lstGroup[1], lstGroup[2],lstGroup[3]) 
        return exists
        
    except Exception, e:
        helper.wcPrintExceptionMessage(e.getMessage())

    return 0
        
def sourceGroupExists(appName, sesUrl, sesSchema, sesPassword, sourceGroupName):
    lstGroup = [String(sesUrl), String(sesSchema),String(sesPassword), String(sourceGroupName)]
    argsGroup =  ['java.lang.String' for x in range(4)]

    objsGroup = jarray.array(lstGroup, Object)
    strsGroup = jarray.array(argsGroup, String)
    try:
        exists =  ora_mbs.invoke(getSesAdminManager(appName),'sourceGroupExists',objsGroup, strsGroup)
        ##bean = oracle.webcenter.search.admin.SesAdminMXBeanImpl()
        ##exists = bean.sourceGroupExists(lstGroup[0], lstGroup[1], lstGroup[2],lstGroup[3]) 
        return exists
        
    except Exception, e:
        helper.wcPrintExceptionMessage(e.getMessage())

   
    return 0

def addToSourceGroup(appName, sesUrl, sesSchema, sesPassword, sourceGroupName, sourceNames):
    exists = sourceGroupExists(appName, sesUrl, sesSchema, sesPassword, sourceGroupName)
    
    lstGroup = [String(sesUrl), String(sesSchema),String(sesPassword), String(sourceGroupName), sourceNames]
    
    argsGroup =  ['java.lang.String' for x in range(5)]
    argsGroup[4] =  '[Ljava.lang.String;'
    
    if exists:
        lstGroup.append(Boolean(0))
        argsGroup.append('java.lang.Boolean')
        
        
        objsGroup = jarray.array(lstGroup, Object)
        strsGroup = jarray.array(argsGroup, String)
      
        try:
            ora_mbs.invoke(getSesAdminManager(appName),'updateSourceGroup',objsGroup, strsGroup)
            ##bean = oracle.webcenter.search.admin.SesAdminMXBeanImpl()
            ##bean.updateSourceGroup(lstGroup[0], lstGroup[1], lstGroup[2],lstGroup[3],lstGroup[4], lstGroup[5] ) 
        except Exception, e:
            if e.getMessage():
              
                helper.wcPrintExceptionMessage(e.getMessage())
            else:
                helper.wcPrintErrorMessage('SOURCE_GROUP_FAILED', sourceGroupName)

    else:
        objsGroup = jarray.array(lstGroup, Object)
        strsGroup = jarray.array(argsGroup, String)
        
        try:
            ora_mbs.invoke(getSesAdminManager(appName),'createSourceGroup',objsGroup, strsGroup)
            ##bean = oracle.webcenter.search.admin.SesAdminMXBeanImpl()
            ##bean.createSourceGroup(lstGroup[0], lstGroup[1], lstGroup[2],lstGroup[3],lstGroup[4] )
        except Exception, e:
            if e.getMessage():
                helper.wcPrintExceptionMessage(e.getMessage())
            else:
                helper.wcPrintErrorMessage('SOURCE_GROUP_FAILED', sourceGroupName)
        

def startSchedule(appName, sesUrl, sesSchema, sesPassword, scheduleName):

    lstSchedule = [String(sesUrl), String(sesSchema),String(sesPassword), String(scheduleName)]
    
    argsSchedule =  ['java.lang.String' for x in range(4)]
    
    objsSchedule = jarray.array(lstSchedule, Object)
    strsSchedule = jarray.array(argsSchedule, String)
    
    try:
        ora_mbs.invoke(getSesAdminManager(appName),'startSchedule',objsSchedule, strsSchedule)
        ##bean = oracle.webcenter.search.admin.SesAdminMXBeanImpl()
        ##bean.startSchedule(lstSchedule[0], lstSchedule[1], lstSchedule[2],lstSchedule[3] )
    except Exception, e:
        helper.wcPrintExceptionMessage(e.getMessage())

def stopSchedule(appName, sesUrl, sesSchema, sesPassword, scheduleName):
    lstSchedule = [String(sesUrl), String(sesSchema),String(sesPassword), String(scheduleName)]
    
    argsSchedule =  ['java.lang.String' for x in range(4)]
    
    objsSchedule = jarray.array(lstSchedule, Object)
    strsSchedule = jarray.array(argsSchedule, String)
    
    try:
        ora_mbs.invoke(getSesAdminManager(appName),'stopSchedule',objsSchedule, strsSchedule)
        ##bean = oracle.webcenter.search.admin.SesAdminMXBeanImpl()
        ##bean.stopSchedule(lstSchedule[0], lstSchedule[1], lstSchedule[2],lstSchedule[3] )
    except Exception, e:
        helper.wcPrintExceptionMessage(e.getMessage())


def updateSchedule(appName, scheduleName, sourceNames, sesUrl, sesSchema, sesPassword, crawlingMode, recrawlPolicy, freqType, startHour, hoursBetweenLaunches, daysBetweenLaunches, weeksBetweenLaunches, startDayOfWeek, monthsBetweenLaunches, startDayOfMonth ):
    if scheduleExists(appName, sesUrl, sesSchema, sesPassword, scheduleName):
      
        lstSchedule = [String(sesUrl), String(sesSchema),String(sesPassword), String(scheduleName), sourceNames ,String(crawlingMode), String(recrawlPolicy), String(freqType), Integer(startHour), Integer(hoursBetweenLaunches),Integer(daysBetweenLaunches), Integer(weeksBetweenLaunches), String(startDayOfWeek),Integer(monthsBetweenLaunches), Integer(startDayOfMonth)]

        argsSchedule =  ['java.lang.String' for x in range(15)]
        argsSchedule[8] = 'java.lang.Integer'
        argsSchedule[9] = 'java.lang.Integer'
        argsSchedule[10] = 'java.lang.Integer'
        argsSchedule[11] = 'java.lang.Integer'
        argsSchedule[13] = 'java.lang.Integer'
        argsSchedule[14] = 'java.lang.Integer'
        argsSchedule[4] = '[Ljava.lang.String;'
    
        objsSchedule = jarray.array(lstSchedule, Object)
        strsSchedule = jarray.array(argsSchedule, String)
     
        try:
            ora_mbs.invoke(getSesAdminManager(appName),'updateSchedule',objsSchedule, strsSchedule)
            ##bean = oracle.webcenter.search.admin.SesAdminMXBeanImpl()
            ##bean.updateSchedule(lstSchedule[0], lstSchedule[1], lstSchedule[2],lstSchedule[3],lstSchedule[4], lstSchedule[5], lstSchedule[6],lstSchedule[7], lstSchedule[8], lstSchedule[9], lstSchedule[10],lstSchedule[11], lstSchedule[12], lstSchedule[13], lstSchedule[14]  )
        except Exception, e:
            helper.wcPrintExceptionMessage(e.getMessage())

#Creates a SES Schedule
def createSchedule(appName, scheduleName, sourceNames, sesUrl, sesSchema, sesPassword, crawlingMode, recrawlPolicy, freqType, startHour, hoursBetweenLaunches, daysBetweenLaunches, weeksBetweenLaunches, startDayOfWeek, monthsBetweenLaunches, startDayOfMonth ):
    if scheduleExists(appName, sesUrl, sesSchema, sesPassword, scheduleName):
        
        helper.wcPrintMessage('SCHEDULE_EXISTS', scheduleName)
        updateSchedule(appName, scheduleName, sourceNames, sesUrl, sesSchema, sesPassword, crawlingMode, recrawlPolicy, freqType, startHour, hoursBetweenLaunches, daysBetweenLaunches, weeksBetweenLaunches, startDayOfWeek, monthsBetweenLaunches, startDayOfMonth )
        return 0

    lstSchedule = [String(sesUrl), String(sesSchema),String(sesPassword), String(scheduleName), sourceNames ,String(crawlingMode), String(recrawlPolicy), String(freqType), Integer(startHour), Integer(hoursBetweenLaunches),Integer(daysBetweenLaunches), Integer(weeksBetweenLaunches), String(startDayOfWeek),Integer(monthsBetweenLaunches), Integer(startDayOfMonth)]

   

    argsSchedule =  ['java.lang.String' for x in range(15)]
    argsSchedule[8] = 'java.lang.Integer'
    argsSchedule[9] = 'java.lang.Integer'
    argsSchedule[10] = 'java.lang.Integer'
    argsSchedule[11] = 'java.lang.Integer'
    argsSchedule[13] = 'java.lang.Integer'
    argsSchedule[14] = 'java.lang.Integer'
    argsSchedule[4] = '[Ljava.lang.String;'
    
   
    objsSchedule = jarray.array(lstSchedule, Object)
    strsSchedule = jarray.array(argsSchedule, String)
   
    
    try:
        ora_mbs.invoke(getSesAdminManager(appName),'createSchedule',objsSchedule, strsSchedule)
        ##bean = oracle.webcenter.search.admin.SesAdminMXBeanImpl()
        ##bean.createSchedule(lstSchedule[0], lstSchedule[1], lstSchedule[2],lstSchedule[3],lstSchedule[4], lstSchedule[5], lstSchedule[6],lstSchedule[7], lstSchedule[8], lstSchedule[9], lstSchedule[10],lstSchedule[11], lstSchedule[12], lstSchedule[13], lstSchedule[14]  )
        return 1
        
    except Exception, e:
        if e.getMessage():
            helper.wcPrintExceptionMessage(e.getMessage())
        else:
            helper.wcPrintErrorMessage('SCHEDULE_CREATION_FAILED',
                                  scheduleName)
        
# Create UCM Source
def  createUCMSource(appName,  host, port, sesUrl, sesSchema, sesPassword, configUrl, user, password, scratchDir,  httpEndpoint, displayUrl, authUserIdFormat, pipeline, realm):
       
    sourceName = constructSourceName(appName, host, port, 'documents')

    if sourceExists(appName, sesUrl, sesSchema, sesPassword, sourceName):
        
        helper.wcPrintMessage('SOURCE_EXISTS', sourceName)
        return sourceName
    
    authType = 'NATIVE'
        
    
    lstSource = [String(sesUrl),
                 String(sesSchema),
                 String(sesPassword),
                 String(sourceName),
                 String(configUrl),
                 String(authType),
                 String(user),
                 String(password),
                 String(realm),
                 String(''),
                 String(''),
                 String(scratchDir),
                 Integer(3),
                 String(httpEndpoint),
                 String(displayUrl),
                 String(user),
                 String(password),
                 Boolean(0),
                 String(authUserIdFormat),
                 Boolean(0),
                 String(''),
                 String(authType),
                 String(realm),
                 String(''),
                 String(''),
                 String(pipeline)]

   
    argsSource = ['java.lang.String' for x in range(26)]
    argsSource[12] = 'java.lang.Integer'
    argsSource[17] = 'java.lang.Boolean'
    argsSource[19] = 'java.lang.Boolean'
    
    objsSource = jarray.array(lstSource, Object)
    strsSource = jarray.array(argsSource, String)
    
    try:
        ora_mbs.invoke(getSesAdminManager(appName),'createContentServerSource',objsSource,strsSource)
        ##bean = oracle.webcenter.search.admin.SesAdminMXBeanImpl()
        ##bean.createContentServerSource(lstSource[0], lstSource[1], lstSource[2],lstSource[3],lstSource[4], lstSource[5], lstSource[6],lstSource[7], lstSource[8], lstSource[9], lstSource[10],lstSource[11], lstSource[12], lstSource[13], lstSource[14], lstSource[15], lstSource[16], lstSource[17],lstSource[18],lstSource[19], lstSource[20], lstSource[21],lstSource[22], lstSource[23], lstSource[24], lstSource[25])
    except Exception, e:
        if e.getMessage():
            helper.wcPrintExceptionMessage(e.getMessage())
        else:
            helper.wcPrintErrorMessage('SOURCE_CREATION_FAILED', sourceName)
    return sourceName

#Creates a since DB source. Type = 'forums' or 'announcements'
def createDBSource(appName, type, sesUrl, sesSchema, sesPassword, host, port,  dbConnString, user, password, authUserIdFormat):
    
    sourceName = constructSourceName(appName, host, port, type)

   
    if sourceExists(appName, sesUrl, sesSchema, sesPassword, sourceName):
        helper.wcPrintMessage('SOURCE_EXISTS', sourceName)
        
        return sourceName
    
    urlPrefix = 'http://' + host + ':' +  port
    authQuery = 'SELECT DISTINCT forumID as WCSECATTR FROM AUTHCRAWLER_FORUM_VW WHERE username = ? UNION SELECT DISTINCT -1 as WCSECATTR  FROM AUTHCRAWLER_FORUM_VW'
    view =''
    queryParam =''
    if type=='forums':
        queryParam = 'SELECT * FROM FORUMCRAWLER_VW'
    if type=='announcements':
        queryParam = 'SELECT * FROM ANNOUNCECRAWLER_VW'
    if type=='messages':
        queryParam = 'SELECT * FROM MESSAGECRAWLER_VW'
    if type=='threads':
        queryParam = 'SELECT * FROM THREADCRAWLER_VW'

    
    lstSource = [String(sesUrl), String(sesSchema),String(sesPassword), String(sourceName), String(dbConnString), String(user), String(password), String(view), Integer(-1), String(queryParam), String(''), String(urlPrefix), String(''), String(''), Boolean(0), String('WCSECATTR'), String(''),Boolean(1), String('PUBLIC'),  String(''), String(''), String(''), String(dbConnString), String(user), String(password), String(authQuery), Boolean(0),  String(authUserIdFormat)]

    argsDB = ['java.lang.String' for x in range(28)]
    argsDB[8] = 'java.lang.Integer'
    argsDB[14] = 'java.lang.Boolean'
    argsDB[17] = 'java.lang.Boolean'
    argsDB[26] = 'java.lang.Boolean'

     
    objsSource = jarray.array(lstSource, Object)
    strsDB = jarray.array(argsDB, String)
    
    try:
        ora_mbs.invoke(getSesAdminManager(appName),'createDatabaseSource',objsSource,strsDB)
        
        ##bean = oracle.webcenter.search.admin.SesAdminMXBeanImpl()
        
        ###bean.createDatabaseSource(lstSource[0], lstSource[1], lstSource[2],lstSource[3],lstSource[4], lstSource[5], lstSource[6],lstSource[7], lstSource[8], lstSource[9], lstSource[10],lstSource[11], lstSource[12], lstSource[13], lstSource[14], lstSource[15], lstSource[16], lstSource[17],lstSource[18],lstSource[19], lstSource[20], lstSource[21],lstSource[22], lstSource[23], lstSource[24], lstSource[25], lstSource[26], lstSource[27])
        
    except Exception, e:
        if e.getMessage():
            helper.wcPrintExceptionMessage(e.getMessage())
        else:
            helper.wcPrintErrorMessage('SOURCE_CREATION_FAILED', sourceName)
    return sourceName

#Creates a Webcenter Spaces source.
def createWCSource(appName,  host, port, sesUrl, sesSchema, sesPassword, crawlUser, crawlPassword, scratchDir,   authUserIdFormat):

    sourceName =constructSourceName(appName, host, port, 'spaces')

    if sourceExists(appName, sesUrl, sesSchema, sesPassword, sourceName):
        helper.wcPrintMessage('SOURCE_EXISTS', sourceName)
        
        return sourceName

   
    configUrl = 'http://' + host + ':' + port +'/rsscrawl'
    authEndpoint = 'http://' + host + ':' + port +'/sesUserAuth'
    
    lstSource = [String(sesUrl),
                 String(sesSchema),
                 String(sesPassword),
                 String(sourceName),
                 String(configUrl),
                 String('BASIC'),
                 String(crawlUser),
                 String(crawlPassword),
                 String('jazn.com'),
                 String(''),
                 String(''),
                 String(scratchDir),
                 Integer(3),
                 String(authEndpoint),
                 String(crawlUser),
                 String(crawlPassword),
                 String('jazn.com'),
                 String(authUserIdFormat)]

    argsDB = ['java.lang.String' for x in range(18)]
    argsDB[12] = 'java.lang.Integer'
    objsSource = jarray.array(lstSource, Object)
    strsDB = jarray.array(argsDB, String)
    
    try:
        ora_mbs.invoke(getSesAdminManager(appName),'createWebCenterSource',objsSource,strsDB)
        ##bean = oracle.webcenter.search.admin.SesAdminMXBeanImpl()
        ##bean.createWebCenterSource(lstSource[0], lstSource[1], lstSource[2],lstSource[3],lstSource[4], lstSource[5], lstSource[6],lstSource[7], lstSource[8], lstSource[9], lstSource[10],lstSource[11], lstSource[12], lstSource[13], lstSource[14], lstSource[15], lstSource[16], lstSource[17])
    except Exception, e:
        if e.getMessage():
            helper.wcPrintExceptionMessage(e.getMessage())
        else:
            helper.wcPrintErrorMessage('SOURCE_CREATION_FAILED', sourceName)
    return sourceName

def setVersion(appName, sesUrl, sesSchema, sesPassword):

    lstVersion = [String(sesUrl), String(sesSchema),String(sesPassword)]
    
    argsVersion =  ['java.lang.String' for x in range(3)]
    
    objsVersion = jarray.array(lstVersion, Object)
    strsVersion = jarray.array(argsVersion, String)
    
    try:
        ora_mbs.invoke(getSesAdminManager(appName),'setVersion',objsVersion, strsVersion)
      
    except Exception, e:
        helper.wcPrintExceptionMessage(e.getMessage())

def getVersion(appName, sesUrl):       
    version = '00.0.0.0.0'
    
    lstVersion = [String(sesUrl)]
    argsVersion =  ['java.lang.String']
    objsVersion = jarray.array(lstVersion, Object)
    strsVersion = jarray.array(argsVersion, String)
    
    try:
        version = ora_mbs.invoke(getSesAdminManager(appName),'getVersion', objsVersion, strsVersion)
      
    except Exception, e:
        helper.wcPrintExceptionMessage(e.getMessage())
    return version

# Get SES connection name in AdfSearchConfig 
def getSearchConfigConnectionName(appName):
    searchConfigObj = getSearchConfigObj(appName)
    if searchConfigObj is not None:
        try:
            defConnectionName = ora_mbs.getAttribute(searchConfigObj,'SesConnectionName')
            if defConnectionName is None:
                 return ''
            else:
                 return defConnectionName.strip()
        except Exception,ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','SesConnectionName')
    return None

# Set SES connection name in AdfSearchConfig
def setSearchConfigConnectionName(appName,connectionName):
    searchConfigObj = getSearchConfigObj(appName)
    if searchConfigObj is not None:
        try:
            ora_mbs.setAttribute(searchConfigObj,Attribute('SesConnectionName',connectionName))
            printSetDefaultSESConnection(connectionName)
            helper.customSaveConfig(appName)
        except Exception,ex:
            helper.wcPrintExceptionMessage(ex.getMessage())
            helper.wcPrintErrorMessage('ERROR_SET_ATTRIBUTE','SesConnectionName')
            helper.customRefreshConfig(appName)
    else:
        helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','SesConnectionName')

# Remove SES connection name in AdfSearchConfig
# if the specified connection name is currently set as the default
def removeSearchConfigConnectionName(appName,connectionName):
    searchConfigObj = getSearchConfigObj(appName)
    if searchConfigObj is not None:
        defConnectionName = getSearchConfigConnectionName(appName)
        if connectionName==defConnectionName:
            try:
                ora_mbs.setAttribute(searchConfigObj,Attribute('SesConnectionName',''))
                printRemoveDefaultSESConnection(connectionName)
                helper.customSaveConfig(appName)
            except Exception,ex:
                helper.wcPrintExceptionMessage(ex.getMessage())
                helper.wcPrintErrorMessage('ERROR_SET_ATTRIBUTE','SesConnectionName')
                helper.customRefreshConfig(appName)
        else:
            return
    else:
        helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE','SesConnectionName')

def sesNonStrAttrs(objName,nonStrAttrs):
    pass

# Get value of an attribute of a SES connection
def getConnectionAttribute(appName,connectionName,attributeName,server,applicationVersion):
    helper.webcenterInitialize(server,applicationVersion)
    mbeanarray = helper.getMBeanArrayInADFConnections()
    ADFConnObjName = helper.getADFConnectionObjName(mbeanarray,appName)
    if ADFConnObjName is None:
        helper.webcenterRestore()
        return
    connObjName = helper.getConnObjName(ADFConnObjName,connectionName,'SesConnectionProvider')
    if connObjName is None:
        helper.webcenterRestore()
        return
    obj = ora_mbs.getAttribute(connObjName,attributeName)
    helper.webcenterRestore()
    return obj

# Get AdfSearchConfig
def getSearchConfigObj(appName):
    # Get Search Config MBean's Object Name
    return helper.findOrCreateConfigObjName(appName,'oracle.adf.mbean.share.config.runtime.webcenter.search.AdfSearchConfig')

# Get attribute value in AdfSearchConfig 
def getSearchConfigAttr(objName,name):
    try:
        obj = ora_mbs.getAttribute(objName,name)
        if obj is None:
          return ''
        else:
          return obj
    except Exception, ex:
        helper.wcPrintExceptionMessage(ex.getMessage())
        helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE',name)

# Get boolean attribute value in AdfSearchConfig that can be null
def getNullableBooleanSearchConfigAttr(objName,name):
    try:
        obj = ora_mbs.getAttribute(objName,name)
        if obj == 1:
            return 'true'
        else:
            return 'false'
    except RuntimeMBeanException: 
        return 'false'
    except Exception:
        helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE',name)

# Get attribute value in AdfSearchConfig that can be null
def getNullableSearchConfigAttr(objName,name):
    try:
        obj = ora_mbs.getAttribute(objName,name)
        return obj
    except RuntimeMBeanException: #Alexis: Not sure how to handle this..
        # Should check that the cause is NullPointerException.
        # For now, it is not done due to programming issue.
        # It is safe because this method is called after the normal
        # get attribute value method is called. If there is any other
        # cause, it would have been caught earlier.
        return 0
    except Exception:
        helper.wcPrintErrorMessage('ERROR_GET_ATTRIBUTE',name)

# Messages
def printDefaultSESConnection(connName):
    print ''
    helper.wcPrintMessage('SES_DEFAULT_CONNECTION',connName)

def printIsDefaultSESConnection(value):
    helper.wcPrintMessage('SES_DEFAULT_CONNECTION_BOOLEAN',value)

def printSetDefaultSESConnection(connName):
    helper.wcPrintMessage('SET_SES_DEFAULT_CONNECTION',connName)
    helper.wcPrintMessage('INFORM_NEED_RESTART')

def printRemoveDefaultSESConnection(connName):
    helper.wcPrintMessage('REMOVE_SES_DEFAULT_CONNECTION',connName)
    helper.wcPrintMessage('INFORM_NEED_RESTART')

def constructSourcePrefix(appName, host, port):
    return appName+ '_' + host + '_' + port

def constructSourceName(appName, host, port,  type):
    return  constructSourcePrefix(appName, host, port) + '_' + type

def createDefaultSourceGroup(appName, sesUrl, sesSchema, sesPassword, host, port, defaultHost, defaultPort,  server='', applicationVersion='' ):
    helper.webcenterInitialize(server,applicationVersion)
   
    announceName = constructSourceName(appName, defaultHost, defaultPort,  'announcements')
    forumName = constructSourceName(appName, defaultHost, defaultPort,  'forums')
    threadName = constructSourceName(appName, defaultHost, defaultPort,  'threads')
    messageName = constructSourceName(appName, defaultHost, defaultPort,  'messages')
    documentsName = constructSourceName(appName, defaultHost, defaultPort,  'documents')
    
    sourceNames = jarray.array([String(announceName), String(threadName), String(messageName), String(forumName), String(documentsName)], String)
 

    sourceGroupName = constructSourcePrefix(appName, host, port)

    addToSourceGroup(appName, sesUrl, sesSchema, sesPassword, sourceGroupName, sourceNames)        
  
    helper.webcenterRestore()

