# Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved. 
import WebCenterWLSTHelper as wlsthelper
wlsthelper.loadHandler('WebCenterWLSTHelper')
wlsthelper.loadHandler('LifecycleHandler')
import LifecycleHandler as lifecyclehandler
from java.io import File
from java.io import FileInputStream
from java.io import FileOutputStream
from java.util import ArrayList
from javax.xml.parsers import DocumentBuilderFactory
from javax.xml.transform import TransformerFactory
from javax.xml.transform.dom import DOMSource
from javax.xml.transform.stream import StreamResult
from org.w3c.dom import Node
from org.apache.commons.io import FileUtils
import WebCenterHandlerHelper as helper

def lifecycleCheck():
    lifecyclehandler.lifecycleCheck()

def upgradeWebCenterApplication(appName, server='', applicationVersion=''):
    if (lifecyclehandler._validateStringDataType('appName', appName, 'upgrade') == 1) and (lifecyclehandler._validateStringDataType('server', server, 'upgrade') == 1) and (lifecyclehandler._validateStringDataType('applicationVersion', applicationVersion, 'upgrade') == 1):
        # if the appName is like <application-name>#<version-number> e.g. myapp#V2.0,
        # then pass non versioned app name to doesADFConfigObjExist function.
        appNameNoVersion = lifecyclehandler.getNonVersionedApplicationName(appName)
        if doesADFConfigObjExist(appNameNoVersion, server, applicationVersion):
            origDirectory = webcenterInitialize(server,applicationVersion)
            returnValue = lifecyclehandler.upgradeWebCenterApplication(appName, server, applicationVersion)
            webcenterRestore(origDirectory)
            if returnValue == lifecyclehandler.successStatus:
                helper.webcenterCommandSuccess()
            else:
                helper.webcenterCommandError()
        else:
            helper.webcenterCommandError()
    else:
        helper.webcenterCommandError()

def exportWebCenterApplication(appName, fileName, exportCustomizations=1, exportSecurity=1, exportData=1,server='',applicationVersion=''):
    if (lifecyclehandler._validateStringDataType('appName', appName, 'export') == 1) and (lifecyclehandler._validateStringDataType('server', server, 'export') == 1) and (lifecyclehandler._validateStringDataType('applicationVersion', applicationVersion, 'export') == 1):
        # if the appName is like <application-name>#<version-number> e.g. myapp#V2.0,
        # then pass non versioned app name to doesADFConfigObjExist function.
        appNameNoVersion = lifecyclehandler.getNonVersionedApplicationName(appName)
        if doesADFConfigObjExist(appNameNoVersion, server, applicationVersion):
            origDirectory = webcenterInitialize(server,applicationVersion)
            returnValue = lifecyclehandler.exportWebCenterApplication(appName, fileName, exportCustomizations, exportSecurity, exportData,server,applicationVersion)
            webcenterRestore(origDirectory)
            if returnValue == lifecyclehandler.successStatus:
                helper.webcenterCommandSuccess()
            else:
                helper.webcenterCommandError()
        else:
            helper.webcenterCommandError()
    else:
        helper.webcenterCommandError()

def importWebCenterApplication(appName, fileName, server='', applicationVersion=''):
    if (lifecyclehandler._validateStringDataType('appName', appName, 'import') == 1) and (lifecyclehandler._validateStringDataType('server', server, 'import') == 1) and (lifecyclehandler._validateStringDataType('applicationVersion', applicationVersion, 'import') == 1):
        # if the appName is like <application-name>#<version-number> e.g. myapp#V2.0,
        # then pass non versioned app name to doesADFConfigObjExist function.
        # For custom apps with versions, the Lifecycle MBean is registered with a version number appended 
        # to the application name for the application, and ADF MBeans are registered with only the application name.
        # doesADFConfigObjExist uses ADF MBean, hence it will require no version app name, if the user has paased the 
        # appName like: <application-name>#<version-number>.
        appNameNoVersion = lifecyclehandler.getNonVersionedApplicationName(appName)
        if doesADFConfigObjExist(appNameNoVersion, server, applicationVersion):
            origDirectory = webcenterInitialize(server,applicationVersion)
            returnValue = lifecyclehandler.importWebCenterApplication(appName, fileName, server, applicationVersion)
            webcenterRestore(origDirectory)
            if returnValue == lifecyclehandler.successStatus:
                helper.webcenterCommandSuccess()
            else:
                helper.webcenterCommandError()
        else:
            helper.webcenterCommandError()
    else:
        helper.webcenterCommandError()

def exportPortletClientMetadata(appName, fileName, exportPersonalizations=1, server='',applicationVersion=''):
    if (lifecyclehandler._validateStringDataType('appName', appName, 'export') == 1) and (lifecyclehandler._validateStringDataType('server', server, 'export') == 1) and (lifecyclehandler._validateStringDataType('applicationVersion', applicationVersion, 'export') == 1):
        # if the appName is like <application-name>#<version-number> e.g. myapp#V2.0,
        # then pass non versioned app name to doesADFConfigObjExist function.
        appNameNoVersion = lifecyclehandler.getNonVersionedApplicationName(appName)
        if doesADFConfigObjExist(appNameNoVersion, server, applicationVersion):
            origDirectory = webcenterInitialize(server,applicationVersion)
            returnValue = lifecyclehandler.exportPortletClientMetadata(appName, fileName, exportPersonalizations, server,applicationVersion)
            webcenterRestore(origDirectory)
            if returnValue == lifecyclehandler.successStatus:
                helper.webcenterCommandSuccess()
            else:
               helper.webcenterCommandError()
        else:
            helper.webcenterCommandError()
    else:
        helper.webcenterCommandError()

def importPortletClientMetadata(appName, fileName,server='',applicationVersion=''):
    if (lifecyclehandler._validateStringDataType('appName', appName, 'import') == 1) and (lifecyclehandler._validateStringDataType('server', server, 'import') == 1) and (lifecyclehandler._validateStringDataType('applicationVersion', applicationVersion, 'import') == 1):
        # if the appName is like <application-name>#<version-number> e.g. myapp#V2.0,
        # then pass non versioned app name to doesADFConfigObjExist function.
        appNameNoVersion = lifecyclehandler.getNonVersionedApplicationName(appName)
        if doesADFConfigObjExist(appNameNoVersion, server, applicationVersion):
            origDirectory = webcenterInitialize(server,applicationVersion)
            returnValue = lifecyclehandler.importPortletClientMetadata(appName, fileName,server,applicationVersion)
            webcenterRestore(origDirectory)
            if returnValue == lifecyclehandler.successStatus:
                helper.webcenterCommandSuccess()
            else:
                helper.webcenterCommandError()
        else:
            helper.webcenterCommandError()
    else:
        helper.webcenterCommandError()
		
def exportProducerMetadata(appName, fileName, exportPersonalizations=1, server='', applicationVersion=''):
    if (lifecyclehandler._validateStringDataType('appName', appName, 'export') == 1) and (lifecyclehandler._validateStringDataType('server', server, 'export') == 1) and (lifecyclehandler._validateStringDataType('applicationVersion', applicationVersion, 'export') == 1):
        # if the appName is like <application-name>#<version-number> e.g. myapp#V2.0,
        # then pass non versioned app name to doesADFConfigObjExist function.
        appNameNoVersion = lifecyclehandler.getNonVersionedApplicationName(appName)
        if doesADFConfigObjExist(appNameNoVersion, server, applicationVersion):
            origDirectory = webcenterInitialize(server,applicationVersion)
            returnValue = lifecyclehandler.exportProducerMetadata(appName, fileName, exportPersonalizations, server, applicationVersion)
            webcenterRestore(origDirectory)
            if returnValue == lifecyclehandler.successStatus:
                helper.webcenterCommandSuccess()
            else:
                helper.webcenterCommandError()
        else:
            helper.webcenterCommandError()
    else:
        helper.webcenterCommandError()

def importProducerMetadata(appName, fileName, server='', applicationVersion=''):
    if (lifecyclehandler._validateStringDataType('appName', appName, 'import') == 1) and (lifecyclehandler._validateStringDataType('server', server, 'import') == 1) and (lifecyclehandler._validateStringDataType('applicationVersion', applicationVersion, 'import') == 1):
        # if the appName is like <application-name>#<version-number> e.g. myapp#V2.0,
        # then pass non versioned app name to doesADFConfigObjExist function.
        appNameNoVersion = lifecyclehandler.getNonVersionedApplicationName(appName)
        if doesADFConfigObjExist(appNameNoVersion, server, applicationVersion): 
            origDirectory = webcenterInitialize(server,applicationVersion)
            returnValue = lifecyclehandler.importProducerMetadata(appName, fileName, server, applicationVersion)
            webcenterRestore(origDirectory)
            if returnValue == lifecyclehandler.successStatus:
                helper.webcenterCommandSuccess()
            else:
                helper.webcenterCommandError()
        else:
            helper.webcenterCommandError()
    else:
        helper.webcenterCommandError()    

def upgradeWebCenterDomain(domainDirName, oracleHome=None, upgradeCustomSpaces=false):
    webcenterHideDisplayReturnValue()
    if mbs is not None:
        disconnect()
    _doUpgradeWebCenterDomain(domainDirName, oracleHome, upgradeCustomSpaces)
    webcenterRestoreDisplay()

def upgradeWebCenterPermissions():
    origDirectory = webcenterInitialize('','')
    if origDirectory is not None:
        _doUpgradeWebCenterPermissions()
    webcenterRestore(origDirectory)

# =============================================================================
# Helper Functions
# =============================================================================
def _doUpgradeWebCenterDomain(domainDirName, oracleHome, upgradeCustomSpaces):
    upgradeJRF(domainDirName)

    oh = oracleHome
    if oh is None:
      oh = System.getProperty('ORACLE_HOME')

    readDomain(domainDirName)
    document = _readConfigGroups(domainDirName)

    # Upgrade the wiki files
    _copyWikiFiles(oh)

    # Remove the OWSM Startup class
    _removeStartupClass('OWSM Startup class', document)

    # Update the cmis shared-libs
    targetLibName = 'content-management-cmis-base-web-lib#10.3.2@10.3.2'
    _addLibrary(libName='cmis-web-lib#11.1.1@11.1.1',
                sourcePath=_path(oh, 'webcenter/modules/oracle.webcenter.content.integration_11.1.1/cmis-web-lib.war'),
                moduleType='war',
                targetLibName=targetLibName,
                configGroupsDoc=document)
    _removeLibrary('content-management-cmis-base-web-lib#10.3.2@10.3.2', document)
    _removeLibrary('content-management-cmis-rest-web-lib#10.3.2@10.3.2', document)
    _removeLibrary('content-management-jps-cmis-rest-app-lib#10.3.2@10.3.2', document)

    # Update the content-web-lib shared-libs
    targetLibName = 'content-management-web-lib#10.3.2@10.3.2'
    _addLibrary(libName='content-web-lib#11.1.1@11.1.1',
                sourcePath=_path(oh, 'webcenter/modules/oracle.webcenter.content.integration_11.1.1/content-web-lib.war'),
                moduleType='war',
                targetLibName=targetLibName,
                configGroupsDoc=document)
    _removeLibrary('content-management-web-lib#10.3.2@10.3.2', document)
    _removeLibrary('content-management-faces-web-lib#10.3.2@10.3.2', document)

    # Update the content-app-lib shared-lib
    targetLibName = 'vcr-app-lib#10.3.2@10.3.2'
    _addLibrary(libName='content-app-lib#11.1.1@11.1.1',
                sourcePath=_path(oh, 'webcenter/modules/oracle.webcenter.content.integration_11.1.1/content-app-lib.ear'),
                moduleType='ear',
                targetLibName=targetLibName,
                configGroupsDoc=document)
    _removeLibrary('vcr-app-lib#10.3.2@10.3.2', document)

    # Update the jaxrs shared-lib
    targetLibName = 'jaxrs-framework-web-lib#10.3.2@10.3.2'
    _addLibrary(libName='jaxrs-framework-web-lib#10.3.2@10.3.2',
                sourcePath=_path(oh, 'webcenter/modules/oracle.webcenter.jaxrs-framework_10.3.2.0/jaxrs-framework-web-lib.war'),
                moduleType='war',
                targetLibName=targetLibName)


    # Update the ridc shared-lib
    targetLibName = 'oracle-ridc-client-app-lib#10.3.2@10.3.2'
    _addLibrary(libName='oracle.ucm.ridc.app-lib#11.1.1@11.1.1',
                sourcePath=_path(oh, 'ucm/Distribution/RIDC/oracle.ucm.ridc.app-lib-11.1.1.ear'),
                moduleType='ear',
                targetLibName=targetLibName,
                securityDdModel=None,
                deploymentOrder=100,
                configGroupsDoc=document)
    _removeLibrary('oracle-ridc-client-app-lib#10.3.2@10.3.2', document)
    _removeLibrary('oracle-ucm-spi-app-lib#10.3.2@10.3.2', document)

    # Update the forum shared-lib
    targetLibName = 'oracle.webcenter.jive.dependency#11.1.1@11.1.1'
    _addLibrary(libName='oracle.webcenter.forum.dependency#11.1.1@11.1.1',
                sourcePath=_path(oh, 'webcenter/modules/oracle.webcenter.framework_11.1.1/oracle.webcenter.forum.dep.ear'),
                moduleType='ear',
                targetLibName=targetLibName,
                configGroupsDoc=document)

    # Update the framework shared-libs
    targetLibName = 'oracle.webcenter.framework#11.1.1@11.1.1'
    _addLibrary(libName='oracle.webcenter.framework.core#11.1.1@11.1.1',
                sourcePath=_path(oh, 'webcenter/modules/oracle.webcenter.framework_11.1.1/oracle.webcenter.framework.core.ear'),
                moduleType='ear',
                targetLibName=targetLibName,
                configGroupsDoc=document)
    _addLibrary(libName='wcps-util-app-lib#11.1.1@11.1.1',
                sourcePath=_path(oh, 'webcenter/modules/wcps-util_11.1.1/wcps-util-app-lib.ear'),
                moduleType='ear',
                targetLibName=targetLibName,
                configGroupsDoc=document)
    _addLibrary(libName='wcps-services-client-web-lib#11.1.1.4.0@11.1.1.4.0',
                sourcePath=_path(oh, 'webcenter/modules/wcps-services-client_11.1.1.4.0/wcps-services-client-web-lib.war'),
                moduleType='war',
                targetLibName=targetLibName,
                configGroupsDoc=document)
    _addLibrary(libName='oracle.webcenter.activitygraph.lib#11.1.1@11.1.1',
                sourcePath=_path(oh, 'activitygraph/modules/oracle.webcenter.activitygraph_11.1.1/oracle.webcenter.activitygraph.lib.ear'),
                moduleType='ear',
                targetLibName=targetLibName,
                configGroupsDoc=document)
    _addLibrary(libName='oracle.webcenter.spaces.fwk#11.1.1@11.1.1',
                sourcePath=_path(oh, 'webcenter/modules/oracle.webcenter.spaces_11.1.1/oracle.webcenter.spaces.fwk.ear'),
                moduleType='ear',
                targetLibName=targetLibName,
                configGroupsDoc=document)
    

    # Update the portlet shared-libs
    targetLibName = 'oracle.portlet-producer.wsrp#11.1.1@11.1.1'
    _addLibrary(libName='oracle.portlet-producer.jpdk#11.1.1@11.1.1',
               sourcePath=_path(oh, '../oracle_common/webcenter/modules/oracle.portlet.server_11.1.1/oracle.producer.jpdk.war'),
               moduleType='war',
               targetLibName=targetLibName,
               configGroupsDoc=document)
    _addLibrary(libName='oracle.portlet-producer.wsrp#11.1.1@11.1.1',
               sourcePath=_path(oh, '../oracle_common/webcenter/modules/oracle.portlet.server_11.1.1/oracle.producer.wsrp.war'),
               moduleType='war',
               targetLibName=targetLibName,
               configGroupsDoc=document)
    _addLibrary(libName='wc-producer-web-lib#11.1.1@11.1.1',
               sourcePath=_path(oh, '../oracle_common/webcenter/modules/oracle.portlet.server_11.1.1/wc-producer-web-lib.war'),
               moduleType='war',
               targetLibName=targetLibName,
               configGroupsDoc=document)
    _addLibrary(libName='wlp-framework-common-web-lib#11.1.1@11.1.1',  
               sourcePath=_path(oh, '../oracle_common/webcenter/modules/oracle.portlet.server_11.1.1/wlp-framework-common-web-lib.war'),
               moduleType='war',
               targetLibName=targetLibName,
               configGroupsDoc=document)
    _addLibrary(libName='wlp-light-core-web-lib#11.1.1@11.1.1',
               sourcePath=_path(oh, '../oracle_common/webcenter/modules/oracle.portlet.server_11.1.1/wlp-light-core-web-lib.war'),
               moduleType='ear',
               targetLibName=targetLibName,
               configGroupsDoc=document)
    _addLibrary(libName='wlp-producer-full-web-lib#11.1.1@11.1.1',
               sourcePath=_path(oh, '../oracle_common/webcenter/modules/oracle.portlet.server_11.1.1/wlp-producer-full-web-lib.war'),
               moduleType='ear',
               targetLibName=targetLibName,
               configGroupsDoc=document)
    _addLibrary(libName='wlp-wsrp-producer-core-web-lib#11.1.1@11.1.1',
               sourcePath=_path(oh, '../oracle_common/webcenter/modules/oracle.portlet.server_11.1.1/wlp-wsrp-producer-core-web-lib.war'),
               moduleType='war',
               targetLibName=targetLibName,
               configGroupsDoc=document)

    # Target the new resource required for the discussions app
    target = _getAppTarget('owc_discussions#11.1.1.2.0')
    if (target != None):
        if (_isAppDeployed('wsm-pm')):
            assign('AppDeployment','wsm-pm','Target',target)
        if (_isDataSourceDeployed('mds-owsm')):
            _assignDataSource('mds-owsm',target)        

    # Add the mapping for the analytics datasource to config-groups
    if (_isAppDeployed('webcenter')):
        _addAnalyticsToConfigGroups(document)

    # Rename the webcenter app
    _renameApp('webcenter', 'webcenter#11.1.1.4.0', domainDirName, document)

    # Rename webcenter help
    _renameApp('webcenter-help#11.1.1.2.0', 'webcenter-help#11.1.1.4.0', domainDirName, document)

    # Rename wsrp-tools
    _renameApp('wsrp-tools#11.1.1.2.0', 'wsrp-tools#11.1.1.4.0', domainDirName, document)

    # Rename wsrp-samples
    _renameApp('wsrp-samples#11.1.1.2.0', 'wsrp-samples#11.1.1.4.0', domainDirName, document)

    # Rename WebCenterWorklistDetailApp
    _renameApp('WebCenterWorklistDetailApp#11.1.1.2.0', 'WebCenterWorklistDetailApp#11.1.1.4.0', domainDirName, document)

    # Rename service-producer
    _renameApp('service-producer#11.1.1.2.0', 'service-producer#11.1.1.4.0', domainDirName, document)

    # Rename portalTools 
    _renameApp('portalTools#11.1.1.2.0', 'portalTools#11.1.1.4.0', domainDirName, document)

    # Rename owc_discussions
    _renameApp('owc_discussions#11.1.1.2.0', 'owc_discussions#11.1.1.4.0', domainDirName, document)

    # Rename the managed servers
    _renameServersWithPrefix('WLS_Spaces', 'WC_Spaces', domainDirName, document)
    _renameServersWithPrefix('WLS_Portlet', 'WC_Portlet', domainDirName, document)
    _renameServersWithPrefix('WLS_Services', 'WC_Collaboration', domainDirName, document)

    updateDomain()
    closeDomain()
    _updateConfigGroups(domainDirName, document)
    _upgradeDatabaseConfig(domainDirName)
 
    # Add new templates to fix the config-groups
    readDomain(domainDirName)
    if (_isLibraryDeployed('oracle.webcenter.skin#11.1.1@11.1.1')):
        _safeAddTemplate(_path(oh, '../oracle_common/common/templates/applications/oracle.wc_skin_template_11.1.1.jar'))
    if (_isLibraryDeployed('oracle.webcenter.composer#11.1.1@11.1.1')):
        _safeAddTemplate(_path(oh, '../oracle_common/common/templates/applications/oracle.wc_composer_template_11.1.1.jar'))

    # Add the Spaces Custom lib patch template
    if (_isLibraryDeployed('custom.webcenter.spaces.fwk#11.1.1@11.1.1')):
        _safeAddTemplate(_path(oh, 'webcenter/scripts/upgrade_11.1.1.4/template/oracle.patch_wc_custom_spaces_lib_template_11.1.1.jar'))

    updateDomain()
    closeDomain()

    #target the new Spaces custom shared lib
    readDomain(domainDirName)
    document = _readConfigGroups(domainDirName)
    
    target = _getAppTarget('webcenter#11.1.1.4.0')
    if (target != None):
       assign('Library', 'extend.spaces.webapp#11.1.1@11.1.1', 'Target', target)
       _addLibraryToConfigGroups(document, 'custom.webcenter.spaces.fwk#11.1.1@11.1.1', 'extend.spaces.webapp#11.1.1@11.1.1')

    updateDomain()
    closeDomain()
    _updateConfigGroups(domainDirName, document)

    # Deploy the ApplCore Stub libraries
    readDomain(domainDirName)

    target = _getAppTarget('webcenter#11.1.1.4.0')
    if (target != None):
      # Add the ApplCore Stub template
      _safeAddTemplate(_path(oh, '../oracle_common/common/templates/applications/oracle.applcore.model.stub.11.1.1_template.jar'))
      assign('Library', 'oracle.applcore.model#0.1@11.1.1.0.0', 'Target', target)
      assign('Library', 'oracle.applcore.view#0.1@11.1.1.0.0', 'Target', target)

    updateDomain()
    closeDomain()

    if upgradeCustomSpaces:
        readDomain(domainDirName)
        _linkExtendSpacesWebappToCustomWebCenterSpaces(oh)
        closeDomain()

    helper.wcPrintMessage('LF_UPGRADE_DOMAIN_COMPLETED') 

def _assignDataSource(dsName, target):
    assign('JDBCSystemResource',dsName,'Target',target)
    cd('/JDBCSystemResource/')
    cd(dsName)
    cd('JdbcResource')
    cd(dsName)
    cd('JDBCDataSourceParams')
    if (_exists('NO_NAME_0')):
        cd('NO_NAME_0')
        dataSourceList = get('DataSourceList')
        if (dataSourceList is not None):
            for d in String(dataSourceList).split(','):
                _assignDataSource(d, target)

def _exists(name):
    entries = ls(returnMap='true', returnType='c')
    for e in entries:
        if (e == name):
            return true
    return false

def _copyWikiFiles(oracleHome):
    if (_isAppDeployed('owc_wiki#11.1.1.2.0')):
        destpath = _getSourcePath('owc_wiki#11.1.1.2.0', 'AppDeployment')
        if (destpath.exists() and destpath.isDirectory()):
            backup = None
            appconfig = File(destpath, 'WEB-INF/classes/application_config.script')
            if (appconfig.exists()):
                backup = File.createTempFile('application_config','script')
                FileUtils.copyFile(appconfig, backup)
            srcpath = File(oracleHome, 'wikiserver/owc_wiki')
            FileUtils.copyDirectory(srcpath, destpath)
            if (backup != None):
                FileUtils.copyFile(backup, appconfig)
                backup.delete()

def _linkExtendSpacesWebappToCustomWebCenterSpaces(oracleHome):
    if (_isLibraryDeployed('extend.spaces.webapp#11.1.1@11.1.1')):
        appdir = _getSourcePath('extend.spaces.webapp#11.1.1@11.1.1', 'Library')
        destpath = File(appdir, 'WEB-INF/weblogic.xml')
        if (destpath.exists()):
            srcpath = File(oracleHome, 'webcenter/scripts/upgrade_11.1.1.4/extend_spaces_weblogic.xml')
            FileUtils.copyFile(srcpath, destpath)


def _getSourcePath(name, resourceType):
    cd('/')
    cd(resourceType)
    cd(name)
    return File(get('SourcePath'))

def _readXmlDocument(xmlFile):
    doc = None
    if (xmlFile.exists()):
        factory = DocumentBuilderFactory.newInstance()
        builder = factory.newDocumentBuilder()
        input = FileInputStream(xmlFile)
        doc = builder.parse(input)
        input.close()
    return doc

def _updateXmlDocument(xmlFile, doc):
    if (doc != None):
        output = FileOutputStream(xmlFile)
        TransformerFactory.newInstance().newTransformer().transform(DOMSource(doc), StreamResult(output))   
        output.close()

def _readConfigGroups(domainDirName):
    configGroupsFile = File(domainDirName, 'init-info/config-groups.xml')
    return _readXmlDocument(configGroupsFile)

def _updateConfigGroups(domainDirName, configGroupsDoc):
    configGroupsFile = File(domainDirName, 'init-info/config-groups.xml')
    _updateXmlDocument(configGroupsFile, configGroupsDoc)

def _upgradeDatabaseConfig(domainDirName):
    dbFile = File(domainDirName, 'init-info/database.xml')
    dbDoc = _readXmlDocument(dbFile)
    if (dbDoc != None):
        sqlNodes = dbDoc.getElementsByTagName('sql-statement')
        if (sqlNodes != None and sqlNodes.getLength() > 0):
            for i in range(0, sqlNodes.getLength()):
                sql = sqlNodes.item(i)
                text = sql.getFirstChild()
                if (text != None and (text.getNodeType() == Node.TEXT_NODE or text.getNodeType() == Node.CDATA_SECTION_NODE) and text.getData() != None):
                    text.setData(String(text.getData()).replaceAll('\\s*and\\s*version=\'11\\.1\\.1\\.2\\.0\'',''))
    _updateXmlDocument(dbFile, dbDoc)

def _getGroupNodesWithElement(configGroupsDoc, tagName, name):
    groups = ArrayList()
    elements = configGroupsDoc.getElementsByTagName(tagName)
    if (elements != None and elements.getLength() > 0):
        for i in range(0, elements.getLength()):
            element = elements.item(i)
            parent = element.getParentNode()
            if (element.getAttribute('name') == name and parent.getNodeName() == 'group'):
                groups.add(parent)
    return groups

def _removeElementFromGroupNode(groupElement, tagName, name):
    elements = groupElement.getElementsByTagName(tagName)
    if (elements != None and elements.getLength() > 0):
        for i in range(0, elements.getLength()):
            element = elements.item(i)
            if (element.getAttribute('name') == name):
                groupElement.removeChild(element)
                return

def _removeElementFromConfigGroups(configGroupsDoc, tagName, name):
    if (configGroupsDoc != None):
        for g in _getGroupNodesWithElement(configGroupsDoc, tagName, name):
            _removeElementFromGroupNode(g, tagName, name)

def _removeLibraryFromConfigGroups(configGroupsDoc, libName):
    _removeElementFromConfigGroups(configGroupsDoc, 'library', libName)

def _removeStartupClassFromConfigGroups(configGroupsDoc, className):
    _removeElementFromConfigGroups(configGroupsDoc, 'startup-class', className)

def _isLibraryInConfigGroup(groupElement, libName):
    libraryNodes = groupElement.getElementsByTagName('library')
    if (libraryNodes != None and libraryNodes.getLength() > 0):
        for i in range(0, libraryNodes.getLength()):
            library = libraryNodes.item(i)
            if (library.getAttribute('name') == libName):
                return true
    return false

def _addLibraryToConfigGroups(configGroupsDoc, targetLibName, libName):
    if (configGroupsDoc != None):
        for g in _getGroupNodesWithElement(configGroupsDoc, 'library', targetLibName):
            if (not _isLibraryInConfigGroup(g, libName)):
                libraryElmt = configGroupsDoc.createElement('library')
                libraryElmt.setAttribute('name', libName)
                g.appendChild(libraryElmt)

def _renameServerInConfigGroups(configGroupsDoc, oldName, newName):
    if (configGroupsDoc != None):
        serverNodes = configGroupsDoc.getElementsByTagName('server-name')
        if (serverNodes != None and serverNodes.getLength() > 0):
            for i in range(0, serverNodes.getLength()):
                server = serverNodes.item(i)
                text = server.getFirstChild()
                if (text != None and (text.getNodeType() == Node.TEXT_NODE or text.getNodeType() == Node.CDATA_SECTION_NODE) and text.getData() == oldName):
                    text.setData(newName)

def _renameServerConfigDirectory(domainDirName, oldServerName, newServerName):
    serversDirectory = File(domainDirName, 'config/fmwconfig/servers')
    oldDirectory = File(serversDirectory, oldServerName)
    newDirectory = File(serversDirectory, newServerName)
    if (oldDirectory.exists() and oldDirectory.isDirectory() and not newDirectory.exists()):
        oldDirectory.renameTo(newDirectory)

def _renameAppInConfigGroups(configGroupsDoc, oldName, newName):
    if (configGroupsDoc != None):
        appNodes = configGroupsDoc.getElementsByTagName('app-deployment')
        if (appNodes != None and appNodes.getLength() > 0):
            for i in range(0, appNodes.getLength()):
                app = appNodes.item(i)
                if (app != None and app.getNodeType() == Node.ELEMENT_NODE and app.getAttribute('name') == oldName):
                    app.setAttribute('name', newName)

def _renameAppConfigDirectory(domainDirName, oldApplicationName, newApplicationName):
    serversDirectory = File(domainDirName, 'config/fmwconfig/servers')
    if (serversDirectory.exists() and serversDirectory.isDirectory()):
        for s in serversDirectory.listFiles():
            applicationsDirectory = File(s, 'applications')
            oldDirectory = File(applicationsDirectory, String(oldApplicationName).replace('#','_'))
            newDirectory = File(applicationsDirectory, String(newApplicationName).replace('#','_'))
            if (oldDirectory.exists() and oldDirectory.isDirectory() and not newDirectory.exists()):
                oldDirectory.renameTo(newDirectory)

def _addAnalyticsToConfigGroups(configGroupsDoc):
    if (configGroupsDoc != None):
        domainTopNodes = configGroupsDoc.getElementsByTagName('domain-topology')
        if (domainTopNodes != None and domainTopNodes.getLength() > 0):
            domainTop = domainTopNodes.item(0)
            mapping = configGroupsDoc.createElement('app-svc-group-mapping')
            domainTop.appendChild(mapping)
            appGroup = configGroupsDoc.createElement('app-svc-group')
            mapping.appendChild(appGroup)
            appGroup.appendChild(configGroupsDoc.createTextNode('ACTIVITIES-DS'))
            serverGroup = configGroupsDoc.createElement('target-server-group')
            mapping.appendChild(serverGroup)
            serverGroup.appendChild(configGroupsDoc.createTextNode('SPACES-MGD-SVRS'))

def _path(parent, child):
    f = File(parent, child)
    return f.getCanonicalPath()

def _addLibrary(libName, sourcePath, moduleType, targetLibName, securityDdModel='DDOnly', deploymentOrder=300, configGroupsDoc=None):
    _addLibraryToConfigGroups(configGroupsDoc, targetLibName, libName)
    target = _getLibraryTarget(targetLibName)
    if (target == None):
        return
    if (not _isLibraryDeployed(libName)):
        cd('/')
        create(libName, 'Library')
    cd('/Library')
    cd(libName)
    set('SourcePath', sourcePath)
    set('ModuleType', moduleType)
    if (securityDdModel != None):
        set('SecurityDdModel', securityDdModel)
    set('DeploymentOrder', deploymentOrder)
    set('StagingMode', 'nostage')
    assign('Library', libName, 'Target', target)

def _isResourceDeployed(name, resourceType):
    cd('/')
    resources = ls(resourceType, returnMap='true', returnType='c')
    for r in resources:
        if (r == name):
            return true
    return false

def _isLibraryDeployed(libName):
    return _isResourceDeployed(libName, 'Library')

def _isAppDeployed(appName):
    return _isResourceDeployed(appName, 'AppDeployment')

def _isStartupClassDeployed(className):
    return _isResourceDeployed(className, 'StartupClass')

def _serverExists(serverName):
    return _isResourceDeployed(serverName, 'Server')

def _isDataSourceDeployed(dsName):
    return _isResourceDeployed(dsName, 'JDBCSystemResource')

def _getServersWithPrefix(prefix):
    servers = ArrayList()
    cd('/')
    resources = ls('Server', returnMap='true', returnType='c')
    for r in resources:
        if (String(r).startsWith(prefix)):
            servers.add(r)
    return servers

def _renameServer(oldName, newName, domainDirName, configGroupsDoc=None):
    if (_serverExists(oldName) and not _serverExists(newName)):
        _renameServerInConfigGroups(configGroupsDoc, oldName, newName)
        _renameServerConfigDirectory(domainDirName, oldName, newName)
        cd('/Server')
        cd(oldName)
        set('Name', newName)

def _renameServersWithPrefix(oldPrefix, newPrefix, domainDirName, configGroupsDoc=None):
    for s in _getServersWithPrefix(oldPrefix):
        newName = newPrefix + String(s).substring(len(oldPrefix))
        _renameServer(s, newName, domainDirName, configGroupsDoc)

def _renameApp(oldName, newName, domainDirName, configGroupsDoc=None):
    if (_isAppDeployed(oldName) and not _isAppDeployed(newName)):
        _renameAppInConfigGroups(configGroupsDoc, oldName, newName)
        _renameAppConfigDirectory(domainDirName, oldName, newName)
        cd('/AppDeployment')
        cd(oldName)
        set('Name', newName)

def _removeLibrary(libName, configGroupsDoc=None):
    _removeLibraryFromConfigGroups(configGroupsDoc, libName)
    if (_isLibraryDeployed(libName)):
        cd('/')
        delete(libName, 'Library')

def _removeStartupClass(className, configGroupsDoc=None):
    _removeStartupClassFromConfigGroups(configGroupsDoc, className)
    if (_isStartupClassDeployed(className)):
        cd('/')
        delete(className, 'StartupClass')

def _getResourceTarget(name, resourceType):
    target = None
    if (_isResourceDeployed(name, resourceType)):
        cd('/')
        cd(resourceType)
        cd(name)
        targets = get('Target')
        for t in targets:
            if (target == None):
                target = t.name
            else:
                target += ',' + t.name
    return target

def _getLibraryTarget(libName):
    return _getResourceTarget(libName, 'Library')

def _getAppTarget(appName):
    return _getResourceTarget(appName, 'AppDeployment')

def _safeAddTemplate(templateFileName):
    try:
        addTemplate(templateFileName)
    except:
        pass 

def _safeRevokePermission(appStripe=None, principalClass=None, principalName=None, codeBaseURL=None, permClass=None, permTarget=None, permActions=None):
    try:
        revokePermission(appStripe      = appStripe,
                         principalClass = principalClass,
                         principalName  = principalName,
                         codeBaseURL    = codeBaseURL,
                         permClass      = permClass,
                         permTarget     = permTarget,
                         permActions    = permActions)
    except:
        pass

def _safeGrantPermission(appStripe=None, principalClass=None, principalName=None, codeBaseURL=None, permClass=None, permTarget=None, permActions=None):
    try:
        grantPermission(appStripe      = appStripe,
                        principalClass = principalClass,
                        principalName  = principalName,
                        codeBaseURL    = codeBaseURL,
                        permClass      = permClass,
                        permTarget     = permTarget,
                        permActions    = permActions)
        return true
    except:
        return false

def _safeCreateAppRole(appStripe, appRoleName):
    try:
        createAppRole(appStripe   = appStripe,
                      appRoleName = appRoleName)
        return true
    except:
        return false

def _doUpgradeWebCenterPermissions():
    error = false
    summaryPolicy = ''
    try:
        summaryPolicy = restoreWCPortalWSPolicies()
    except:
        error = true
    try:
        _doUpgradeWebCenterCodeBasePermissions()
    except:
        error = true
    error = not _doUpgradeWebCenterAppPermissions() or error
    print summaryPolicy
    if error:
        helper.wcPrintErrorMessage('LF_UPGRADE_PERMISSIONS_FAILED')
    else:
        helper.wcPrintMessage('LF_UPGRADE_PERMISSIONS_COMPLETED')

def _doUpgradeWebCenterCodeBasePermissions():
    grantPermission(codeBaseURL="file:${common.components.home}/modules/oracle.wsm.agent.common_11.1.1/wsm-agent-core.jar",
                    permClass="oracle.wsm.security.WSIdentityPermission",
                    permTarget="resource=webcenter",
                    permActions="assert")
    #-- 11.1.1.8.0 Start
    grantPermission(codeBaseURL="file:${domain.home}/servers/${weblogic.Name}/tmp/_WL_user/oracle.webcenter.framework.core/-",
                    permClass="oracle.security.jps.service.audit.AuditStoreAccessPermission",
                    permTarget="webcenter#11.1.1.4.0",
                    permActions="read")
    #-- 11.1.1.8.0 End

def _doUpgradeWebCenterAppPermissions():
    error = false
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#defaultauthenticated",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_taskflow_view_SpacesContainerPageDef",
                                  permActions="update") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sb175bdde_4cb8_4da8_bcdb_eff13e59da2d#-#Moderator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_sb175bdde_4cb8_4da8_bcdb_eff13e59da2d_.*",
                                  permActions="manage") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#defaultadministrator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="*",
                                  permActions="manage") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#defaultpublic",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="o_w_p_s_s8bba98ff_4cbb_40b8_beee_296c916a23ed_system_pages_public_view_authenticated_edit",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#defaultpublic",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_sitetemplate_view_SpacesSiteTemplateEditingPageDef",
                                  permActions="customize,update,view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#defaultpublic",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_taskflow_view_SpacesContainerPageDef",
                                  permActions="view") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Spaces-User",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_SpaceTemplatesMainViewPageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Spaces-User",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_TagCenterMainViewPageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Spaces-User",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="o_w_p_s_s8bba98ff_4cbb_40b8_beee_296c916a23ed_system_pages_public_view_authenticated_edit",
                                  permActions="update") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Spaces-User",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="o_w_p_s_s8bba98ff_4cbb_40b8_beee_296c916a23ed_system_pages_authenticated_view_authenticated_edit",
                                  permActions="view,update") or error
    # --
    _safeRevokePermission(appStripe="webcenter",
                          principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                          principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Spaces-User",
                          permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                          permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_UserProfileMainViewPageDef",
                          permActions="view")
    # --
    try:
        createAppRole(appStripe="webcenter",
                      appRoleName="AppConnectionManager")
        grantAppRole(appStripe="webcenter",
                     appRoleName="AppConnectionManager",
                     principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                     principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Administrator")
    except:
        error = true
    # --
    try:
        createAppRole(appStripe="webcenter",
                      appRoleName="AppConnectionViewer")
        grantAppRole(appStripe="webcenter",
                     appRoleName="AppConnectionViewer",
                     principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                     principalName="authenticated-role")
    except:
        error = true
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Administrator",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle.webcenter.page.scopedMD.defaultScope.pageDefs.oracle_webcenter_page_scopedMD_defaultScope_pageDefs_page-1159239472PageDef",
                                  permActions="create,manage,view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Administrator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_pagetemplate_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Administrator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_skin_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Administrator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_pagestyle_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Administrator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_taskflowstyle_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Administrator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_taskflow_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Administrator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_datacontrol_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Administrator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_contentpresenter_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Administrator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_catalog_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Administrator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_navigation_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Administrator",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_roles_AnalyticsConsoleMainViewPageDef",
                                  permActions="manage") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Spaces-User",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_DocumentsMainViewPageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Spaces-User",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_ActivityStreamMainViewPageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Spaces-User",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_SpacesMainViewPageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Spaces-User",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_MyProfileMainViewPageDef",
                                  permActions="view") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                                  principalName="authenticated-role",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_DocumentsMainViewPageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                                  principalName="authenticated-role",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_ActivityStreamMainViewPageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                                  principalName="authenticated-role",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_SpacesMainViewPageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                                  principalName="authenticated-role",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_MyProfileMainViewPageDef",
                                  permActions="view") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#defaultpublic",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_UserProfileMainViewPageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#defaultpublic",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_TagCenterMainViewPageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#defaultpublic",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_SpaceMembersPageDef",
                                  permActions="view") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sb175bdde_4cb8_4da8_bcdb_eff13e59da2d#-#Participant",
                                  permClass="oracle.webcenter.security.internal.rolemapping.RoleMappingPermission",
                                  permTarget="oracle.webcenter.collab.forum__4") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sb175bdde_4cb8_4da8_bcdb_eff13e59da2d#-#Participant",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_sb175bdde_4cb8_4da8_bcdb_eff13e59da2d_.*",
                                  permActions="update") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sb175bdde_4cb8_4da8_bcdb_eff13e59da2d#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_sb175bdde_4cb8_4da8_bcdb_eff13e59da2d_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sb175bdde_4cb8_4da8_bcdb_eff13e59da2d#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.security.internal.rolemapping.RoleMappingPermission",
                                  permTarget="oracle.webcenter.doclib__4") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sb175bdde_4cb8_4da8_bcdb_eff13e59da2d#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.security.internal.rolemapping.RoleMappingPermission",
                                  permTarget="oracle.webcenter.collab.forum__1") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sb175bdde_4cb8_4da8_bcdb_eff13e59da2d#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.security.internal.rolemapping.RoleMappingPermission",
                                  permTarget="oracle.webcenter.collab.rtc__1") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sb175bdde_4cb8_4da8_bcdb_eff13e59da2d#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.security.internal.rolemapping.RoleMappingPermission",
                                  permTarget="oracle.webcenter.collab.announcement__1") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sb175bdde_4cb8_4da8_bcdb_eff13e59da2d#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.security.internal.rolemapping.RoleMappingPermission",
                                  permTarget="oracle.webcenter.collab.mail__1") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sb175bdde_4cb8_4da8_bcdb_eff13e59da2d#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.relationship.model.security.RelationshipPermission",
                                  permTarget="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3/.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sb175bdde_4cb8_4da8_bcdb_eff13e59da2d#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.relationship.model.security.RelationshipPermission",
                                  permTarget="sb175bdde_4cb8_4da8_bcdb_eff13e59da2d/.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sb175bdde_4cb8_4da8_bcdb_eff13e59da2d#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.list.model.security.ListPermission",
                                  permTarget="/oracle/webcenter/list/scopedMD/sb175bdde_4cb8_4da8_bcdb_eff13e59da2d/lists/.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sb175bdde_4cb8_4da8_bcdb_eff13e59da2d#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.note.model.security.NotePermission",
                                  permTarget="/oracle/webcenter/note/scopedMD/sb175bdde_4cb8_4da8_bcdb_eff13e59da2d/notes/.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sb175bdde_4cb8_4da8_bcdb_eff13e59da2d#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.collab.calendar.model.security.EventPermission",
                                  permTarget="/oracle/webcenter/collab/calendar/spaces/sb175bdde_4cb8_4da8_bcdb_eff13e59da2d/.*",
                                  permActions="view") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3#-#Moderator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3_.*",
                                  permActions="manage") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3#-#Participant",
                                  permClass="oracle.webcenter.security.internal.rolemapping.RoleMappingPermission",
                                  permTarget="oracle.webcenter.collab.forum__4") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3#-#Participant",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3_.*",
                                  permActions="update") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.security.internal.rolemapping.RoleMappingPermission",
                                  permTarget="oracle.webcenter.doclib__4") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.security.internal.rolemapping.RoleMappingPermission",
                                  permTarget="oracle.webcenter.collab.forum__1") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.security.internal.rolemapping.RoleMappingPermission",
                                  permTarget="oracle.webcenter.collab.rtc__1") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.security.internal.rolemapping.RoleMappingPermission",
                                  permTarget="oracle.webcenter.collab.mail__1") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.security.internal.rolemapping.RoleMappingPermission",
                                  permTarget="oracle.webcenter.collab.announcement__1") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.security.internal.rolemapping.RoleMappingPermission",
                                  permTarget="oracle.webcenter.collab.tasks__1") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.list.model.security.ListPermission",
                                  permTarget="/oracle/webcenter/list/scopedMD/s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3/lists/.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.relationship.model.security.RelationshipPermission",
                                  permTarget="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3/.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.note.model.security.NotePermission",
                                  permTarget="/oracle/webcenter/note/scopedMD/s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3/notes/.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.collab.calendar.model.security.EventPermission",
                                  permTarget="/oracle/webcenter/collab/calendar/spaces/s5dd6d6b3_7f5f_4f1c_8ee6_ce305469f1b3/.*",
                                  permActions="view") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sdfcd3cd3_8a53_4a7c_872f_74de46969cef#-#Moderator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_sdfcd3cd3_8a53_4a7c_872f_74de46969cef_.*",
                                  permActions="manage") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sdfcd3cd3_8a53_4a7c_872f_74de46969cef#-#Participant",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_sdfcd3cd3_8a53_4a7c_872f_74de46969cef_.*",
                                  permActions="update") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sdfcd3cd3_8a53_4a7c_872f_74de46969cef#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.security.internal.rolemapping.RoleMappingPermission",
                                  permTarget="oracle.webcenter.collab.rtc__1") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sdfcd3cd3_8a53_4a7c_872f_74de46969cef#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.security.internal.rolemapping.RoleMappingPermission",
                                  permTarget="oracle.webcenter.collab.mail__1") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sdfcd3cd3_8a53_4a7c_872f_74de46969cef#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_sdfcd3cd3_8a53_4a7c_872f_74de46969cef_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sdfcd3cd3_8a53_4a7c_872f_74de46969cef#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.note.model.security.NotePermission",
                                  permTarget="/oracle/webcenter/note/scopedMD/sdfcd3cd3_8a53_4a7c_872f_74de46969cef/notes/.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sdfcd3cd3_8a53_4a7c_872f_74de46969cef#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.relationship.model.security.RelationshipPermission",
                                  permTarget="sdfcd3cd3_8a53_4a7c_872f_74de46969cef/.*",
                                  permActions="view") or error

    #--Bug 9791879
    _safeRevokePermission(appStripe="webcenter",
                          principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                          principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Administrator",
                          permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                          permTarget="*",
                          permActions="create,manage,view")
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Administrator",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle.webcenter.webcenterapp.bindings.pageDefs.oracle_webcenter_page_scopedMD_defaultScope_roles_WelcomePageDef",
                                  permActions="manage") or error
    # --
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                                  principalName="authenticated-role",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_SpaceTemplatesMainViewPageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                                  principalName="authenticated-role",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_TagCenterMainViewPageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                                  principalName="authenticated-role",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_OutlookEventsPagePageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                                  principalName="authenticated-role",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_OutlookMembersPagePageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                                  principalName="authenticated-role",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_OutlookDocumentsPagePageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                                  principalName="authenticated-role",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_OutlookDiscussionsPagePageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                                  principalName="authenticated-role",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_OutlookHomePagePageDef",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                                  principalName="authenticated-role",
                                  permClass="oracle.adf.rc.security.CatalogPermission",
                                  permTarget="/oracle/webcenter/quicklinks/scopedMD/.*",
                                  permActions="create,edit") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#defaultpublic",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="ps_targetusage",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Spaces-User",
                                  permClass="oracle.adf.controller.security.TaskFlowPermission",
                                  permTarget="oracle/webcenter/peopleconnections/personalweb/view/jsf/regions/profile-gallery.xml#profile-gallery",
                                  permActions="personalize") or error
    # --
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#Moderator") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#Participant") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#Viewer") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#Spaces-User") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#Public-User") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#Moderator") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#Participant") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#Viewer") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#Spaces-User") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#Public-User") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#Moderator") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#Participant") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#Viewer") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#Spaces-User") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#Public-User") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#Moderator") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#Participant") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#Viewer") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#Spaces-User") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#Public-User") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s510da3ff_9660_43e2_8366_27b15972ce62#-#Moderator") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s510da3ff_9660_43e2_8366_27b15972ce62#-#Participant") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s510da3ff_9660_43e2_8366_27b15972ce62#-#Viewer") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s510da3ff_9660_43e2_8366_27b15972ce62#-#Spaces-User") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s510da3ff_9660_43e2_8366_27b15972ce62#-#Public-User") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#Moderator") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#Participant") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#Viewer") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#Spaces-User") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#Public-User") or error
    try:
        createAppRole(appStripe="webcenter",
                      appRoleName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#TemplateSpaces-User")
        grantAppRole(appStripe="webcenter",
                     appRoleName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#TemplateSpaces-User",
                     principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                     principalName="authenticated-role")
    except:
        error = true
    try:
        createAppRole(appStripe="webcenter",
                      appRoleName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#TemplateSpaces-User")
        grantAppRole(appStripe="webcenter",
                     appRoleName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#TemplateSpaces-User",
                     principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                     principalName="authenticated-role")
    except:
        error = true
    try:
        createAppRole(appStripe="webcenter",
                      appRoleName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#TemplateSpaces-User")
        grantAppRole(appStripe="webcenter",
                     appRoleName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#TemplateSpaces-User",
                     principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                     principalName="authenticated-role")
    except:
        error = true
    try:
        createAppRole(appStripe="webcenter",
                      appRoleName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#TemplateSpaces-User")
        grantAppRole(appStripe="webcenter",
                     appRoleName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#TemplateSpaces-User",
                     principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                     principalName="authenticated-role")
    except:
        error = true
    try:
        createAppRole(appStripe="webcenter",
                      appRoleName="s510da3ff_9660_43e2_8366_27b15972ce62#-#TemplateSpaces-User")
        grantAppRole(appStripe="webcenter",
                     appRoleName="s510da3ff_9660_43e2_8366_27b15972ce62#-#TemplateSpaces-User",
                     principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                     principalName="authenticated-role")
    except:
        error = true
    try:
        createAppRole(appStripe="webcenter",
                      appRoleName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#TemplateSpaces-User")
        grantAppRole(appStripe="webcenter",
                     appRoleName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#TemplateSpaces-User",
                     principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                     principalName="authenticated-role")
    except:
        error = true
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#Moderator",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s1dc1888a_2289_4a58_8d86_bda66f6faa30_.*",
                                  permActions="manage,update,personalize,view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#Moderator",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s1dc1888a_2289_4a58_8d86_bda66f6faa30",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#Moderator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s1dc1888a_2289_4a58_8d86_bda66f6faa30_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#Participant",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s1dc1888a_2289_4a58_8d86_bda66f6faa30_.*",
                                  permActions="view,personalize") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#Participant",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s1dc1888a_2289_4a58_8d86_bda66f6faa30",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s1dc1888a_2289_4a58_8d86_bda66f6faa30",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s1dc1888a_2289_4a58_8d86_bda66f6faa30_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#Viewer",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s1dc1888a_2289_4a58_8d86_bda66f6faa30_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s1dc1888a_2289_4a58_8d86_bda66f6faa30#-#Viewer",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s1dc1888a_2289_4a58_8d86_bda66f6faa30",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#Moderator",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2_.*",
                                  permActions="manage,update,personalize,view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#Moderator",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#Moderator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#Participant",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2_.*",
                                  permActions="view,personalize") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#Participant",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#Viewer",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2#-#Viewer",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s8b3f25b3_3f19_4bbd_a5bb_ae3dbe130cc2",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#Moderator",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_sc6eb3db1_0374_48e5_b6ca_13b1c9389269_.*",
                                  permActions="manage,update,personalize,view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#Moderator",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/sc6eb3db1_0374_48e5_b6ca_13b1c9389269",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#Moderator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_sc6eb3db1_0374_48e5_b6ca_13b1c9389269_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#Participant",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_sc6eb3db1_0374_48e5_b6ca_13b1c9389269_.*",
                                  permActions="view,personalize") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#Participant",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/sc6eb3db1_0374_48e5_b6ca_13b1c9389269",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/sc6eb3db1_0374_48e5_b6ca_13b1c9389269",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_sc6eb3db1_0374_48e5_b6ca_13b1c9389269_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#Viewer",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_sc6eb3db1_0374_48e5_b6ca_13b1c9389269_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="sc6eb3db1_0374_48e5_b6ca_13b1c9389269#-#Viewer",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/sc6eb3db1_0374_48e5_b6ca_13b1c9389269",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#Moderator",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s436e28ff_9590_431f_893b_2f55fcf611f0_.*",
                                  permActions="manage,update,personalize,view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#Moderator",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s436e28ff_9590_431f_893b_2f55fcf611f0",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#Moderator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s436e28ff_9590_431f_893b_2f55fcf611f0_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#Participant",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s436e28ff_9590_431f_893b_2f55fcf611f0_.*",
                                  permActions="view,personalize") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#Participant",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s436e28ff_9590_431f_893b_2f55fcf611f0",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s436e28ff_9590_431f_893b_2f55fcf611f0",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s436e28ff_9590_431f_893b_2f55fcf611f0_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#Viewer",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s436e28ff_9590_431f_893b_2f55fcf611f0_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s436e28ff_9590_431f_893b_2f55fcf611f0#-#Viewer",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s436e28ff_9590_431f_893b_2f55fcf611f0",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s510da3ff_9660_43e2_8366_27b15972ce62#-#Moderator",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s510da3ff_9660_43e2_8366_27b15972ce62_.*",
                                  permActions="manage,update,personalize,view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s510da3ff_9660_43e2_8366_27b15972ce62#-#Moderator",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s510da3ff_9660_43e2_8366_27b15972ce62",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s510da3ff_9660_43e2_8366_27b15972ce62#-#Moderator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s510da3ff_9660_43e2_8366_27b15972ce62_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s510da3ff_9660_43e2_8366_27b15972ce62#-#Participant",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s510da3ff_9660_43e2_8366_27b15972ce62_.*",
                                  permActions="view,personalize") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s510da3ff_9660_43e2_8366_27b15972ce62#-#Participant",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s510da3ff_9660_43e2_8366_27b15972ce62",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s510da3ff_9660_43e2_8366_27b15972ce62#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s510da3ff_9660_43e2_8366_27b15972ce62",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s510da3ff_9660_43e2_8366_27b15972ce62#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s510da3ff_9660_43e2_8366_27b15972ce62_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s510da3ff_9660_43e2_8366_27b15972ce62#-#Viewer",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s510da3ff_9660_43e2_8366_27b15972ce62_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s510da3ff_9660_43e2_8366_27b15972ce62#-#Viewer",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s510da3ff_9660_43e2_8366_27b15972ce62",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#Moderator",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_scfe64d73_df30_44ea_9b60_0159680e4dbb_.*",
                                  permActions="manage,update,personalize,view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#Moderator",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/scfe64d73_df30_44ea_9b60_0159680e4dbb",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#Moderator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_scfe64d73_df30_44ea_9b60_0159680e4dbb_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#Participant",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_scfe64d73_df30_44ea_9b60_0159680e4dbb_.*",
                                  permActions="view,personalize") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#Participant",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/scfe64d73_df30_44ea_9b60_0159680e4dbb",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/scfe64d73_df30_44ea_9b60_0159680e4dbb",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_scfe64d73_df30_44ea_9b60_0159680e4dbb_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#Viewer",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_scfe64d73_df30_44ea_9b60_0159680e4dbb_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="scfe64d73_df30_44ea_9b60_0159680e4dbb#-#Viewer",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/scfe64d73_df30_44ea_9b60_0159680e4dbb",
                                  permActions="view") or error
    #--Bug 10226293
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#defaultpublic",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_webcenterapp_view_pages_ListOfAccessiblePagesPageDef",
                                  permActions="view") or error

    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Spaces-User",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle.webcenter.webcenterapp.bindings.pageDefs.oracle_webcenter_webcenterapp_view_pages_peopleconn_MyProfileGalleryPageDef",
                                  permActions="personalize") or error
    # -- Bug8915287 
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#defaultadministrator",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="space/*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#defaultadministrator",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/*",
                                  permActions="manage") or error

    #-- 11.1.1.8.0 Start

    #-- Impersonator Role
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="webcenter#-#impersonators") or error

    #-- Application Specialist
    try:
        createAppRole(appStripe="webcenter",
                      appRoleName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Application Specialist")
    except:
        error = true
        
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Application Specialist",
                                  permClass="oracle.webcenter.webcenterapp.model.security.WebCenterPermission",
                                  permTarget="webcenter",
                                  permActions="view,create-space") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Application Specialist",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Application Specialist",
                                  permClass="oracle.webcenter.peopleconnections.profile.security.ProfilePermission",
                                  permTarget="/oracle/webcenter/peopleconnections/profile/s8bba98ff_4cbb_40b8_beee_296c916a23ed/.*",
                                  permActions="edit,share") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Application Specialist",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Application Specialist",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_pagetemplate_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Application Specialist",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_skin_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Application Specialist",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_pagestyle_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Application Specialist",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_taskflowstyle_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Application Specialist",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_taskflow_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Application Specialist",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_datacontrol_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Application Specialist",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_contentpresenter_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Application Specialist",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_catalog_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Application Specialist",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_navigation_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Application Specialist",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_pagelet_.*",
                                  permActions="manage") or error

    #-- Builder Portal
    try:
        createAppRole(appStripe="webcenter",
                      appRoleName="s5f9c65ed_c93c_4467_96cf_06a82f3dad22#-#Moderator")
    except:
        error = true

    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s5f9c65ed_c93c_4467_96cf_06a82f3dad22#-#Participant") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s5f9c65ed_c93c_4467_96cf_06a82f3dad22#-#Viewer") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s5f9c65ed_c93c_4467_96cf_06a82f3dad22#-#Spaces-User") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s5f9c65ed_c93c_4467_96cf_06a82f3dad22#-#Public-User") or error

    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5f9c65ed_c93c_4467_96cf_06a82f3dad22#-#Moderator",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s5f9c65ed_c93c_4467_96cf_06a82f3dad22_.*",
                                  permActions="manage,personalize,update,view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5f9c65ed_c93c_4467_96cf_06a82f3dad22#-#Moderator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s5f9c65ed_c93c_4467_96cf_06a82f3dad22_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5f9c65ed_c93c_4467_96cf_06a82f3dad22#-#Moderator",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/null",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5f9c65ed_c93c_4467_96cf_06a82f3dad22#-#Moderator",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="space/s5f9c65ed_c93c_4467_96cf_06a82f3dad22",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5f9c65ed_c93c_4467_96cf_06a82f3dad22#-#Participant",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s5f9c65ed_c93c_4467_96cf_06a82f3dad22_.*",
                                  permActions="personalize,view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5f9c65ed_c93c_4467_96cf_06a82f3dad22#-#Participant",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="space/s5f9c65ed_c93c_4467_96cf_06a82f3dad22",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5f9c65ed_c93c_4467_96cf_06a82f3dad22#-#Viewer",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s5f9c65ed_c93c_4467_96cf_06a82f3dad22_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5f9c65ed_c93c_4467_96cf_06a82f3dad22#-#Viewer",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="space/s5f9c65ed_c93c_4467_96cf_06a82f3dad22",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5f9c65ed_c93c_4467_96cf_06a82f3dad22#-#Spaces-User",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s5f9c65ed_c93c_4467_96cf_06a82f3dad22_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s5f9c65ed_c93c_4467_96cf_06a82f3dad22#-#Spaces-User",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="space/s5f9c65ed_c93c_4467_96cf_06a82f3dad22",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#Global-GroupSpaces-Spaces-User",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s5f9c65ed_c93c_4467_96cf_06a82f3dad22_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#Global-GroupSpaces-Spaces-User",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="space/s5f9c65ed_c93c_4467_96cf_06a82f3dad22",
                                  permActions="view") or error

    #-- Portal Template
    try:
        createAppRole(appStripe="webcenter",
                      appRoleName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#TemplateSpaces-User")
        grantAppRole(appStripe="webcenter",
                     appRoleName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#TemplateSpaces-User",
                     principalClass="oracle.security.jps.internal.core.principals.JpsAuthenticatedRoleImpl",
                     principalName="authenticated-role")
    except:
        error = true

    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#Moderator") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#Participant") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#Viewer") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#Spaces-User") or error
    error = not _safeCreateAppRole(appStripe="webcenter",
                                   appRoleName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#Public-User") or error

    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#Moderator",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s3f471f76_35d2_46a8_88f9_313a327c039d_.*",
                                  permActions="manage,update,personalize,view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#Moderator",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s3f471f76_35d2_46a8_88f9_313a327c039d",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#Moderator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s3f471f76_35d2_46a8_88f9_313a327c039d_.*",
                                  permActions="manage") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#Participant",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s3f471f76_35d2_46a8_88f9_313a327c039d_.*",
                                  permActions="view,personalize") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#Participant",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s3f471f76_35d2_46a8_88f9_313a327c039d",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s3f471f76_35d2_46a8_88f9_313a327c039d",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#TemplateSpaces-User",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s3f471f76_35d2_46a8_88f9_313a327c039d_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#Viewer",
                                  permClass="oracle.webcenter.page.model.security.PagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s3f471f76_35d2_46a8_88f9_313a327c039d_.*",
                                  permActions="view") or error
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s3f471f76_35d2_46a8_88f9_313a327c039d#-#Viewer",
                                  permClass="oracle.webcenter.community.model.security.CommunityPermission",
                                  permTarget="spacetemplate/s3f471f76_35d2_46a8_88f9_313a327c039d",
                                  permActions="view") or error
    #-- Pagelet producer
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Administrator",
                                  permClass="oracle.webcenter.security.auth.WebCenterResourcePermission",
                                  permTarget="oracle_webcenter_siteresource_s8bba98ff_4cbb_40b8_beee_296c916a23ed_pagelet_.*",
                                  permActions="manage") or error
    #-- 11.1.1.8.0 End

    #-- 11.1.1.9.0 Begin

    error = not _safeRevokePermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#defaultpublic",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_UserProfileMainViewPageDef",
                                  permActions="view") or error
						  
						  
    error = not _safeRevokePermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="webcenter#-#defaultpublic",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_UserProfileMainView_v2PageDef",
                                  permActions="view") or error

    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Spaces-User",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_UserProfileMainView_v2PageDef",
                                  permActions="view") or error
								  
    error = not _safeGrantPermission(appStripe="webcenter",
                                  principalClass="oracle.security.jps.service.policystore.ApplicationRole",
                                  principalName="s8bba98ff_4cbb_40b8_beee_296c916a23ed#-#Spaces-User",
                                  permClass="oracle.webcenter.page.model.security.CustomPagePermission",
                                  permTarget="oracle_webcenter_page_scopedMD_s8bba98ff_4cbb_40b8_beee_296c916a23ed_businessRolePages_UserProfileMainViewPageDef",
                                  permActions="view") or error
    return not error

    #-- 11.1.1.9.0 End
