/* $Header: workplace/src/apps/webcenter-app/spaces-web/src/javascripts/oracle/webcenter/webcenterapp/jsLibs/WebCenterUtils.js /main/19 2010/03/21 10:05:37 rsampath Exp $ */

/* Copyright (c) 2006, 2010, Oracle and/or its affiliates. 
All rights reserved. */

/*
   DESCRIPTION
    Contains javascript utility methods for common operations
    in the WebCenter App UI.

   NOTES
    <other useful comments, qualifications, etc.>

   MODIFIED    (MM/DD/YY)
    rsampath    02/25/10 - Adding checkAll and uncheckAll to utils
    hkarambe    06/24/09 - XbranchMerge hkarambe_enable_group_support from
                           st_workplace-d7ps1
    aduggad     04/04/08 - Changing the gotoBook* methode.
    sfrankli    02/22/08 - 
    anjbaner    11/28/07 - postponing refresh of menu
    sfrankli    09/26/07 - 
    rdharmch    04/10/07 - Add gotoBookMark method.
    anjbaner    03/23/07 - adding generic script to show popup by client id
    anjbaner    19/01/07 - added copyright message
 */


/**
 * Displays an ADF Faces popup component.
 *
 * @param popupId Server-side ID of the popup component
 * @param actionEvent Client-side event whose source would
 *  be used for locating the popup.
 * @param alignmentHint (Optional) hint for specifying the alignment
 *  of the popup with the event's source. Valid values are those 
 *  permissible for AdfRichPopup.HINT_ALIGN.
 */
function showPopup(popupId, actionEvent, alignmentHint)
{
  var actionSource = actionEvent.getSource();
  var popup = findComponent(actionSource, popupId);
  var popupHints = {};
  if (alignmentHint != null)
  {
    popupHints[AdfRichPopup.HINT_ALIGN_ID] = actionSource.getClientId();
    popupHints[AdfRichPopup.HINT_ALIGN] = alignmentHint;
  }
  popup.show(popupHints);
}

function selectUserOrGroup(event)
                      {
                       if (event.getSource().getValue() == '0')
                       {
                         event.getSource().findComponent('addmem').setVisible(true);
                         event.getSource().findComponent('addgrp').setVisible(false);

                         event.getSource().findComponent('idUserTooltip').setVisible(true);
                         event.getSource().findComponent('idGroupTooltip').setVisible(false);
                         
                         event.getSource().findComponent(':::inviteMemberSelected').setDisabled(false);
                       }
                       else 
                       {
                         event.getSource().findComponent('addmem').setVisible(false);
                         event.getSource().findComponent('addgrp').setVisible(true);

                         event.getSource().findComponent('idUserTooltip').setVisible(false);
                         event.getSource().findComponent('idGroupTooltip').setVisible(true);
                         
                         event.getSource().findComponent(':::inviteMemberSelected').setDisabled(true);
                         
                       }
                       event.cancel();
                      }
/**
 * Load a popup with content delivery as lazy. 
 * send in the popup id using a client attribute, e.g:- 
 *     <af:clientAttribute name="popupId" value="lang_popup"/>
 *  for a popup with id lang_popup
 */ 
function loadLazyPopup(event) 
{
  var component = event.getSource();
  var popupId = component.getProperty('popupId');
  var popupSubId = AdfRichUIPeer.CreateSubId(component.getClientId(), 
		      AdfDhtmlCommandToolbarButtonPeer._POPUP_ELEMENT);
  var evtTarget = event.getNativeEventTarget();

  event.cancel();
  var popup = event.getSource().findComponent(popupId);

  if (popup.isPopupVisible())
  {
    popup.hide();
  }
  else
  {
    var hints = {};
    hints[AdfDhtmlPopupWindow.HINT_LAUNCH_SOURCE_ID] = popupSubId;
    hints[AdfRichPopup.HINT_ALIGN] = AdfRichPopup.ALIGN_AFTER_START;
    hints[AdfRichPopup.HINT_ALIGN_ID] = component.getClientId();
    popup.show(hints);
  }
}

/**
 * Displays a popup given the client id. 
 *
 * <P>This is most commonly used to trigger off the popup
 * from the server side code. where only the client id is known. 
 *
 * @param clientId Full client id of the popup. 
 * @param alignId (Optional) full client id of component to align with
 * @param alignmentHint (Optional) hint for specifying alignment.
 */
function showPopupByClientId(popupClientId, alignId, alignmentHint)
{
  var popup = AdfPage.PAGE.findComponent(popupClientId);
  var popupHints = {};
  if (alignId != null && alignmentHint != null)
  {
    popupHints[AdfRichPopup.HINT_ALIGN_ID] = alignId;
    popupHints[AdfRichPopup.HINT_ALIGN] = alignmentHint;
  }
  popup.show(popupHints);
}

/**
 * Displays a popup given the client id. 
 * This is most commonly used to trigger off the popup
 * from the server side code. where only the client id is known. 
 * @param clientId The client id, got using component binding. 
 */
function showTheWCPopup(clientId)
{
  var popup = AdfPage.PAGE.findComponent(clientId);
  var hints = {};
  popup.show(hints);
}

/**
 * TODO: javadoc
 */
function changeLanguage(event) 
{ 
  //alert(event.getSource().getProperty("LANG_COOKIE"));
  setLangCookie(event.getSource().getProperty("LANG_COOKIE"), 
                event.getSource().getProperty("COOKIE_PATH"));
}
/**
 * TODO: javadoc
 */
function setLangCookie(langName, cookiePath)
{
  /* the same constant is also defined in LocaleUtils
     which is used when creating cookie using java server code.
     any change to the cookieName has to be kept in synch.
  */
  var cookieName = 'ORA_WEBCENTERAPP_USER_preferredLang';
  var today = new Date();
  var expire = new Date();
  expire.setTime(today.getTime() + 1000*60*60*24*365);
  var cookieStr = cookieName+"="+escape(langName)+
	      "; expires="+expire.toGMTString() +
	      "; path="+cookiePath;
  document.cookie = cookieStr;
}

/**
 * Closes an ADF Faces popup component.
 *
 * @param popupId Server-side ID of the popup component
 * @param actionEvent Client-side event whose source would
 *        be used for locating the popup.
 */
function hidePopup(popupId, actionEvent)
{
  var actionSource = actionEvent.getSource();
  var popup = findComponent(actionSource, popupId);
  popup.hide();
}

/**
 * Returns a client-side ADF Faces component having the specified
 * server-side ID and within the same scope (naming container)
 * as the specified sibling component.
 *
 * Additionally, if such a component cannot be located, then this
 * method further attempts to find a component having a client-side 
 * ID suffixed by a sequence possessed by the sibling component,
 * which would be the case typically when both the components are
 * included in an <af:forEach/>
 *
 * @param siblingComponent client-side ADF Faces component that is located
 *  within the same scope (naming container) as the popup component.
 * @param targetId Server-side ID of the component to be returned.
 *
 * @return Client-side ADF Faces component with specified ID.
 */
function findComponent(siblingComponent, targetId) // e.g. {...}, 'mypopup'
{
  var siblingClientId = siblingComponent.getClientId(); // e.g. '_id39:mybutton'
  var iColon = siblingClientId.lastIndexOf(':'); // e.g. 5
  var scopePrefix = siblingClientId.substring(0, iColon + 1); // e.g. '_id39:'
  var targetComponentClientId = scopePrefix + targetId; // e.g. '_id39:mypopup'
  var target = AdfPage.PAGE.findComponent(targetComponentClientId);
  if (target == null)
  {
    // Intelligently handling case when components
    // are included in an <af:forEach/> e.g.
    //   siblingClientId = '_id39:mybutton_26'
    var iIdSuffixStart = siblingClientId.lastIndexOf('_'); // e.g. 14
    var idSuffix = siblingClientId.substring(iIdSuffixStart); // e.g. '_26'
    var suffixedTargetClientId 
      = targetComponentClientId + idSuffix; // e.g. '_id39:mypopup_26'
    target = AdfPage.PAGE.findComponent(suffixedTargetClientId);
  }
  return target;
}

/**
 * Queues an ADF Faces custom event of type "<code>popupClosure</code>" 
 * on the server side.
 *
 * <P>Typical use of this method would be to register this method in a client
 * listener for a popup, so that any server listeners of type 
 * "<code>popupClosure</code>" registered with the popup would get invoked when
 * the popup gets closed, e.g. in the following snippet:
 *
 * <P>&lt;af:popup&gt;
 *   &lt;af:clientListener type="popupClosed" method="enqueuePopupClosureEvent"/&gt;
 *   &lt;af:serverListener type="popupClosure" method="#{myBean.handleCustomEvent}"/&gt;
 *   ...
 * &lt;/af:popup&gt;
 *
 * <P>if "<code>#{myBean}</code>" resolves to a bean having a method with
 * signature <code>void handleCustomEvent(CustomEvent event)</code>, then
 * that method would get called on <code>#{myBean}</code> after the popup
 * is closed.
 *
 * @param event ADF Faces client-side event that might have been queued
 *        on the popup that has got closed.
 */
function enqueuePopupClosureEvent(event)
{
  AdfCustomEvent.queue(event.getSource(), 'popupClosure', {}, false);
}


/**
 * Function to navigate to the location URL on click of a favorite.
 * @param event ADF Faces client-side action event.
 */
function gotoBookmark(event)
{
  event.cancel();
  var compSrc = event.getSource();
  var bookmarkLocation = compSrc.getProperty('bookmarkLocation');
  var bookmarkTarget = compSrc.getProperty('bookmarkTarget');
  var bookmarkName = compSrc.getProperty('text');
  
  if(bookmarkTarget == '_blank')
  {
    window.open(bookmarkLocation, bookmarkTarget, '', true);
  }
  else
  {
    /* Get user confirmation before moving out of webcenter page.*/
    var confirmRedirect = confirm(moveoutWCConfirmMessage);
    if(confirmRedirect)
    {
      window.location = bookmarkLocation;
    }
  }
}

/**
 * Function to set the default page title.
 */
function setAddFavoritesDialogDefaults(event)
{
  var linkNameComp =
    findComponent(event.getSource(), 'addFavoritesLinkName');
  linkNameComp.setProperty('value', document.title);
}

/**
 * Method to queue a client event to refresh the menu on closing popup.
 */
function queueWCLinksMenuRefreshEvent(event)
{
  var srcComp = event.getSource();
  var btnName = 'menuBtn';
  var eventName = 'refreshWCLinksMenu';
  var menuBtn = findComponent(srcComp, btnName);
  while(!menuBtn)
  {
    srcComp = srcComp.getParent();
    menuBtn = findComponent(srcComp, btnName);
  }
  //If the button was found.
  if(menuBtn)
  {
    AdfCustomEvent.queue(menuBtn,
                         eventName,
                         {refresh:true},
                         false);
  }
} 

function showPagePrintPreview(event)
{
  event.cancel();
  var actionSource = event.getSource();
  var pagePath = actionSource.getProperty("pagePath");
  var pageTitle = actionSource.getProperty("pageTitle");
  if (pagePath == null)
    return;
  var currentURL = window.location.href;
  var host = window.location.host;
  var index = currentURL.indexOf(host, 0);
  var startIndex = currentURL.indexOf("/", index);
  var endIndex = currentURL.indexOf("/", startIndex + 1);
  if (endIndex < 0)
    return;
  endIndex = currentURL.indexOf("/", endIndex + 1);
  if (endIndex < 0)
    return;
  var prefix = currentURL.slice(0, endIndex);

  if (pagePath.indexOf("?") < 0)
    pagePath = pagePath + "?wc.chromeLevel=noChrome&wc.printPreview=true";
  else
    pagePath = pagePath + "&wc.chromeLevel=noChrome&wc.printPreview=true";

  pagePath = prefix + pagePath;
  window.open(pagePath, "_blank",
    pageTitle, true);
}

function checkAllLanguagePopup(event)
{
	for (i = 0; i < 90; i++)
	{
		var id = "";
		if(i == 0) 
		{
			id ="T:j_id__ctru7:langreg:sb1::content";
		}
		else
		{
			id ="T:j_id__ctru7:langreg:sb1j_id_"+i+"::content";
		}
		var field = AdfPage.PAGE.findComponent(id);
		field.checked = true ;
	}
	event.cancel();
}

function uncheckAllLanguagePopup(event)
{
	for (i = 0; i < 90; i++)
	{
		var id = "";
		if(i == 0) 
		{
			id ="T:j_id__ctru7:langreg:sb1::content";
		}
		else
		{
			id ="T:j_id__ctru7:langreg:sb1j_id_"+i+"::content";
		}
		var field = AdfPage.PAGE.findComponent(id);
		field.checked = false ;
	}
	event.cancel();
}



